@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,16 +21,14 @@
 
 /*! \file channel.h
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.h 8916 2019-04-21 22:49:51Z michael $
+ * \version $Id: channel.h 9266 2020-02-12 16:55:29Z michael $
  */
 
 #ifndef INCLUDED_channel_h
 #define INCLUDED_channel_h
 
 #include "ircd_defs.h"        /* KEYLEN, CHANNELLEN */
-
-/* channel visible */
-#define ShowChannel(v,c)        (PubChannel(c) || IsMember((v),(c)))
+#include "extban.h"
 
 #define IsMember(who, chan) ((find_channel_link(who, chan)) ? 1 : 0)
 #define AddMemberFlag(x, y) ((x)->flags |=  (y))
@@ -78,12 +76,12 @@ struct Channel
   char topic[TOPICLEN + 1];
   char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];
 
-  uintmax_t creationtime;  /**< Real time */
+  uintmax_t creation_time;  /**< Real time */
   uintmax_t topic_time;  /**< Real time */
-  uintmax_t last_knock;  /**< Don't allow knock to flood; monotonic time */
-  uintmax_t last_invite;  /**< Monotonic time */
+  uintmax_t last_knock_time;  /**< Don't allow knock to flood; monotonic time */
+  uintmax_t last_invite_time;  /**< Monotonic time */
   uintmax_t last_join_time;  /**< Monotonic time */
-  uintmax_t first_received_message_time; /*!< Channel flood control; monotonic time */
+  uintmax_t first_received_message_time;  /*!< Channel flood control; monotonic time */
   unsigned int flags;
   unsigned int received_number_of_privmsgs;
 
@@ -100,66 +98,57 @@ struct Channel
   size_t name_len;
 };
 
-/*! \brief Membership structure */
-struct Membership
+/*! \brief ChannelMember structure */
+struct ChannelMember
 {
-  dlink_node locchannode;  /**< link to chptr->members_local */
-  dlink_node channode;     /**< link to chptr->members    */
-  dlink_node usernode;     /**< link to source_p->channel */
-  struct Channel *chptr;   /**< Channel pointer */
-  struct Client *client_p; /**< Client pointer */
-  unsigned int flags;      /**< user/channel flags, e.g. CHFL_CHANOP */
+  dlink_node locchannode;  /**< link to channel->members_local */
+  dlink_node channode;  /**< link to channel->members */
+  dlink_node usernode;  /**< link to client->channel */
+  struct Channel *channel;  /**< Channel pointer */
+  struct Client *client;  /**< Client pointer */
+  unsigned int flags;  /**< user/channel flags, e.g. CHFL_CHANOP */
 };
 
+enum { BANSTRLEN = 200 }; /* XXX */
+
 /*! \brief Ban structure. Used for b/e/I n!u\@h masks */
 struct Ban
 {
   dlink_node node;
+  unsigned int extban;
+  char banstr[BANSTRLEN];
   char name[NICKLEN + 1];
   char user[USERLEN + 1];
   char host[HOSTLEN + 1];
   char who[NICKLEN + USERLEN + HOSTLEN + 3];
-  size_t len;
+  size_t banstr_len;  /**< Cached string length of Ban::banstr */
   uintmax_t when;  /**< Time this ban has been set; real time */
   struct irc_ssaddr addr;
   int bits;
   int type;
 };
 
-/*! \brief Invite structure */
-struct Invite
-{
-  dlink_node user_node;  /**< link to client_p->connection->invited */
-  dlink_node chan_node;  /**< link to chptr->invites */
-  struct Channel *chptr;  /**< Channel pointer */
-  struct Client *client_p;  /**< Client pointer */
-  uintmax_t when;  /**< Time the invite has been created; monotonic time */
-};
-
-
 extern const dlink_list *channel_get_list(void);
 extern bool channel_check_name(const char *, bool);
-extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *, bool);
-extern bool is_banned(const struct Channel *, const struct Client *);
-extern int has_member_flags(const struct Membership *, const unsigned int);
+extern int can_send(struct Channel *, struct Client *, struct ChannelMember *, const char *, bool);
+extern bool is_banned(struct Channel *, struct Client *);
+extern bool find_bmask(struct Client *, struct Channel*, const dlink_list *, struct Extban *);
+extern int has_member_flags(const struct ChannelMember *, const unsigned int);
 
 extern void channel_do_join(struct Client *, char *, char *);
 extern void channel_do_part(struct Client *, char *, const char *);
 extern void remove_ban(struct Ban *, dlink_list *);
 extern void add_user_to_channel(struct Channel *, struct Client *, unsigned int, bool);
-extern void remove_user_from_channel(struct Membership *);
+extern void remove_user_from_channel(struct ChannelMember *);
 extern void channel_member_names(struct Client *, struct Channel *, bool);
-extern void add_invite(struct Channel *, struct Client *);
-extern void del_invite(struct Invite *);
-extern void clear_invite_list(dlink_list *);
 extern void channel_send_modes(struct Client *, const struct Channel *);
 extern void channel_modes(const struct Channel *, const struct Client *, char *, char *);
 extern void check_spambot_warning(struct Client *, const char *);
 extern void channel_free(struct Channel *);
 extern void channel_set_topic(struct Channel *, const char *, const char *, uintmax_t, bool);
 
-extern const char *get_member_status(const struct Membership *, bool);
+extern const char *get_member_status(const struct ChannelMember *, bool);
 
 extern struct Channel *channel_make(const char *);
-extern struct Membership *find_channel_link(const struct Client *, const struct Channel *);
+extern struct ChannelMember *find_channel_link(const struct Client *, const struct Channel *);
 #endif  /* INCLUDED_channel_h */
