@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id: channel_mode.h 8807 2019-01-19 19:47:11Z michael $
+ * \version $Id: channel_mode.h 9233 2020-01-31 17:31:08Z michael $
  */
 
 #ifndef INCLUDED_channel_mode_h
@@ -63,7 +63,8 @@ enum
   CHFL_INVEX        = 1 << 5,
   /* Cache flags for silence on ban */
   CHFL_BAN_CHECKED  = 1 << 6,
-  CHFL_BAN_SILENCED = 1 << 7
+  CHFL_BAN_SILENCED = 1 << 7,
+  CHFL_MUTE_CHECKED = 1 << 8
 };
 
 /* channel modes ONLY */
@@ -75,7 +76,7 @@ enum
   MODE_TOPICLIMIT   = 1 <<  3,  /**< Only chanops can change the topic */
   MODE_INVITEONLY   = 1 <<  4,  /**< Only invited users may join this channel */
   MODE_NOPRIVMSGS   = 1 <<  5,  /**< Users must be in the channel to send text to it */
-  MODE_SSLONLY      = 1 <<  6,  /**< Prevents anyone who isn't connected via SSL/TLS from joining the channel */
+  MODE_SECUREONLY   = 1 <<  6,  /**< Prevents anyone who isn't connected via TLS from joining the channel */
   MODE_OPERONLY     = 1 <<  7,  /**< Prevents anyone who hasn't obtained IRC operator status from joining the channel */
   MODE_REGISTERED   = 1 <<  8,  /**< Channel has been registered with ChanServ */
   MODE_REGONLY      = 1 <<  9,  /**< Only registered clients may join a channel with that mode set */
@@ -124,8 +125,8 @@ extern const struct chan_mode *cmode_map[];
 extern const struct chan_mode  cmode_tab[];
 
 extern void channel_mode_init(void);
-extern bool add_id(struct Client *, struct Channel *, char *, dlink_list *);
+extern const char *add_id(struct Client *, struct Channel *, const char *, dlink_list *, unsigned int);
 extern void channel_mode_set(struct Client *, struct Channel *,
-                             struct Membership *, int, char **);
+                             struct ChannelMember *, int, char **);
 extern void clear_ban_cache_list(dlink_list *);
 #endif /* INCLUDED_channel_mode_h */
