@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.h
  * \brief The file descriptor list header.
- * \version $Id: fdlist.h 8806 2019-01-19 19:32:10Z michael $
+ * \version $Id: fdlist.h 9156 2020-01-13 14:51:47Z michael $
  */
 
 #ifndef INCLUDED_fdlist_h
@@ -75,7 +75,7 @@ typedef struct _fde
     /* We'd also add the retry count here when we get to that -- adrian */
   } connect;
 
-  tls_data_t ssl;
+  tls_data_t tls;
 } fde_t;
 
 extern int number_fd;
