@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file listener.h
  * \brief A header for the listener code.
- * \version $Id: listener.h 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: listener.h 9156 2020-01-13 14:51:47Z michael $
  */
 
 #ifndef INCLUDED_listener_h
@@ -32,7 +32,7 @@
 
 enum
 {
-  LISTENER_SSL    = 1 << 0,
+  LISTENER_TLS    = 1 << 0,
   LISTENER_HIDDEN = 1 << 1,
   LISTENER_SERVER = 1 << 2
 };
@@ -46,7 +46,7 @@ struct Listener
   int ref_count;             /**< Number of connection references */
   struct irc_ssaddr addr;    /**< Holds an IPv6 or IPv4 address */
   char name[HOSTIPLEN + 1];  /**< Holds an IPv6 or IPv4 address in string representation*/
-  unsigned int flags;        /**< Listener flags (ssl, hidden, server) */
+  unsigned int flags;        /**< Listener flags (tls, hidden, server) */
 };
 
 extern const dlink_list *listener_get_list(void);
