@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file numeric.h
  * \brief Declarations of numeric replies.
- * \version $Id: numeric.h 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: numeric.h 9291 2020-02-23 10:33:32Z michael $
  */
 
 #ifndef INCLUDED_numeric_h
@@ -179,6 +179,7 @@ enum irc_numerics
   ERR_NONICKNAMEGIVEN      = 431,
   ERR_ERRONEUSNICKNAME     = 432,
   ERR_NICKNAMEINUSE        = 433,
+  ERR_BANNICKCHANGE        = 435,
   ERR_NICKCOLLISION        = 436,
   ERR_NICKTOOFAST          = 438,
   ERR_SERVICESDOWN         = 440,
@@ -208,7 +209,7 @@ enum irc_numerics
   ERR_CANTKILLSERVER       = 483,
   ERR_CHANBANREASON        = 485,
   ERR_NONONREG             = 486,
-  ERR_SSLONLYCHAN          = 489,
+  ERR_SECUREONLYCHAN       = 489,
   ERR_NOOPERHOST           = 491,
   ERR_NOCTCP               = 492,
   ERR_UMODEUNKNOWNFLAG     = 501,
@@ -245,6 +246,7 @@ enum irc_numerics
   RPL_TARGNOTIFY           = 717,
   RPL_UMODEGMSG            = 718,
   ERR_NOPRIVS              = 723,
+  ERR_INVALIDBAN           = 743,
   RPL_ETRACEEND            = 759,
   ERR_LAST_ERR_MSG         = 999
 };
