@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file parse.h
  * \brief A header for the message parser.
- * \version $Id: parse.h 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: parse.h 9102 2020-01-01 09:58:57Z michael $
  */
 
 #ifndef INCLUDED_parse_h
@@ -85,7 +85,7 @@ struct Message
   /* handlers:
    * UNREGISTERED, CLIENT, SERVER, ENCAP, OPER, LAST
    */
-  int (*handlers[LAST_HANDLER_TYPE])(struct Client *, int, char *[]);
+  void (*handlers[LAST_HANDLER_TYPE])(struct Client *, int, char *[]);
 };
 
 #define MAXPARA    15
@@ -103,8 +103,8 @@ extern struct Message *find_command(const char *);
 extern void report_messages(struct Client *);
 
 /* generic handlers */
-extern int m_ignore(struct Client *, int, char *[]);
-extern int m_not_oper(struct Client *, int, char *[]);
-extern int m_registered(struct Client *, int, char *[]);
-extern int m_unregistered(struct Client *, int, char *[]);
+extern void m_ignore(struct Client *, int, char *[]);
+extern void m_not_oper(struct Client *, int, char *[]);
+extern void m_registered(struct Client *, int, char *[]);
+extern void m_unregistered(struct Client *, int, char *[]);
 #endif  /* INCLUDED_parse_h */
