@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2019 ircd-hybrid development team
+ *  Copyright (c) 2015-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,14 +23,14 @@
 
 /*! \file tls_gnutls.h
  * \brief GnuTLS-specific TLS types
- * \version $Id: tls_gnutls.h 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: tls_gnutls.h 9194 2020-01-21 15:56:22Z michael $
  */
 
 
 #ifndef INCLUDED_tls_gnutls_h
 #define INCLUDED_tls_gnutls_h
 
-#if defined(HAVE_LIBGNUTLS) && !defined(HAVE_LIBCRYPTO)
+#ifdef HAVE_LIBGNUTLS
 
 #define HAVE_TLS
 #define HAVE_TLS_GNUTLS
@@ -57,5 +57,5 @@ typedef struct
   tls_context_t context;
 } tls_data_t;
 
-#endif  /* defined(HAVE_LIBGNUTLS) && !defined(HAVE_LIBCRYPTO) */
-#endif  /* INCLUDED_tls_openssl_h */
+#endif  /* HAVE_LIBGNUTLS */
+#endif  /* INCLUDED_tls_gnutls_h */
