@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_bmask.c
  * \brief Includes required functions for processing the BMASK command.
- * \version $Id: m_bmask.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_bmask.c 9347 2020-04-25 17:00:41Z michael $
  */
 
 #include "stdinc.h"
@@ -52,39 +52,43 @@
  *      - parv[3] = type of ban to add ('b' 'I' or 'e')
  *      - parv[4] = space delimited list of masks to add
  */
-static int
+static void
 ms_bmask(struct Client *source_p, int parc, char *parv[])
 {
   char modebuf[IRCD_BUFSIZE] = "";
   char parabuf[IRCD_BUFSIZE] = "";
   char banbuf[IRCD_BUFSIZE] = "";
-  struct Channel *chptr = NULL;
+  struct Channel *channel = NULL;
+  const char *mask;
   char *s, *t, *mbuf, *pbuf;
   dlink_list *list = NULL;
   int mlen = 0, tlen = 0;
   int modecount = 0;
-  unsigned int flags = 0;
+  unsigned int flags = 0, type = 0;
 
-  if ((chptr = hash_find_channel(parv[2])) == NULL)
-    return 0;
+  if ((channel = hash_find_channel(parv[2])) == NULL)
+    return;
 
   /* TS is higher, drop it. */
-  if (strtoumax(parv[1], NULL, 10) > chptr->creationtime)
-    return 0;
+  if (strtoumax(parv[1], NULL, 10) > channel->creation_time)
+    return;
 
   switch (*parv[3])
   {
     case 'b':
-      list = &chptr->banlist;
+      type = CHFL_BAN;
+      list = &channel->banlist;
       break;
     case 'e':
-      list = &chptr->exceptlist;
+      type = CHFL_EXCEPTION;
+      list = &channel->exceptlist;
       break;
     case 'I':
-      list = &chptr->invexlist;
+      type = CHFL_INVEX;
+      list = &channel->invexlist;
       break;
     default:
-      return 0;
+      return;
   }
 
   strlcpy(banbuf, parv[4], sizeof(banbuf));
@@ -92,11 +96,11 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
 
   mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s +",
                   (IsHidden(source_p) || ConfigServerHide.hide_servers) ? me.name : source_p->name,
-                  chptr->name);
+                  channel->name);
   mbuf = modebuf + mlen;
   pbuf = parabuf;
 
-  if (HasCMode(chptr, MODE_HIDEBMASKS))
+  if (HasCMode(channel, MODE_HIDEBMASKS))
     flags = CHFL_CHANOP | CHFL_HALFOP;
 
   do
@@ -109,10 +113,10 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
     if (tlen > MODEBUFLEN)
       break;
 
-    if (tlen && *s != ':' && add_id(source_p, chptr, s, list) == true)
+    if (tlen && *s != ':' && (mask = add_id(source_p, channel, s, list, type)))
     {
-      /* add_id can modify 's' */
-      tlen = strlen(s);
+      /* add_id can modify the actual ban mask */
+      tlen = strlen(mask);
 
       /* this new one wont fit.. */
       if (mbuf - modebuf + 2 + pbuf - parabuf + tlen > IRCD_BUFSIZE - 2 ||
@@ -120,14 +124,14 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
       {
         *mbuf = *(pbuf - 1) = '\0';
 
-        sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
+        sendto_channel_local(NULL, channel, flags, 0, 0, "%s %s", modebuf, parabuf);
         mbuf = modebuf + mlen;
         pbuf = parabuf;
         modecount = 0;
       }
 
       *mbuf++ = *parv[3];
-      pbuf += sprintf(pbuf, "%s ", s);
+      pbuf += snprintf(pbuf, sizeof(parabuf) - (pbuf - parabuf), "%s ", mask);
       ++modecount;
     }
 
@@ -137,13 +141,12 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   if (modecount)
   {
     *mbuf = *(pbuf - 1) = '\0';
-    sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
+    sendto_channel_local(NULL, channel, flags, 0, 0, "%s %s", modebuf, parabuf);
   }
 
   sendto_server(source_p, 0, 0, ":%s BMASK %ju %s %s :%s",
-                source_p->id, chptr->creationtime, chptr->name,
+                source_p->id, channel->creation_time, channel->name,
                 parv[3], parv[4]);
-  return 0;
 }
 
 static struct Message bmask_msgtab =
@@ -172,7 +175,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9347 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
