@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_error.c
  * \brief Includes required functions for processing the ERROR command.
- * \version $Id: m_error.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_error.c 9364 2020-04-30 19:24:10Z michael $
  */
 
 #include "stdinc.h"
@@ -45,15 +45,17 @@
  *      - parv[0] = command
  *      - parv[1] = error message
  */
-static int
+static void
 mr_error(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = (parc > 1 && !EmptyString(parv[1])) ? parv[1] : "<>";
-
   assert(MyConnect(source_p));
 
   if (!IsHandshake(source_p) && !IsConnecting(source_p))
-    return 0;
+    return;
+
+  const char *message = "<>";
+  if (parc > 1 && !EmptyString(parv[1]))
+    message = parv[1];
 
   ilog(LOG_TYPE_IRCD, "Received ERROR message from %s: %s",
        source_p->name, message);
@@ -64,7 +66,6 @@ mr_error(struct Client *source_p, int parc, char *parv[])
   sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                        "ERROR :from %s -- %s",
                        client_get_name(source_p, MASK_IP), message);
-  return 0;
 }
 
 /*! \brief ERROR command handler
@@ -78,10 +79,12 @@ mr_error(struct Client *source_p, int parc, char *parv[])
  *      - parv[0] = command
  *      - parv[1] = error message
  */
-static int
+static void
 ms_error(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = (parc > 1 && !EmptyString(parv[1])) ? parv[1] : "<>";
+  const char *message = "<>";
+  if (parc > 1 && !EmptyString(parv[1]))
+    message = parv[1];
 
   ilog(LOG_TYPE_IRCD, "Received ERROR message from %s: %s",
        source_p->name, message);
@@ -95,7 +98,6 @@ ms_error(struct Client *source_p, int parc, char *parv[])
                          "ERROR :from %s via %s -- %s",
                          source_p->name,
                          client_get_name(source_p->from, MASK_IP), message);
-  return 0;
 }
 
 static struct Message error_msgtab =
@@ -123,7 +125,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9364 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
