@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_message.c
  * \brief Includes required functions for processing the PRIVMSG/NOTICE command.
- * \version $Id: m_message.c 8983 2019-05-21 13:18:58Z michael $
+ * \version $Id: m_message.c 9364 2020-04-30 19:24:10Z michael $
  */
 
 #include "stdinc.h"
@@ -121,8 +121,7 @@ flood_attack_client(bool notice, struct Client *source_p, struct Client *target_
   {
     if (!HasFlag(target_p, FLAGS_FLOOD_NOTICED))
     {
-      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
-                           "Possible Flooder %s on %s target: %s",
+      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
                            client_get_name(source_p, HIDE_IP),
                            source_p->servptr->name, target_p->name);
       AddFlag(target_p, FLAGS_FLOOD_NOTICED);
@@ -145,10 +144,10 @@ flood_attack_client(bool notice, struct Client *source_p, struct Client *target_
  *              - pointer to source Client
  *              - pointer to target channel
  * output       - 1 if target is under flood attack
- * side effects - check for flood attack on target chptr
+ * side effects - check for flood attack on target channel
  */
 static bool
-flood_attack_channel(bool notice, struct Client *source_p, struct Channel *chptr)
+flood_attack_channel(bool notice, struct Client *source_p, struct Channel *channel)
 {
   if (!(GlobalSetOptions.floodcount && GlobalSetOptions.floodtime))
     return false;
@@ -159,37 +158,36 @@ flood_attack_channel(bool notice, struct Client *source_p, struct Channel *chptr
   if (HasFlag(source_p, FLAGS_SERVICE | FLAGS_CANFLOOD))
     return false;
 
-  if (chptr->first_received_message_time + GlobalSetOptions.floodtime < event_base->time.sec_monotonic)
+  if (channel->first_received_message_time + GlobalSetOptions.floodtime < event_base->time.sec_monotonic)
   {
-    if (chptr->received_number_of_privmsgs)
-      chptr->received_number_of_privmsgs = 0;
+    if (channel->received_number_of_privmsgs)
+      channel->received_number_of_privmsgs = 0;
     else
-      ClearFloodNoticed(chptr);
+      ClearFloodNoticed(channel);
 
-    chptr->first_received_message_time = event_base->time.sec_monotonic;
+    channel->first_received_message_time = event_base->time.sec_monotonic;
   }
 
-  if (chptr->received_number_of_privmsgs >= GlobalSetOptions.floodcount)
+  if (channel->received_number_of_privmsgs >= GlobalSetOptions.floodcount)
   {
-    if (!IsSetFloodNoticed(chptr))
+    if (!IsSetFloodNoticed(channel))
     {
-      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
-                           "Possible Flooder %s on %s target: %s",
+      sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE, "Possible Flooder %s on %s target: %s",
                            client_get_name(source_p, HIDE_IP),
-                           source_p->servptr->name, chptr->name);
-      SetFloodNoticed(chptr);
+                           source_p->servptr->name, channel->name);
+      SetFloodNoticed(channel);
     }
 
     if (MyClient(source_p))
     {
       if (notice == false)
         sendto_one_notice(source_p, &me, ":*** Message to %s throttled due to flooding",
-                          chptr->name);
+                          channel->name);
       return true;
     }
   }
 
-  ++chptr->received_number_of_privmsgs;
+  ++channel->received_number_of_privmsgs;
   return false;
 }
 
@@ -205,7 +203,7 @@ flood_attack_channel(bool notice, struct Client *source_p, struct Channel *chptr
  * side effects	- message given channel either chanop or voice
  */
 static void
-msg_channel(bool notice, struct Client *source_p, struct Channel *chptr,
+msg_channel(bool notice, struct Client *source_p, struct Channel *channel,
             unsigned int flags, const char *text)
 {
   unsigned int type = 0;
@@ -228,15 +226,15 @@ msg_channel(bool notice, struct Client *source_p, struct Channel *chptr,
   }
 
   /* Chanops and voiced can flood their own channel with impunity */
-  int ret = can_send(chptr, source_p, NULL, text, notice);
+  int ret = can_send(channel, source_p, NULL, text, notice);
   if (ret < 0)
   {
-    if (ret == CAN_SEND_OPV || flood_attack_channel(notice, source_p, chptr) == false)
-      sendto_channel_butone(source_p, source_p, chptr, type, "%s %s%s :%s",
-                            command[notice], prefix, chptr->name, text);
+    if (ret == CAN_SEND_OPV || flood_attack_channel(notice, source_p, channel) == false)
+      sendto_channel_butone(source_p, source_p, channel, type, "%s %s%s :%s",
+                            command[notice], prefix, channel->name, text);
   }
   else if (notice == false)
-    sendto_one_numeric(source_p, &me, ret, chptr->name, text);
+    sendto_one_numeric(source_p, &me, ret, channel->name, text);
 }
 
 /* msg_client()
@@ -332,15 +330,14 @@ static void
 handle_special(bool notice, struct Client *source_p,
                const char *nick, const char *text)
 {
-  struct Client *target_p = NULL;
-  const char *server = NULL, *s = NULL;
-
   /*
    * user[%host]@server addressed?
    */
-  if ((server = strchr(nick, '@')))
+  const char *server = strchr(nick, '@');
+  if (server)
   {
-    if ((target_p = hash_find_server(server + 1)) == NULL)
+    struct Client *target_p = hash_find_server(server + 1);
+    if (target_p == NULL)
     {
       sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, server + 1);
       return;
@@ -385,7 +382,8 @@ handle_special(bool notice, struct Client *source_p,
       return;
     }
 
-    if ((s = strrchr(nick, '.')) == NULL)
+    const char *s = strrchr(nick, '.');
+    if (s == NULL)
     {
       sendto_one_numeric(source_p, &me, ERR_NOTOPLEVEL, nick);
       return;
@@ -508,8 +506,8 @@ build_target_list(bool notice, struct Client *source_p, char *list, const char *
       }
 
       /*
-       * At this point, name+1 should be a channel name i.e. #foo or &foo
-       * if the channel is found, fine, if not report an error
+       * At this point, name+1 should be a channel name i.e. #foo. If the channel
+       * is found, fine, if not report an error.
        */
       if ((target = hash_find_channel(name)))
       {
@@ -592,7 +590,7 @@ m_message(bool notice, struct Client *source_p, int parc, char *parv[])
   }
 }
 
-static int
+static void
 m_privmsg(struct Client *source_p, int parc, char *parv[])
 {
   /*
@@ -600,20 +598,18 @@ m_privmsg(struct Client *source_p, int parc, char *parv[])
    * for a notice.. (for example remote kline replies) --fl_
    */
   if (!IsClient(source_p))
-    return 0;
+    return;
 
   if (MyConnect(source_p))
     source_p->connection->last_privmsg = event_base->time.sec_monotonic;
 
   m_message(false, source_p, parc, parv);
-  return 0;
 }
 
-static int
+static void
 m_notice(struct Client *source_p, int parc, char *parv[])
 {
   m_message(true, source_p, parc, parv);
-  return 0;
 }
 
 static struct Message privmsg_msgtab =
@@ -655,7 +651,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8983 $",
+  .version = "$Revision: 9364 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
