@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 8927 2019-04-22 11:08:47Z michael $
+ * \version $Id: m_nick.c 9304 2020-02-25 10:51:22Z michael $
  */
 
 #include "stdinc.h"
@@ -36,6 +36,7 @@
 #include "user.h"
 #include "whowas.h"
 #include "send.h"
+#include "channel.h"
 #include "channel_mode.h"
 #include "parse.h"
 #include "modules.h"
@@ -44,6 +45,7 @@
 #include "misc.h"
 #include "id.h"
 #include "ipcache.h"
+#include "extban.h"
 
 
 /* check_clean_nick()
@@ -58,7 +60,7 @@
  * side effects - if nickname is erroneous, or a different length to
  *                truncated nickname, return 1
  */
-static int
+static bool
 check_clean_nick(struct Client *source_p, const char *nick)
 {
   assert(IsServer(source_p) || (IsClient(source_p) && !MyConnect(source_p)));
@@ -68,7 +70,7 @@ check_clean_nick(struct Client *source_p, const char *nick)
    * and don't bother messing at all
    */
   if (valid_nickname(nick, false) == true)
-    return 0;
+    return true;
 
   ++ServerStats.is_kill;
   sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE, "Bad/long Nick: %s From: %s(via %s)",
@@ -86,16 +88,16 @@ check_clean_nick(struct Client *source_p, const char *nick)
     exit_client(source_p, "Bad Nickname");
   }
 
-  return 1;
+  return false;
 }
 
-static int
+static bool
 check_clean_uid(struct Client *source_p, const char *nick, const char *uid)
 {
   assert(IsServer(source_p));
 
   if (valid_uid(uid) == true && strncmp(uid, source_p->id, IRC_MAXSID) == 0)
-    return 0;
+    return true;
 
   ++ServerStats.is_kill;
   sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
@@ -103,7 +105,7 @@ check_clean_uid(struct Client *source_p, const char *nick, const char *uid)
                        uid, nick, source_p->name, source_p->from->name);
   sendto_one(source_p, ":%s KILL %s :%s (Bad UID)",
              me.id, uid, me.name);
-  return 1;
+  return false;
 }
 
 /* check_clean_user()
@@ -115,13 +117,13 @@ check_clean_uid(struct Client *source_p, const char *nick, const char *uid)
  * output       - none
  * side effects - if username is erroneous, return 1
  */
-static int
+static bool
 check_clean_user(struct Client *source_p, const char *nick, const char *user)
 {
   assert(IsServer(source_p));
 
   if (valid_username(user, false) == true)
-    return 0;
+    return true;
 
   ++ServerStats.is_kill;
   sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
@@ -129,7 +131,7 @@ check_clean_user(struct Client *source_p, const char *nick, const char *user)
                        user, nick, source_p->name, source_p->from->name);
   sendto_one(source_p, ":%s KILL %s :%s (Bad Username)",
              me.id, nick, me.name);
-  return 1;
+  return false;
 }
 
 /* check_clean_host()
@@ -141,13 +143,13 @@ check_clean_user(struct Client *source_p, const char *nick, const char *user)
  * output       - none
  * side effects - if hostname is erroneous, return 1
  */
-static int
+static bool
 check_clean_host(struct Client *source_p, const char *nick, const char *host)
 {
   assert(IsServer(source_p));
 
   if (valid_hostname(host) == true)
-    return 0;
+    return true;
 
   ++ServerStats.is_kill;
   sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
@@ -155,7 +157,7 @@ check_clean_host(struct Client *source_p, const char *nick, const char *host)
                        host, nick, source_p->name, source_p->from->name);
   sendto_one(source_p, ":%s KILL %s :%s (Bad Hostname)",
              me.id, nick, me.name);
-  return 1;
+  return false;
 }
 
 /* set_initial_nick()
@@ -227,17 +229,17 @@ change_local_nick(struct Client *source_p, const char *nick)
     if (HasUMode(source_p, UMODE_REGISTERED))
     {
       unsigned int oldmodes = source_p->umodes;
-      char modebuf[IRCD_BUFSIZE] = "";
+      char buf[UMODE_MAX_STR] = "";
 
       DelUMode(source_p, UMODE_REGISTERED);
-      send_umode(source_p, true, oldmodes, modebuf);
+      send_umode(source_p, true, oldmodes, buf);
     }
   }
 
   /*
-   * Client just changing his/her nick. If he/she is on a channel,
-   * send note of change to all clients on that channel. Propagate
-   * notice to other servers.
+   * Client just changing their nick. If they are on a channel, send
+   * note of change to all clients on that channel. Propagate notice
+   * to other servers.
    */
   sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
                        "Nick change: From %s to %s [%s@%s]",
@@ -254,7 +256,7 @@ change_local_nick(struct Client *source_p, const char *nick)
   strlcpy(source_p->name, nick, sizeof(source_p->name));
   hash_add_client(source_p);
 
-  if (samenick == 0)
+  if (samenick == false)
     watch_check_hash(source_p, RPL_LOGON);
 
   /* fd_desc is long enough */
@@ -265,7 +267,6 @@ change_local_nick(struct Client *source_p, const char *nick)
  *
  * \param source_p Pointer to allocated Client struct from which the message
  *                 originally comes from.  This can be a local or remote client.
- * \param parc     Integer holding the number of supplied arguments.
  * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
  *                 pointers.
  * \note Valid arguments for this command are:
@@ -613,7 +614,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
  *      - parv[0] = command
  *      - parv[1] = nickname
  */
-static int
+static void
 mr_nick(struct Client *source_p, int parc, char *parv[])
 {
   char nick[NICKLEN + 1] = "";
@@ -621,7 +622,7 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
   /* Copy the nick and terminate it */
@@ -631,27 +632,25 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
   if (valid_nickname(nick, true) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, parv[1], "Erroneous Nickname");
-    return 0;
+    return;
   }
 
   /* Check if the nick is resv'd */
-  const struct ResvItem *resv;
-  if ((resv = resv_find(nick, match)))
+  const struct ResvItem *resv = resv_find(nick, match);
+  if (resv)
   {
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, resv->reason);
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
                          nick, client_get_name(source_p, HIDE_IP));
-    return 0;
+    return;
   }
 
-  struct Client *target_p;
-  if ((target_p = hash_find_client(nick)) == NULL || target_p == source_p)
+  struct Client *target_p = hash_find_client(nick);
+  if (target_p == NULL || target_p == source_p)
     set_initial_nick(source_p, nick);
   else
     sendto_one_numeric(source_p, &me, ERR_NICKNAMEINUSE, target_p->name);
-
-  return 0;
 }
 
 /*! \brief NICK command handler
@@ -665,7 +664,7 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
  *      - parv[0] = command
  *      - parv[1] = nickname
  */
-static int
+static void
 m_nick(struct Client *source_p, int parc, char *parv[])
 {
   char nick[NICKLEN + 1] = "";
@@ -676,7 +675,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
   /* Terminate nick to NICKLEN */
@@ -686,7 +685,7 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   if (valid_nickname(nick, true) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, "Erroneous Nickname");
-    return 0;
+    return;
   }
 
   if (!HasFlag(source_p, FLAGS_EXEMPTRESV) &&
@@ -697,26 +696,32 @@ m_nick(struct Client *source_p, int parc, char *parv[])
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "Forbidding reserved nick %s from user %s",
                          nick, client_get_name(source_p, HIDE_IP));
-    return 0;
+    return;
   }
 
   dlink_node *node;
   DLINK_FOREACH(node, source_p->channel.head)
   {
-    const struct Membership *member = node->data;
+    struct ChannelMember *member = node->data;
 
-    if (HasCMode(member->chptr, MODE_NONICKCHANGE))
+    if ((member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE)) == 0)
     {
-      if (has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP) == 0)
+      if (HasCMode(member->channel, MODE_NONICKCHANGE))
       {
-        sendto_one_numeric(source_p, &me, ERR_NONICKCHANGE, member->chptr->name);
-        return 0;
+        sendto_one_numeric(source_p, &me, ERR_NONICKCHANGE, member->channel->name);
+        return;
+      }
+
+      if (extban_nick_can_change(member->channel, source_p, member) == ERR_BANNEDFROMCHAN)
+      {
+        sendto_one_numeric(source_p, &me, ERR_BANNICKCHANGE, member->channel->name);
+        return;
       }
     }
   }
 
-  struct Client *target_p;
-  if ((target_p = hash_find_client(nick)) == NULL)
+  struct Client *target_p = hash_find_client(nick);
+  if (target_p == NULL)
     change_local_nick(source_p, nick);
   else if (target_p == source_p)
   {
@@ -740,8 +745,6 @@ m_nick(struct Client *source_p, int parc, char *parv[])
   }
   else
     sendto_one_numeric(source_p, &me, ERR_NICKNAMEINUSE, target_p->name);
-
-  return 0;
 }
 
 /*! \brief NICK command handler
@@ -758,21 +761,21 @@ m_nick(struct Client *source_p, int parc, char *parv[])
  *      - parv[1] = nickname
  *      - parv[2] = timestamp
  */
-static int
+static void
 ms_nick(struct Client *source_p, int parc, char *parv[])
 {
   if (parc != 3 || EmptyString(parv[parc - 1]))
-    return 0;
+    return;
 
   if (!IsClient(source_p))
-    return 0;  /* Servers and unknown clients can't change nicks.. */
+    return;  /* Servers and unknown clients can't change nicks.. */
 
-  if (check_clean_nick(source_p, parv[1]))
-    return 0;
+  if (check_clean_nick(source_p, parv[1]) == false)
+    return;
 
   /* If the nick doesn't exist, allow it and process like normal */
-  struct Client *target_p;
-  if ((target_p = hash_find_client(parv[1])) == NULL)
+  struct Client *target_p = hash_find_client(parv[1]);
+  if (target_p == NULL)
     change_remote_nick(source_p, parv);
   else if (IsUnknown(target_p))
   {
@@ -787,7 +790,6 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
   }
   else if (perform_nick_change_collides(source_p, target_p, parc, parv) == true)
     change_remote_nick(source_p, parv);
-  return 0;
 }
 
 /*! \brief UID command handler
@@ -824,29 +826,29 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
  *      - parv[10] = services id (account name)
  *      - parv[11] = ircname (gecos)
  */
-static int
+static void
 ms_uid(struct Client *source_p, int parc, char *parv[])
 {
   /* TBR: compatibility mode */
   const int does_rhost = parc == 12;
 
-  if (check_clean_nick(source_p, parv[1]) ||
-      check_clean_user(source_p, parv[1], parv[5]) ||
-      check_clean_host(source_p, parv[1], parv[6]) ||
-      check_clean_uid(source_p, parv[1], parv[8 + does_rhost]))
-    return 0;
+  if (check_clean_nick(source_p, parv[1]) == false ||
+      check_clean_user(source_p, parv[1], parv[5]) == false ||
+      check_clean_host(source_p, parv[1], parv[6]) == false ||
+      check_clean_uid(source_p, parv[1], parv[8 + does_rhost]) == false)
+    return;
 
   /* TBR: compatibility mode */
-  if (does_rhost && check_clean_host(source_p, parv[1], parv[7]))
-    return 0;
+  if (does_rhost && check_clean_host(source_p, parv[1], parv[7]) == false)
+    return;
 
   /*
    * If there is an ID collision, kill our client, and kill theirs.
    * This may generate 401's, but it ensures that both clients always
    * go, even if the other server refuses to do the right thing.
    */
-  struct Client *target_p;
-  if ((target_p = hash_find_id(parv[8 + does_rhost])))
+  struct Client *target_p = hash_find_id(parv[8 + does_rhost]);
+  if (target_p)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "ID collision on %s(%s <- %s)(both killed)",
@@ -859,10 +861,11 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
     ++ServerStats.is_kill;
     AddFlag(target_p, FLAGS_KILLED);
     exit_client(target_p, "ID Collision");
-    return 0;
+    return;
   }
 
-  if ((target_p = hash_find_client(parv[1])) == NULL)
+  target_p = hash_find_client(parv[1]);
+  if (target_p == NULL)
     uid_from_server(source_p, parc, parv);
   else if (IsUnknown(target_p))
   {
@@ -871,7 +874,6 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
   }
   else if (perform_uid_introduction_collides(source_p, target_p, parc, parv) == true)
     uid_from_server(source_p, parc, parv);
-  return 0;
 }
 
 static struct Message nick_msgtab =
@@ -914,7 +916,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8927 $",
+  .version = "$Revision: 9304 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
