@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_part.c
  * \brief Includes required functions for processing the PART command.
- * \version $Id: m_part.c 8983 2019-05-21 13:18:58Z michael $
+ * \version $Id: m_part.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -51,15 +51,13 @@
  *      - parv[1] = channel name
  *      - parv[2] = part message
  */
-static int
+static void
 m_part(struct Client *source_p, int parc, char *parv[])
 {
   if (EmptyString(parv[1]))
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "PART");
   else
     channel_do_part(source_p, parv[1], parv[2]);
-
-  return 0;
 }
 
 static struct Message part_msgtab =
@@ -89,7 +87,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8983 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
