@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_quit.c
  * \brief Includes required functions for processing the QUIT command.
- * \version $Id: m_quit.c 8918 2019-04-22 09:51:16Z michael $
+ * \version $Id: m_quit.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -45,7 +45,7 @@
  *      - parv[0] = command
  *      - parv[1] = quit message
  */
-static int
+static void
 m_quit(struct Client *source_p, int parc, char *parv[])
 {
   char reason[KICKLEN + 1] = "Quit: ";
@@ -56,7 +56,6 @@ m_quit(struct Client *source_p, int parc, char *parv[])
     strlcpy(reason + 6, parv[1], sizeof(reason) - 6);
 
   exit_client(source_p, reason);
-  return 0;
 }
 
 /*! \brief QUIT command handler
@@ -70,7 +69,7 @@ m_quit(struct Client *source_p, int parc, char *parv[])
  *      - parv[0] = command
  *      - parv[1] = quit message
  */
-static int
+static void
 ms_quit(struct Client *source_p, int parc, char *parv[])
 {
   char reason[KICKLEN + 1] = "";
@@ -79,7 +78,6 @@ ms_quit(struct Client *source_p, int parc, char *parv[])
     strlcpy(reason, parv[1], sizeof(reason));
 
   exit_client(source_p, reason);
-  return 0;
 }
 
 static struct Message quit_msgtab =
@@ -107,7 +105,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8918 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
