@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_server.c
  * \brief Includes required functions for processing the SERVER/SID command.
- * \version $Id: m_server.c 8967 2019-05-18 11:00:34Z michael $
+ * \version $Id: m_server.c 9360 2020-04-29 14:02:24Z michael $
  */
 
 #include "stdinc.h"
@@ -46,6 +46,7 @@
 #include "memory.h"
 #include "modules.h"
 #include "fdlist.h"
+#include "channel.h"
 
 
 /*! Parses server flags to be potentially set
@@ -83,7 +84,7 @@ server_set_flags(struct Client *client_p, const char *flags)
  *                server is CAPAB_TBURST capable
  */
 static void
-server_send_tburst(struct Client *client_p, const struct Channel *chptr)
+server_send_tburst(struct Client *client_p, const struct Channel *channel)
 {
   /*
    * We may also send an empty topic here, but only if topic_time isn't 0,
@@ -98,12 +99,12 @@ server_send_tburst(struct Client *client_p, const struct Channel *chptr)
    * it to their old topic they had before.  Read m_tburst.c:ms_tburst
    * for further information   -Michael
    */
-  if (chptr->topic_time)
+  if (channel->topic_time)
     sendto_one(client_p, ":%s TBURST %ju %s %ju %s :%s", me.id,
-               chptr->creationtime, chptr->name,
-               chptr->topic_time,
-               chptr->topic_info,
-               chptr->topic);
+               channel->creation_time, channel->name,
+               channel->topic_time,
+               channel->topic_info,
+               channel->topic);
 }
 
 /* sendnick_TS()
@@ -190,14 +191,14 @@ server_burst(struct Client *client_p)
 
   DLINK_FOREACH(node, channel_get_list()->head)
   {
-    const struct Channel *chptr = node->data;
+    const struct Channel *channel = node->data;
 
-    if (dlink_list_length(&chptr->members))
+    if (dlink_list_length(&channel->members))
     {
-      channel_send_modes(client_p, chptr);
+      channel_send_modes(client_p, channel);
 
       if (IsCapable(client_p, CAPAB_TBURST))
-        server_send_tburst(client_p, chptr);
+        server_send_tburst(client_p, channel);
     }
   }
 
@@ -214,22 +215,6 @@ server_burst(struct Client *client_p)
 static void
 server_estab(struct Client *client_p)
 {
-  struct MaskItem *conf = NULL;
-  dlink_node *node = NULL;
-
-  if ((conf = find_conf_name(&client_p->connection->confs, client_p->name, CONF_SERVER)) == NULL)
-  {
-    /* This shouldn't happen, better tell the ops... -A1kmm */
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-                         "Warning: lost connect{} block for %s",
-                         client_get_name(client_p, SHOW_IP));
-    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-                         "Warning: lost connect{} block for %s",
-                         client_get_name(client_p, MASK_IP));
-    exit_client(client_p, "Lost connect{} block!");
-    return;
-  }
-
   xfree(client_p->connection->password);
   client_p->connection->password = NULL;
 
@@ -242,6 +227,8 @@ server_estab(struct Client *client_p)
 
   if (IsUnknown(client_p))
   {
+    const struct MaskItem *const conf = client_p->connection->confs.head->data;
+
     sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
 
     sendto_one(client_p, "CAPAB :%s", capab_get(NULL));
@@ -253,12 +240,11 @@ server_estab(struct Client *client_p)
   sendto_one(client_p, ":%s SVINFO %u %u 0 :%ju", me.id, TS_CURRENT, TS_MIN,
              event_base->time.sec_real);
 
-  client_p->servptr = &me;
-
   if (IsDead(client_p))
     return;
 
   SetServer(client_p);
+  client_p->servptr = &me;
 
   dlinkAdd(client_p, &client_p->lnode, &me.serv->server_list);
 
@@ -287,21 +273,21 @@ server_estab(struct Client *client_p)
     AddFlag(client_p, FLAGS_SERVICE);
 
   /* Show the real host/IP to admins */
-  if (tls_isusing(&client_p->connection->fd->ssl))
+  if (tls_isusing(&client_p->connection->fd->tls))
   {
     /* Show the real host/IP to admins */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->ssl),
+                         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->tls),
                          capab_get(client_p));
 
     /* Now show the masked hostname/IP to opers */
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: [TLS: %s] (Capabilities: %s)",
-                         client_get_name(client_p, MASK_IP), tls_get_cipher(&client_p->connection->fd->ssl),
+                         client_get_name(client_p, MASK_IP), tls_get_cipher(&client_p->connection->fd->tls),
                          capab_get(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: [TLS: %s] (Capabilities: %s)",
-         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->ssl),
+         client_get_name(client_p, SHOW_IP), tls_get_cipher(&client_p->connection->fd->tls),
          capab_get(client_p));
   }
   else
@@ -338,6 +324,7 @@ server_estab(struct Client *client_p)
    * up connection this other fragment at the same time, it's
    * a race condition, not the normal way of operation...
    */
+  dlink_node *node;
   DLINK_FOREACH_PREV(node, global_server_list.tail)
   {
     struct Client *target_p = node->data;
@@ -396,7 +383,7 @@ server_set_gecos(struct Client *client_p, const char *info)
 enum
 {
   SERVER_CHECK_OK                  =  0,
-  SERVER_CHECK_NOCONNECT           = -1,
+  SERVER_CHECK_CONNECT_NOT_FOUND   = -1,
   SERVER_CHECK_INVALID_PASSWORD    = -2,
   SERVER_CHECK_INVALID_HOST        = -3,
   SERVER_CHECK_INVALID_CERTIFICATE = -4,
@@ -406,8 +393,7 @@ static int
 server_check(const char *name, struct Client *client_p)
 {
   dlink_node *node;
-  struct MaskItem *server_conf = NULL;
-  int error = SERVER_CHECK_NOCONNECT;
+  int error = SERVER_CHECK_CONNECT_NOT_FOUND;
 
   assert(client_p);
 
@@ -431,16 +417,12 @@ server_check(const char *name, struct Client *client_p)
         if (EmptyString(client_p->certfp) || strcasecmp(client_p->certfp, conf->certfp))
           return SERVER_CHECK_INVALID_CERTIFICATE;
 
-      server_conf = conf;
+      conf_attach(client_p, conf);
+      return SERVER_CHECK_OK;
     }
   }
 
-  if (server_conf == NULL)
-    return error;
-
-  conf_attach(client_p, server_conf);
-
-  return SERVER_CHECK_OK;
+  return error;
 }
 
 /* mr_server()
@@ -457,19 +439,18 @@ server_check(const char *name, struct Client *client_p)
  *  parv[4] = string of flags starting with '+'
  *  parv[5] = serverinfo
  */
-static int
+static void
 mr_server(struct Client *source_p, int parc, char *parv[])
 {
   const char *name = parv[1];
   const char *sid = parc == 6 ? parv[3] : source_p->id; /* TBR: compatibility 'mode' */
-  struct Client *target_p = NULL;
   const char *error = NULL;
   bool warn = true;
 
   if (EmptyString(parv[parc - 1]))
   {
     exit_client(source_p, "No server description supplied");
-    return 0;
+    return;
   }
 
   if (server_valid_name(name) == false)
@@ -481,7 +462,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
           "Unauthorized server connection attempt from %s: Bogus server name "
           "for server %s", client_get_name(source_p, MASK_IP), name);
     exit_client(source_p, "Bogus server name");
-    return 0;
+    return;
   }
 
   if (valid_sid(sid) == false)
@@ -493,7 +474,19 @@ mr_server(struct Client *source_p, int parc, char *parv[])
                          "Link %s introduced server with bogus server ID %s",
                          client_get_name(source_p, MASK_IP), sid);
     exit_client(source_p, "Bogus server ID introduced");
-    return 0;
+    return;
+  }
+
+  if (IsHandshake(source_p) && irccmp(source_p->name, name))
+  {
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Link %s introduced server with mismatching server name %s",
+                         client_get_name(source_p, SHOW_IP), name);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "Link %s introduced server with mismatching server name %s",
+                         client_get_name(source_p, MASK_IP), name);
+    exit_client(source_p, "Mismatching server name introduced");
+    return;
   }
 
   /*
@@ -502,7 +495,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
    */
   switch (server_check(name, source_p))
   {
-    case SERVER_CHECK_NOCONNECT:
+    case SERVER_CHECK_CONNECT_NOT_FOUND:
       error = "No connect {} block";
       warn = ConfigGeneral.warn_no_connect_block != 0;
       break;
@@ -530,9 +523,10 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     }
 
     exit_client(source_p, error);
-    return 0;
+    return;
   }
 
+  struct Client *target_p;
   if ((target_p = hash_find_server(name)))
   {
     /* This link is trying feed me a server that I already have
@@ -552,7 +546,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
                          "Attempt to re-introduce server %s from %s",
                          name, client_get_name(source_p, MASK_IP));
     exit_client(source_p, "Server already exists");
-    return 0;
+    return;
   }
 
   if ((target_p = hash_find_id(source_p->id)))
@@ -566,7 +560,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
                          name, source_p->id,
                          client_get_name(source_p, MASK_IP));
     exit_client(source_p, "Server ID already exists");
-    return 0;
+    return;
   }
 
   /* XXX If somehow there is a connect in progress and
@@ -593,7 +587,6 @@ mr_server(struct Client *source_p, int parc, char *parv[])
 
   source_p->hopcount = atoi(parv[2]);
   server_estab(source_p);
-  return 0;
 }
 
 /* ms_sid()
@@ -611,19 +604,17 @@ mr_server(struct Client *source_p, int parc, char *parv[])
  *  parv[4] = string of flags starting with '+'
  *  parv[5] = serverinfo
  */
-static int
+static void
 ms_sid(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p = NULL;
-
   /* Just to be sure -A1kmm. */
   if (!IsServer(source_p))
-    return 0;
+    return;
 
   if (EmptyString(parv[parc - 1]))
   {
     exit_client(source_p->from, "No server description supplied");
-    return 0;
+    return;
   }
 
   if (server_valid_name(parv[1]) == false)
@@ -635,7 +626,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Link %s introduced server with bogus server name %s",
                          client_get_name(source_p->from, MASK_IP), parv[1]);
     exit_client(source_p->from, "Bogus server name introduced");
-    return 0;
+    return;
   }
 
   if (valid_sid(parv[3]) == false)
@@ -647,10 +638,11 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Link %s introduced server with bogus server ID %s",
                          client_get_name(source_p->from, MASK_IP), parv[3]);
     exit_client(source_p->from, "Bogus server ID introduced");
-    return 0;
+    return;
   }
 
   /* collision on SID? */
+  struct Client *target_p;
   if ((target_p = hash_find_id(parv[3])))
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
@@ -660,7 +652,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Link %s cancelled, server ID %s already exists",
                          client_get_name(source_p->from, MASK_IP), parv[3]);
     exit_client(source_p->from, "Link cancelled, server ID already exists");
-    return 0;
+    return;
   }
 
   /* collision on name? */
@@ -673,7 +665,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Link %s cancelled, server %s already exists",
                          client_get_name(source_p->from, MASK_IP), parv[1]);
     exit_client(source_p->from, "Server exists");
-    return 0;
+    return;
   }
 
   /* XXX If somehow there is a connect in progress and
@@ -745,7 +737,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Non-Hub link %s introduced %s.",
                          client_get_name(source_p->from, MASK_IP), parv[1]);
     exit_client(source_p, "No matching hub_mask.");
-    return 0;
+    return;
   }
 
   /* Check for the new server being leafed behind this HUB */
@@ -759,7 +751,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
                          "Link %s introduced leafed server %s.",
                          client_get_name(source_p->from, MASK_IP), parv[1]);
     exit_client(source_p->from, "Leafed server.");
-    return 0;
+    return;
   }
 
   target_p = client_make(source_p->from);
@@ -795,7 +787,6 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   sendto_realops_flags(UMODE_EXTERNAL, L_ALL, SEND_NOTICE,
                        "Server %s being introduced by %s",
                        target_p->name, source_p->name);
-  return 0;
 }
 
 static struct Message server_msgtab =
@@ -838,7 +829,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8967 $",
+  .version = "$Revision: 9360 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
