@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,12 +21,13 @@
 
 /*! \file m_sjoin.c
  * \brief Includes required functions for processing the SJOIN command.
- * \version $Id: m_sjoin.c 8787 2019-01-16 18:47:10Z michael $
+ * \version $Id: m_sjoin.c 9288 2020-02-23 08:38:34Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
 #include "channel.h"
+#include "channel_invite.h"
 #include "channel_mode.h"
 #include "client.h"
 #include "hash.h"
@@ -59,14 +60,13 @@ static void remove_ban_list(struct Channel *, struct Client *, dlink_list *, cha
  * incoming modes or undo the existing ones or merge them, and JOIN
  * all the specified users while sending JOIN/MODEs to local clients
  */
-static int
+static void
 ms_sjoin(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *chptr = NULL;
+  struct Channel *channel = NULL;
   struct Client  *target_p = NULL;
   uintmax_t newts;
   uintmax_t oldts;
-  uintmax_t tstosend;
   struct Mode mode, *oldmode;
   int            args = 0;
   bool           isnew = false;
@@ -94,14 +94,14 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   unsigned int pargs = 0;
 
   if (!IsServer(source_p))
-    return 0;
+    return;
 
   if (channel_check_name(parv[2], false) == false)
   {
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
                          "*** Too long or invalid channel name from %s(via %s): %s",
                          source_p->name, source_p->from->name, parv[2]);
-    return 0;
+    return;
   }
 
   pargs = 0;
@@ -120,7 +120,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
         ++args;
 
         if (parc < 5 + args)
-          return 0;
+          return;
         break;
 
       case 'l':
@@ -128,7 +128,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
         ++args;
 
         if (parc < 5 + args)
-          return 0;
+          return;
         break;
 
       default:
@@ -142,41 +142,38 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if ((chptr = hash_find_channel(parv[2])) == NULL)
+  if ((channel = hash_find_channel(parv[2])) == NULL)
   {
     isnew = true;
-    chptr = channel_make(parv[2]);
+    channel = channel_make(parv[2]);
   }
 
-  oldts = chptr->creationtime;
-  oldmode = &chptr->mode;
+  oldts = channel->creation_time;
+  oldmode = &channel->mode;
 
   if (newts == 0 && isnew == false && oldts)
   {
-    sendto_channel_local(NULL, chptr, 0, 0, 0,
+    sendto_channel_local(NULL, channel, 0, 0, 0,
                          ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to 0",
-                         me.name, chptr->name, chptr->name, oldts);
+                         me.name, channel->name, channel->name, oldts);
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Server %s changing TS on %s from %ju to 0",
-                         source_p->name, chptr->name, oldts);
+                         source_p->name, channel->name, oldts);
   }
 
   if (isnew == true)
-    chptr->creationtime = tstosend = newts;
+    channel->creation_time = newts;
   else if (newts == 0 || oldts == 0)
-    chptr->creationtime = tstosend = 0;
+    channel->creation_time = 0;
   else if (newts == oldts)
-    tstosend = oldts;
+    ;
   else if (newts < oldts)
   {
     keep_our_modes = false;
-    chptr->creationtime = tstosend = newts;
+    channel->creation_time = newts;
   }
   else
-  {
     keep_new_modes = false;
-    tstosend = oldts;
-  }
 
   if (keep_new_modes == false)
     mode = *oldmode;
@@ -191,36 +188,36 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   }
 
   set_final_mode(&mode, oldmode, modebuf, parabuf);
-  chptr->mode = mode;
+  channel->mode = mode;
 
   /* Lost the TS, other side wins, so remove modes on this side */
   if (keep_our_modes == false)
   {
     /* Update channel name to be the correct case */
     if (isnew == false)
-      strlcpy(chptr->name, parv[2], sizeof(chptr->name));
+      strlcpy(channel->name, parv[2], sizeof(channel->name));
 
-    remove_our_modes(chptr, source_p);
+    remove_our_modes(channel, source_p);
 
-    remove_ban_list(chptr, source_p, &chptr->banlist, 'b');
-    remove_ban_list(chptr, source_p, &chptr->exceptlist, 'e');
-    remove_ban_list(chptr, source_p, &chptr->invexlist, 'I');
+    remove_ban_list(channel, source_p, &channel->banlist, 'b');
+    remove_ban_list(channel, source_p, &channel->exceptlist, 'e');
+    remove_ban_list(channel, source_p, &channel->invexlist, 'I');
 
-    clear_ban_cache_list(&chptr->members_local);
-    clear_invite_list(&chptr->invites);
+    clear_ban_cache_list(&channel->members_local);
+    invite_clear_list(&channel->invites);
 
-    if (chptr->topic[0])
+    if (channel->topic[0])
     {
-      channel_set_topic(chptr, "", "", 0, false);
-      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :",
+      channel_set_topic(channel, "", "", 0, false);
+      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s TOPIC %s :",
                            (IsHidden(source_p) ||
                            ConfigServerHide.hide_servers) ?
-                           me.name : source_p->name, chptr->name);
+                           me.name : source_p->name, channel->name);
     }
 
-    sendto_channel_local(NULL, chptr, 0, 0, 0,
+    sendto_channel_local(NULL, channel, 0, 0, 0,
                          ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to %ju",
-                         me.name, chptr->name, chptr->name,
+                         me.name, channel->name, channel->name,
                          oldts, newts);
   }
 
@@ -228,12 +225,12 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   {
     /* This _SHOULD_ be to ALL_MEMBERS
      * It contains only +imnpstlk, etc */
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s %s",
-                         servername, chptr->name, modebuf, parabuf);
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s %s",
+                         servername, channel->name, modebuf, parabuf);
   }
 
   if (*parv[3] != '0' && keep_new_modes == true)
-    channel_modes(chptr, source_p, modebuf, parabuf);
+    channel_modes(channel, source_p, modebuf, parabuf);
   else
   {
     modebuf[0] = '0';
@@ -241,8 +238,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   }
 
   buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %ju %s %s %s:",
-                    source_p->id, tstosend,
-                    chptr->name, modebuf, parabuf);
+                    source_p->id, channel->creation_time,
+                    channel->name, modebuf, parabuf);
   uid_ptr = uid_buf + buflen;
 
   /*
@@ -254,7 +251,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Long SJOIN from server: %s(via %s) (ignored)",
                          source_p->name, source_p->from->name);
-    return 0;
+    return;
   }
 
   char *mbuf = modebuf;
@@ -342,26 +339,26 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
       sendto_server(source_p, 0, 0, "%s", uid_buf);
 
       buflen = snprintf(uid_buf, sizeof(uid_buf), ":%s SJOIN %ju %s %s %s:",
-                        source_p->id, tstosend,
-                        chptr->name, modebuf, parabuf);
+                        source_p->id, channel->creation_time,
+                        channel->name, modebuf, parabuf);
       uid_ptr = uid_buf + buflen;
     }
 
     uid_ptr += sprintf(uid_ptr, "%s%s ", uid_prefix, target_p->id);
 
-    if (!IsMember(target_p, chptr))
+    if (!IsMember(target_p, channel))
     {
-      add_user_to_channel(chptr, target_p, fl, have_many_uids == false);
+      add_user_to_channel(channel, target_p, fl, have_many_uids == false);
 
-      sendto_channel_local(NULL, chptr, 0, CAP_EXTENDED_JOIN, 0, ":%s!%s@%s JOIN %s %s :%s",
+      sendto_channel_local(NULL, channel, 0, CAP_EXTENDED_JOIN, 0, ":%s!%s@%s JOIN %s %s :%s",
                            target_p->name, target_p->username,
-                           target_p->host, chptr->name, target_p->account, target_p->info);
-      sendto_channel_local(NULL, chptr, 0, 0, CAP_EXTENDED_JOIN, ":%s!%s@%s JOIN :%s",
+                           target_p->host, channel->name, target_p->account, target_p->info);
+      sendto_channel_local(NULL, channel, 0, 0, CAP_EXTENDED_JOIN, ":%s!%s@%s JOIN :%s",
                            target_p->name, target_p->username,
-                           target_p->host, chptr->name);
+                           target_p->host, channel->name);
 
       if (target_p->away[0])
-        sendto_channel_local(target_p, chptr, 0, CAP_AWAY_NOTIFY, 0,
+        sendto_channel_local(target_p, channel, 0, CAP_AWAY_NOTIFY, 0,
                              ":%s!%s@%s AWAY :%s",
                              target_p->name, target_p->username,
                              target_p->host, target_p->away);
@@ -392,8 +389,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;  /* ready for next */
         }
 
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, chptr->name, modebuf, sendbuf);
+        sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, channel->name, modebuf, sendbuf);
         mbuf = modebuf;
         *mbuf++ = '+';
 
@@ -418,8 +415,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;
         }
 
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, chptr->name, modebuf, sendbuf);
+        sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, channel->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -445,8 +442,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           sptr += slen;
         }
 
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
-                             servername, chptr->name, modebuf, sendbuf);
+        sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
+                             servername, channel->name, modebuf, sendbuf);
 
         mbuf = modebuf;
         *mbuf++ = '+';
@@ -493,8 +490,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
       sptr += slen;
     }
 
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
-                         servername, chptr->name, modebuf, sendbuf);
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
+                         servername, channel->name, modebuf, sendbuf);
   }
 
   /*
@@ -504,17 +501,16 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
    * and leaving us with a channel formed just as the client parts.
    * - Dianora
    */
-  if (dlink_list_length(&chptr->members) == 0 && isnew == true)
+  if (dlink_list_length(&channel->members) == 0 && isnew == true)
   {
-    channel_free(chptr);
-    return 0;
+    channel_free(channel);
+    return;
   }
 
   if (*parv[4 + args] == '\0')
-    return 0;
+    return;
 
   sendto_server(source_p, 0, 0, "%s", uid_buf);
-  return 0;
 }
 
 /* set_final_mode
@@ -586,11 +582,11 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode, char *mbuf, char *pbuf)
  *		  chanop modes etc., this side lost the TS.
  */
 static void
-remove_our_modes(struct Channel *chptr, struct Client *source_p)
+remove_our_modes(struct Channel *channel, struct Client *source_p)
 {
-  remove_a_mode(chptr, source_p, CHFL_CHANOP, 'o');
-  remove_a_mode(chptr, source_p, CHFL_HALFOP, 'h');
-  remove_a_mode(chptr, source_p, CHFL_VOICE, 'v');
+  remove_a_mode(channel, source_p, CHFL_CHANOP, 'o');
+  remove_a_mode(channel, source_p, CHFL_HALFOP, 'h');
+  remove_a_mode(channel, source_p, CHFL_VOICE, 'v');
 }
 
 /* remove_a_mode()
@@ -603,7 +599,7 @@ remove_our_modes(struct Channel *chptr, struct Client *source_p)
  * side effects	- remove ONE mode from all members of a channel
  */
 static void
-remove_a_mode(struct Channel *chptr, struct Client *source_p,
+remove_a_mode(struct Channel *channel, struct Client *source_p,
              int mask, char flag)
 {
   dlink_node *node = NULL;
@@ -618,16 +614,16 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
   *mbuf++ = '-';
   *sp = '\0';
 
-  DLINK_FOREACH(node, chptr->members.head)
+  DLINK_FOREACH(node, channel->members.head)
   {
-    struct Membership *member = node->data;
+    struct ChannelMember *member = node->data;
 
     if ((member->flags & mask) == 0)
       continue;
 
     member->flags &= ~mask;
 
-    lpara[count++] = member->client_p->name;
+    lpara[count++] = member->client->name;
 
     *mbuf++ = flag;
 
@@ -640,10 +636,10 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
       }
 
       *mbuf = '\0';
-      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
                            (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
                            me.name : source_p->name,
-                           chptr->name, lmodebuf, sendbuf);
+                           channel->name, lmodebuf, sendbuf);
       mbuf = lmodebuf;
       *mbuf++ = '-';
       count = 0;
@@ -662,10 +658,10 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
       sp += l;
     }
 
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s %s%s",
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s %s%s",
                          (IsHidden(source_p) || ConfigServerHide.hide_servers) ?
                          me.name : source_p->name,
-                         chptr->name, lmodebuf, sendbuf);
+                         channel->name, lmodebuf, sendbuf);
   }
 }
 
@@ -676,7 +672,7 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
  * side effects	- given ban list is removed, modes are sent to local clients
  */
 static void
-remove_ban_list(struct Channel *chptr, struct Client *source_p, dlink_list *list, char c)
+remove_ban_list(struct Channel *channel, struct Client *source_p, dlink_list *list, char c)
 {
   dlink_node *node, *node_next;
   char modebuf[IRCD_BUFSIZE];
@@ -690,21 +686,21 @@ remove_ban_list(struct Channel *chptr, struct Client *source_p, dlink_list *list
     return;
 
   cur_len = mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s -",
-                            source_p->name, chptr->name);
+                            source_p->name, channel->name);
   mbuf = modebuf + mlen;
   pbuf = parabuf;
 
   DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
     struct Ban *ban = node->data;
-    int plen = ban->len + 4;  /* another +b and "!@ " */
+    int plen = ban->banstr_len + 2;  /* +2 = b and space */
 
     if (count >= MAXMODEPARAMS ||
         (cur_len + 1 /* space between */ + (plen - 1)) > IRCD_BUFSIZE - 2)
     {
       /* NUL-terminate and remove trailing space */
       *mbuf = *(pbuf - 1) = '\0';
-      sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
+      sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
 
       cur_len = mlen;
       mbuf = modebuf + mlen;
@@ -714,14 +710,14 @@ remove_ban_list(struct Channel *chptr, struct Client *source_p, dlink_list *list
 
     *mbuf++ = c;
     cur_len += plen;
-    pbuf += sprintf(pbuf, "%s!%s@%s ", ban->name, ban->user, ban->host);
+    pbuf += sprintf(pbuf, "%s ", ban->banstr);
     ++count;
 
     remove_ban(ban, list);
   }
 
   *mbuf = *(pbuf - 1) = '\0';
-  sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
+  sendto_channel_local(NULL, channel, 0, 0, 0, "%s %s", modebuf, parabuf);
 }
 
 static struct Message sjoin_msgtab =
@@ -750,7 +746,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8787 $",
+  .version = "$Revision: 9288 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
