@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tmode.c
  * \brief Includes required functions for processing the TMODE command.
- * \version $Id: m_tmode.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_tmode.c 9364 2020-04-30 19:24:10Z michael $
  */
 
 #include "stdinc.h"
@@ -49,24 +49,22 @@
  *      - parv[2] = channel name
  *      - parv[3] = modes to be added or removed
  */
-static int
+static void
 ms_tmode(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *chptr;
-
   assert(!MyClient(source_p));
 
-  if ((chptr = hash_find_channel(parv[2])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[2]);
+  if (channel == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[2]);
-    return 0;
+    return;
   }
 
-  if (strtoumax(parv[1], NULL, 10) > chptr->creationtime)
-    return 0;
+  if (strtoumax(parv[1], NULL, 10) > channel->creation_time)
+    return;
 
-  channel_mode_set(source_p, chptr, NULL, parc - 3, parv + 3);
-  return 0;
+  channel_mode_set(source_p, channel, NULL, parc - 3, parv + 3);
 }
 
 static struct Message tmode_msgtab =
@@ -95,7 +93,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9364 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_core = true
