@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2019 ircd-hybrid development team
+ *  Copyright (c) 2014-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_opme.c
  * \brief Includes required functions for processing the OPME command.
- * \version $Id: m_opme.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_opme.c 9233 2020-01-31 17:31:08Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,7 @@
 #include "irc_string.h"
 #include "parse.h"
 #include "modules.h"
+#include "channel.h"
 #include "channel_mode.h"
 #include "conf.h"
 
@@ -50,61 +51,60 @@
  *      - parv[0] = command
  *      - parv[1] = channel name
  */
-static int
+static void
 mo_opme(struct Client *source_p, int parc, char *parv[])
 {
   const char *const name = parv[1];
-  struct Channel *chptr = NULL;
-  struct Membership *member = NULL;
+  struct Channel *channel = NULL;
+  struct ChannelMember *member = NULL;
   dlink_node *node = NULL;
 
   if (EmptyString(name))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "OPME");
-    return 0;
+    return;
   }
 
   if (!HasOFlag(source_p, OPER_FLAG_OPME))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "opme");
-    return 0;
+    return;
   }
 
-  if ((chptr = hash_find_channel(name)) == NULL)
+  if ((channel = hash_find_channel(name)) == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, name);
-    return 0;
+    return;
   }
 
-  if ((member = find_channel_link(source_p, chptr)) == NULL)
+  if ((member = find_channel_link(source_p, channel)) == NULL)
   {
-    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
-    return 0;
+    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
+    return;
   }
 
-  DLINK_FOREACH(node, chptr->members.head)
+  DLINK_FOREACH(node, channel->members.head)
   {
-    if (((struct Membership *)node->data)->flags & CHFL_CHANOP)
+    if (((struct ChannelMember *)node->data)->flags & CHFL_CHANOP)
     {
       sendto_one_notice(source_p, &me, ":Cannot use OPME on %s: channel is not opless",
-                        chptr->name);
-      return 0;
+                        channel->name);
+      return;
     }
   }
 
   ilog(LOG_TYPE_IRCD, "%s used OPME on channel %s",
-       get_oper_name(source_p), chptr->name);
+       get_oper_name(source_p), channel->name);
   sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_GLOBAL, "from %s: %s used OPME on channel %s",
-                       me.name, get_oper_name(source_p), chptr->name);
+                       me.name, get_oper_name(source_p), channel->name);
   sendto_server(NULL, 0, 0, ":%s GLOBOPS :%s used OPME on channel %s",
-                me.id, get_oper_name(source_p), chptr->name);
+                me.id, get_oper_name(source_p), channel->name);
 
   AddMemberFlag(member, CHFL_CHANOP);
-  sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s +o %s",
-                       me.name, chptr->name, source_p->name);
-  sendto_server(NULL, 0, 0, ":%s TMODE %ju %s +o %s", me.id, chptr->creationtime,
-                chptr->name, source_p->id);
-  return 0;
+  sendto_channel_local(NULL, channel, 0, 0, 0, ":%s MODE %s +o %s",
+                       me.name, channel->name, source_p->name);
+  sendto_server(NULL, 0, 0, ":%s TMODE %ju %s +o %s", me.id, channel->creation_time,
+                channel->name, source_p->id);
 }
 
 static struct Message opme_msgtab =
@@ -133,7 +133,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9233 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
