@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_away.c
  * \brief Includes required functions for processing the AWAY command.
- * \version $Id: m_away.c 8973 2019-05-18 18:23:27Z michael $
+ * \version $Id: m_away.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -104,13 +104,12 @@ do_away(struct Client *source_p, const char *message)
  *      - parv[0] = command
  *      - parv[1] = away message
  */
-static int
+static void
 m_away(struct Client *source_p, int parc, char *parv[])
 {
   const char *const message = parv[1];
 
   do_away(source_p, message);
-  return 0;
 }
 
 static struct Message away_msgtab =
@@ -140,7 +139,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8973 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
