@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2019 ircd-hybrid development team
+ *  Copyright (c) 1998-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_capab.c
  * \brief Includes required functions for processing the CAPAB command.
- * \version $Id: m_capab.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_capab.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -43,7 +43,7 @@
  *      - parv[0] = command
  *      - parv[1] = space-separated list of capabilities
  */
-static int
+static void
 mr_capab(struct Client *source_p, int parc, char *parv[])
 {
   unsigned int cap = 0;
@@ -53,8 +53,6 @@ mr_capab(struct Client *source_p, int parc, char *parv[])
                    s = strtok_r(NULL,    " ", &p))
     if ((cap = capab_find(s)))
       SetCapable(source_p, cap);
-
-  return 0;
 }
 
 static struct Message capab_msgtab =
@@ -83,7 +81,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
