@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2019 ircd-hybrid development team
+ *  Copyright (c) 2000-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_eob.c
  * \brief Includes required functions for processing the EOB command.
- * \version $Id: m_eob.c 8918 2019-04-22 09:51:16Z michael $
+ * \version $Id: m_eob.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -43,7 +43,7 @@
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  */
-static int
+static void
 ms_eob(struct Client *source_p, int parc, char *parv[])
 {
   assert(IsServer(source_p));
@@ -55,8 +55,6 @@ ms_eob(struct Client *source_p, int parc, char *parv[])
 
   AddFlag(source_p, FLAGS_EOB);
   sendto_server(source_p, 0, 0, ":%s EOB", source_p->id);
-
-  return 0;
 }
 
 static struct Message eob_msgtab =
@@ -84,7 +82,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8918 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
