@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_hash.c
  * \brief Includes required functions for processing the HASH command.
- * \version $Id: m_hash.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_hash.c 9233 2020-01-31 17:31:08Z michael $
  */
 
 #include "stdinc.h"
@@ -33,6 +33,7 @@
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
+#include "channel.h"
 
 
 /*! \brief HASH command handler
@@ -45,7 +46,7 @@
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  */
-static int
+static void
 mo_hash(struct Client *source_p, int parc, char *parv[])
 {
   unsigned int i = 0;
@@ -117,7 +118,6 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_notice(source_p, &me, ":Id: entries: %u buckets: %u "
                     "max chain: %u", count, buckets, max_chain);
-  return 0;
 }
 
 static struct Message hash_msgtab =
@@ -145,7 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9233 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
