@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2019 ircd-hybrid development team
+ *  Copyright (c) 1999-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_help.c
  * \brief Includes required functions for processing the HELP command.
- * \version $Id: m_help.c 8902 2019-04-21 20:41:04Z michael $
+ * \version $Id: m_help.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -121,7 +121,7 @@ do_help(struct Client *source_p, char *topic)
  *      - parv[0] = command
  *      - parv[1] = help topic
  */
-static int
+static void
 m_help(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
@@ -129,13 +129,12 @@ m_help(struct Client *source_p, int parc, char *parv[])
   if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "HELP");
-    return 0;
+    return;
   }
 
   last_used = event_base->time.sec_monotonic;
 
   do_help(source_p, parv[1]);
-  return 0;
 }
 
 /*! \brief HELP command handler
@@ -149,11 +148,10 @@ m_help(struct Client *source_p, int parc, char *parv[])
  *      - parv[0] = command
  *      - parv[1] = help topic
  */
-static int
+static void
 mo_help(struct Client *source_p, int parc, char *parv[])
 {
   do_help(source_p, parv[1]);
-  return 0;
 }
 
 static struct Message help_msgtab =
@@ -181,7 +179,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8902 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
