@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 8962 2019-05-11 21:04:34Z michael $
+ * \version $Id: m_info.c 9320 2020-03-08 12:33:15Z michael $
  */
 
 #include "stdinc.h"
@@ -50,8 +50,7 @@ struct InfoStruct
     OUTPUT_STRING_PTR,  /* Output option as %s w/out deference */
     OUTPUT_DECIMAL,  /* Output option as decimal (%d) */
     OUTPUT_BOOLEAN,  /* Output option as "ON" or "OFF" */
-    OUTPUT_BOOLEAN_YN,  /* Output option as "YES" or "NO" */
-    OUTPUT_BOOLEAN2  /* Output option as "YES/NO/MASKED" */
+    OUTPUT_BOOLEAN_YN  /* Output option as "YES" or "NO" */
   } output_type;  /* Type of output. See enum above */
 
   const void *option;  /* Pointer reference to the value */
@@ -152,6 +151,12 @@ static const struct InfoStruct info_table[] =
     &ConfigLog.use_logging,
     "Enable logging"
   },
+  {
+    "enable_extbans",
+    OUTPUT_BOOLEAN_YN,
+    &ConfigChannel.enable_extbans,
+    "Whether or not to enable extbans"
+  },
   {
     "disable_fake_channels",
     OUTPUT_BOOLEAN_YN,
@@ -466,13 +471,13 @@ static const struct InfoStruct info_table[] =
   },
   {
     "stats_i_oper_only",
-    OUTPUT_BOOLEAN2,
+    OUTPUT_BOOLEAN_YN,
     &ConfigGeneral.stats_i_oper_only,
     "STATS I output is only shown to operators"
   },
   {
     "stats_k_oper_only",
-    OUTPUT_BOOLEAN2,
+    OUTPUT_BOOLEAN_YN,
     &ConfigGeneral.stats_k_oper_only,
     "STATS K output is only shown to operators"
   },
@@ -551,7 +556,7 @@ static const char *infotext[] =
   "ircd-hybrid --",
   "Based on the original code written by Jarkko Oikarinen",
   "Copyright (c) 1988-1991 University of Oulu, Computing Center",
-  "Copyright (c) 1997-2019 ircd-hybrid development team",
+  "Copyright (c) 1997-2020 ircd-hybrid development team",
   "",
   "This program is free software; you can redistribute it and/or",
   "modify it under the terms of the GNU General Public License as",
@@ -699,17 +704,6 @@ send_conf_options(struct Client *source_p)
                            iptr->desc ? iptr->desc : "<none>");
         break;
       }
-
-      case OUTPUT_BOOLEAN2:
-      {
-        const unsigned int option = *((const unsigned int *const)iptr->option);
-
-        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
-                           ":%-30s %-5s [%s]",
-                           iptr->name, option ? ((option == 1) ? "MASK" : "YES") : "NO",
-                           iptr->desc ? iptr->desc : "<none>");
-        break;
-      }
     }
   }
 
@@ -764,7 +758,7 @@ send_info_text(struct Client *source_p)
  *      - parv[0] = command
  *      - parv[1] = nickname/servername
  */
-static int
+static void
 m_info(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
@@ -772,17 +766,16 @@ m_info(struct Client *source_p, int parc, char *parv[])
   if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "INFO");
-    return 0;
+    return;
   }
 
   last_used = event_base->time.sec_monotonic;
 
   if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
-      return 0;
+      return;
 
   send_info_text(source_p);
-  return 0;
 }
 
 /*! \brief INFO command handler
@@ -796,14 +789,13 @@ m_info(struct Client *source_p, int parc, char *parv[])
  *      - parv[0] = command
  *      - parv[1] = nickname/servername
  */
-static int
+static void
 ms_info(struct Client *source_p, int parc, char *parv[])
 {
   if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
-    return 0;
+    return;
 
   send_info_text(source_p);
-  return 0;
 }
 
 static struct Message info_msgtab =
@@ -831,7 +823,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8962 $",
+  .version = "$Revision: 9320 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
