@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2019 ircd-hybrid development team
+ *  Copyright (c) 1998-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_knock.c
  * \brief Includes required functions for processing the KNOCK command.
- * \version $Id: m_knock.c 8918 2019-04-22 09:51:16Z michael $
+ * \version $Id: m_knock.c 9199 2020-01-23 17:49:06Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,7 @@
  *      - parv[0] = command
  *      - parv[1] = channel name
  */
-static int
+static void
 m_knock(struct Client *source_p, int parc, char *parv[])
 {
   const char *const name = parv[1];
@@ -61,29 +61,29 @@ m_knock(struct Client *source_p, int parc, char *parv[])
   if (EmptyString(name))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "KNOCK");
-    return 0;
+    return;
   }
 
-  struct Channel *chptr;
-  if ((chptr = hash_find_channel(name)) == NULL)
+  struct Channel *channel = hash_find_channel(name);
+  if (channel == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, name);
-    return 0;
+    return;
   }
 
   /* Normal channel, just be sure they aren't on it. */
-  if (IsMember(source_p, chptr))
+  if (IsMember(source_p, channel))
   {
-    sendto_one_numeric(source_p, &me, ERR_KNOCKONCHAN, chptr->name);
-    return 0;
+    sendto_one_numeric(source_p, &me, ERR_KNOCKONCHAN, channel->name);
+    return;
   }
 
-  if (!((chptr->mode.mode & MODE_INVITEONLY) || chptr->mode.key[0] ||
-        (chptr->mode.limit && dlink_list_length(&chptr->members) >=
-         chptr->mode.limit)))
+  if (!((channel->mode.mode & MODE_INVITEONLY) || channel->mode.key[0] ||
+        (channel->mode.limit && dlink_list_length(&channel->members) >=
+         channel->mode.limit)))
   {
-    sendto_one_numeric(source_p, &me, ERR_CHANOPEN, chptr->name);
-    return 0;
+    sendto_one_numeric(source_p, &me, ERR_CHANOPEN, channel->name);
+    return;
   }
 
   if (MyClient(source_p))
@@ -91,10 +91,10 @@ m_knock(struct Client *source_p, int parc, char *parv[])
     /*
      * Don't allow a knock if the user is banned, or the channel is private.
      */
-    if (PrivateChannel(chptr) || is_banned(chptr, source_p) == true)
+    if (PrivateChannel(channel) || is_banned(channel, source_p) == true)
     {
-      sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN, chptr->name);
-      return 0;
+      sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN, channel->name);
+      return;
     }
 
     if ((source_p->connection->knock.last_attempt + ConfigChannel.knock_client_time) < event_base->time.sec_monotonic)
@@ -102,33 +102,32 @@ m_knock(struct Client *source_p, int parc, char *parv[])
 
     if (source_p->connection->knock.count > ConfigChannel.knock_client_count)
     {
-      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->name, "user");
-      return 0;
+      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, channel->name, "user");
+      return;
     }
 
-    if ((chptr->last_knock + ConfigChannel.knock_delay_channel) > event_base->time.sec_monotonic)
+    if ((channel->last_knock_time + ConfigChannel.knock_delay_channel) > event_base->time.sec_monotonic)
     {
-      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->name, "channel");
-      return 0;
+      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, channel->name, "channel");
+      return;
     }
 
     source_p->connection->knock.last_attempt = event_base->time.sec_monotonic;
     source_p->connection->knock.count++;
 
-    sendto_one_numeric(source_p, &me, RPL_KNOCKDLVR, chptr->name);
+    sendto_one_numeric(source_p, &me, RPL_KNOCKDLVR, channel->name);
   }
 
-  chptr->last_knock = event_base->time.sec_monotonic;
-  sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, 0,
+  channel->last_knock_time = event_base->time.sec_monotonic;
+  sendto_channel_local(NULL, channel, CHFL_CHANOP | CHFL_HALFOP, 0, 0,
                        ":%s NOTICE %%%s :KNOCK: %s (%s [%s@%s] has asked for an invite)",
-                       me.name, chptr->name, chptr->name,
+                       me.name, channel->name, channel->name,
                        source_p->name,
                        source_p->username,
                        source_p->host);
 
   sendto_server(source_p, CAPAB_KNOCK, 0, ":%s KNOCK %s",
-                source_p->id, chptr->name);
-  return 0;
+                source_p->id, channel->name);
 }
 
 static struct Message knock_msgtab =
@@ -161,7 +160,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8918 $",
+  .version = "$Revision: 9199 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
