@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_list.c
  * \brief Includes required functions for processing the LIST command.
- * \version $Id: m_list.c 8927 2019-04-22 11:08:47Z michael $
+ * \version $Id: m_list.c 9334 2020-04-18 16:18:49Z michael $
  */
 
 #include "stdinc.h"
@@ -60,10 +60,10 @@ do_list(struct Client *source_p, char *arg)
 
   if (!EmptyString(arg))
   {
-    dlink_list *list = NULL;
+    dlink_list *list;
     char *opt, *save = NULL;
     bool error = false;
-    int i = 0;
+    int i;
 
     for (opt = strtok_r(arg,  ",", &save); opt;
          opt = strtok_r(NULL, ",", &save))
@@ -175,11 +175,10 @@ do_list(struct Client *source_p, char *arg)
  *      - parv[0] = command
  *      - parv[1] = channel name/list options
  */
-static int
+static void
 m_list(struct Client *source_p, int parc, char *parv[])
 {
   do_list(source_p, parv[1]);
-  return 0;
 }
 
 static struct Message list_msgtab =
@@ -211,7 +210,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8927 $",
+  .version = "$Revision: 9334 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
