@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2019 ircd-hybrid development team
+ *  Copyright (c) 2001-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_map.c
  * \brief Includes required functions for processing the MAP command.
- * \version $Id: m_map.c 8902 2019-04-21 20:41:04Z michael $
+ * \version $Id: m_map.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -143,25 +143,27 @@ do_map(struct Client *source_p)
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  */
-static int
+static void
 m_map(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
   if (ConfigServerHide.flatten_links)
-    return m_not_oper(source_p, parc, parv);
+  {
+    m_not_oper(source_p, parc, parv);
+    return;
+  }
 
   if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "MAP");
-    return 0;
+    return;
   }
 
   last_used = event_base->time.sec_monotonic;
 
   do_map(source_p);
   sendto_one_numeric(source_p, &me, RPL_MAPEND);
-  return 0;
 }
 
 /*! \brief MAP command handler
@@ -174,12 +176,11 @@ m_map(struct Client *source_p, int parc, char *parv[])
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  */
-static int
+static void
 mo_map(struct Client *source_p, int parc, char *parv[])
 {
   do_map(source_p);
   sendto_one_numeric(source_p, &me, RPL_MAPEND);
-  return 0;
 }
 
 static struct Message map_msgtab =
@@ -207,7 +208,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8902 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
