@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2019 ircd-hybrid development team
+ *  Copyright (c) 2000-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_module.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -197,11 +197,11 @@ struct ModuleStruct
 
 static const struct ModuleStruct module_cmd_table[] =
 {
-  { "LOAD",   module_load,   true  },
-  { "UNLOAD", module_unload, true  },
-  { "RELOAD", module_reload, true  },
-  { "LIST",   module_list,   false },
-  { NULL,     NULL,          false }
+  { .cmd = "LOAD", .handler = module_load, .arg_required = true },
+  { .cmd = "UNLOAD", .handler = module_unload, .arg_required = true },
+  { .cmd = "RELOAD", .handler = module_reload, .arg_required = true },
+  { .cmd = "LIST", .handler = module_list },
+  { .cmd = NULL }
 };
 
 /*! \brief MODULE command handler
@@ -216,7 +216,7 @@ static const struct ModuleStruct module_cmd_table[] =
  *      - parv[1] = MODULE subcommand [LOAD, UNLOAD, RELOAD, LIST]
  *      - parv[2] = module name
  */
-static int
+static void
 mo_module(struct Client *source_p, int parc, char *parv[])
 {
   const char *const subcmd = parv[1];
@@ -225,13 +225,13 @@ mo_module(struct Client *source_p, int parc, char *parv[])
   if (!HasOFlag(source_p, OPER_FLAG_MODULE))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "module");
-    return 0;
+    return;
   }
 
   if (EmptyString(subcmd))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
-    return 0;
+    return;
   }
 
   for (const struct ModuleStruct *tab = module_cmd_table; tab->handler; ++tab)
@@ -242,17 +242,16 @@ mo_module(struct Client *source_p, int parc, char *parv[])
     if (tab->arg_required == true && EmptyString(module))
     {
       sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
-      return 0;
+      return;
     }
 
     tab->handler(source_p, module);
-    return 0;
+    return;
   }
 
   sendto_one_notice(source_p, &me, ":%s is not a valid option. "
                     "Choose from LOAD, UNLOAD, RELOAD, LIST",
                     subcmd);
-  return 0;
 }
 
 static struct Message module_msgtab =
@@ -281,7 +280,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
   .is_resident = true
