@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_names.c
  * \brief Includes required functions for processing the NAMES command.
- * \version $Id: m_names.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_names.c 9112 2020-01-04 15:50:08Z michael $
  */
 
 #include "stdinc.h"
@@ -48,23 +48,21 @@
  *      - parv[0] = command
  *      - parv[1] = channel name
  */
-static int
+static void
 m_names(struct Client *source_p, int parc, char *parv[])
 {
-  const char *const para = parc > 1 ? parv[1] : NULL;
+  const char *const name = parv[1];
 
-  if (!EmptyString(para))
+  if (!EmptyString(name))
   {
-    struct Channel *chptr = hash_find_channel(para);
-    if (chptr)
-      channel_member_names(source_p, chptr, true);
+    struct Channel *channel = hash_find_channel(name);
+    if (channel)
+      channel_member_names(source_p, channel, true);
     else
-      sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, para);
+      sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, name);
   }
   else
     sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, "*");
-
-  return 0;
 }
 
 static struct Message names_msgtab =
@@ -92,7 +90,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9112 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
