@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_oper.c 9334 2020-04-18 16:18:49Z michael $
  */
 
 #include "stdinc.h"
@@ -123,7 +123,7 @@ failed_oper_notice(struct Client *source_p, const char *name,
  *      - parv[1] = oper name
  *      - parv[2] = oper password
  */
-static int
+static void
 m_oper(struct Client *source_p, int parc, char *parv[])
 {
   const char *const opername = parv[1];
@@ -132,24 +132,24 @@ m_oper(struct Client *source_p, int parc, char *parv[])
   if (EmptyString(password))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "OPER");
-    return 0;
+    return;
   }
 
-  struct MaskItem *conf;
-  if ((conf = operator_find(source_p, opername)) == NULL)
+  struct MaskItem *conf = operator_find(source_p, opername);
+  if (conf == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOOPERHOST);
 
     conf = operator_find(NULL, opername);
     failed_oper_notice(source_p, opername, conf ? "host mismatch" : "no operator {} block");
-    return 0;
+    return;
   }
 
-  if (IsConfSSL(conf) && !HasUMode(source_p, UMODE_SSL))
+  if (IsConfTLS(conf) && !HasUMode(source_p, UMODE_SECURE))
   {
     sendto_one_numeric(source_p, &me, ERR_NOOPERHOST);
-    failed_oper_notice(source_p, opername, "requires SSL/TLS");
-    return 0;
+    failed_oper_notice(source_p, opername, "requires TLS");
+    return;
   }
 
   if (!EmptyString(conf->certfp))
@@ -158,7 +158,7 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     {
       sendto_one_numeric(source_p, &me, ERR_NOOPERHOST);
       failed_oper_notice(source_p, opername, "client certificate fingerprint mismatch");
-      return 0;
+      return;
     }
   }
 
@@ -168,7 +168,7 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     {
       sendto_one_notice(source_p, &me, ":Can't attach conf!");
       failed_oper_notice(source_p, opername, "can't attach conf!");
-      return 0;
+      return;
     }
 
     oper_up(source_p, conf);
@@ -178,8 +178,6 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     sendto_one_numeric(source_p, &me, ERR_PASSWDMISMATCH);
     failed_oper_notice(source_p, opername, "password mismatch");
   }
-
-  return 0;
 }
 
 /*! \brief OPER command handler
@@ -194,11 +192,10 @@ m_oper(struct Client *source_p, int parc, char *parv[])
  *      - parv[1] = oper name
  *      - parv[2] = oper password
  */
-static int
+static void
 mo_oper(struct Client *source_p, int parc, char *parv[])
 {
   sendto_one_numeric(source_p, &me, RPL_YOUREOPER);
-  return 0;
 }
 
 static struct Message oper_msgtab =
@@ -228,7 +225,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9334 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
