@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2019 ircd-hybrid development team
+ *  Copyright (c) 2001-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_post.c
  * \brief Includes required functions for processing the POST/GET/PUT command.
- * \version $Id: m_post.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_post.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -42,14 +42,13 @@
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  */
-static int
+static void
 mr_dumb_proxy(struct Client *source_p, int parc, char *parv[])
 {
   sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                        "HTTP Proxy disconnected: [%s@%s]",
                        source_p->username, source_p->host);
   exit_client(source_p, "Client Exit");
-  return 0;
 }
 
 static struct Message post_msgtab =
@@ -103,7 +102,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
