@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_restart.c
  * \brief Includes required functions for processing the RESTART command.
- * \version $Id: m_restart.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_restart.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -46,34 +46,33 @@
  *      - parv[0] = command
  *      - parv[1] = server name
  */
-static int
+static void
 mo_restart(struct Client *source_p, int parc, char *parv[])
 {
-  char buf[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
   const char *const name = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_RESTART))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "restart");
-    return 0;
+    return;
   }
 
   if (EmptyString(name))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "RESTART");
-    return 0;
+    return;
   }
 
   if (irccmp(name, me.name))
   {
     sendto_one_notice(source_p, &me, ":Mismatch on /restart %s", me.name);
-    return 0;
+    return;
   }
 
   snprintf(buf, sizeof(buf), "received RESTART command from %s",
            client_get_name(source_p, HIDE_IP));
   server_die(buf, true);
-  return 0;
 }
 
 static struct Message restart_msgtab =
@@ -101,7 +100,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
