@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 9037 2019-05-30 12:26:21Z michael $
+ * \version $Id: m_stats.c 9321 2020-03-08 12:40:32Z michael $
  */
 
 #include "stdinc.h"
@@ -53,6 +53,8 @@
 #include "reslib.h"
 #include "motd.h"
 #include "ipcache.h"
+#include "channel.h"
+#include "channel_invite.h"
 
 
 static const char *
@@ -266,7 +268,7 @@ stats_connect(struct Client *source_p, int parc, char *parv[])
 
     if (IsConfAllowAutoConn(conf))
       *p++ = 'A';
-    if (IsConfSSL(conf))
+    if (IsConfTLS(conf))
       *p++ = 'S';
     if (p == buf)
       *p++ = '*';
@@ -376,19 +378,19 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   /* Count up all members, invites, ban lists, except lists, Invex lists */
   DLINK_FOREACH(node, channel_get_list()->head)
   {
-    const struct Channel *chptr = node->data;
+    const struct Channel *channel = node->data;
 
-    channel_members += dlink_list_length(&chptr->members);
-    channel_invites += dlink_list_length(&chptr->invites);
+    channel_members += dlink_list_length(&channel->members);
+    channel_invites += dlink_list_length(&channel->invites);
 
-    channel_bans += dlink_list_length(&chptr->banlist);
-    channel_ban_memory += dlink_list_length(&chptr->banlist) * sizeof(struct Ban);
+    channel_bans += dlink_list_length(&channel->banlist);
+    channel_ban_memory += dlink_list_length(&channel->banlist) * sizeof(struct Ban);
 
-    channel_except += dlink_list_length(&chptr->exceptlist);
-    channel_except_memory += dlink_list_length(&chptr->exceptlist) * sizeof(struct Ban);
+    channel_except += dlink_list_length(&channel->exceptlist);
+    channel_except_memory += dlink_list_length(&channel->exceptlist) * sizeof(struct Ban);
 
-    channel_invex += dlink_list_length(&chptr->invexlist);
-    channel_invex_memory += dlink_list_length(&chptr->invexlist) * sizeof(struct Ban);
+    channel_invex += dlink_list_length(&channel->invexlist);
+    channel_invex_memory += dlink_list_length(&channel->invexlist) * sizeof(struct Ban);
   }
 
   safelist_count = dlink_list_length(&listing_client_list);
@@ -469,7 +471,7 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "z :Channel members %u(%zu) invites %u(%zu)",
                      channel_members,
-                     channel_members * sizeof(struct Membership),
+                     channel_members * sizeof(struct ChannelMember),
                      channel_invites,
                      channel_invites * sizeof(struct Invite));
 
@@ -502,13 +504,12 @@ stats_memory(struct Client *source_p, int parc, char *parv[])
 static void
 stats_dns_servers(struct Client *source_p, int parc, char *parv[])
 {
-  char ipaddr[HOSTIPLEN + 1] = "";
+  char ipaddr[HOSTIPLEN + 1];
 
   for (unsigned int i = 0; i < irc_nscount; ++i)
   {
-    getnameinfo((const struct sockaddr *)&(irc_nsaddr_list[i]),
-                irc_nsaddr_list[i].ss_len, ipaddr,
-                sizeof(ipaddr), NULL, 0, NI_NUMERICHOST);
+    getnameinfo((const struct sockaddr *)&irc_nsaddr_list[i], irc_nsaddr_list[i].ss_len,
+                ipaddr, sizeof(ipaddr), NULL, 0, NI_NUMERICHOST);
     sendto_one_numeric(source_p, &me, RPL_STATSALINE, ipaddr);
   }
 }
@@ -704,10 +705,17 @@ show_iline_prefix(const struct Client *source_p, const struct MaskItem *conf)
 }
 
 static void
-report_auth(struct Client *source_p, int parc, char *parv[])
+stats_auth(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
 
+  /* Oper only, if unopered, return ERR_NOPRIVILEGES */
+  if (ConfigGeneral.stats_i_oper_only && !HasUMode(source_p, UMODE_OPER))
+  {
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+    return;
+  }
+
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
     DLINK_FOREACH(node, atable[i].head)
@@ -718,7 +726,7 @@ report_auth(struct Client *source_p, int parc, char *parv[])
         continue;
 
       const struct MaskItem *conf = arec->conf;
-      if (!HasUMode(source_p, UMODE_OPER) && IsConfDoSpoofIp(conf))
+      if (IsConfDoSpoofIp(conf) && !HasUMode(source_p, UMODE_OPER))
         continue;
 
       sendto_one_numeric(source_p, &me, RPL_STATSILINE, 'I',
@@ -730,39 +738,6 @@ report_auth(struct Client *source_p, int parc, char *parv[])
   }
 }
 
-static void
-stats_auth(struct Client *source_p, int parc, char *parv[])
-{
-  /* Oper only, if unopered, return ERR_NOPRIVILEGES */
-  if (ConfigGeneral.stats_i_oper_only == 2 && !HasUMode(source_p, UMODE_OPER))
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
-
-  /* If unopered, only return matching auth blocks */
-  else if (ConfigGeneral.stats_i_oper_only == 1 && !HasUMode(source_p, UMODE_OPER))
-  {
-    const struct MaskItem *conf = NULL;
-
-    if (MyConnect(source_p))
-      conf = find_conf_by_address(source_p->host,
-                                  &source_p->ip, CONF_CLIENT,
-                                  source_p->username,
-                                  source_p->connection->password, 1);
-    else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_CLIENT,
-                                  source_p->username, NULL, 1);
-
-    if (conf == NULL)
-      return;
-
-    sendto_one_numeric(source_p, &me, RPL_STATSILINE,
-                       'I', "*", show_iline_prefix(source_p, conf),
-                       conf->host, conf->port,
-                       conf->class->name);
-  }
-  else  /* They are opered, or allowed to see all auth blocks */
-    report_auth(source_p, 0, NULL);
-}
-
 /* report_Klines()
  * Inputs: Client to report to,
  *         type(==0 for perm, !=0 for temporary)
@@ -771,15 +746,16 @@ stats_auth(struct Client *source_p, int parc, char *parv[])
  * Side effects: Reports configured K(or k)-lines to source_p.
  */
 static void
-report_Klines(struct Client *source_p, int tkline)
+stats_kill(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
-  char c = '\0';
 
-  if (tkline)
-    c = 'k';
-  else
-    c = 'K';
+  /* Oper only, if unopered, return ERR_NOPRIVILEGES */
+  if (ConfigGeneral.stats_k_oper_only && !HasUMode(source_p, UMODE_OPER))
+  {
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+    return;
+  }
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -791,83 +767,46 @@ report_Klines(struct Client *source_p, int tkline)
         continue;
 
       const struct MaskItem *conf = arec->conf;
-      if ((!tkline && conf->until) ||
-          (tkline && !conf->until))
+      /* Don't report a temporary kline as permanent kline */
+      if (conf->until)
         continue;
 
-      sendto_one_numeric(source_p, &me, RPL_STATSKLINE, c, conf->host, conf->user,
+      sendto_one_numeric(source_p, &me, RPL_STATSKLINE, 'K', conf->host, conf->user,
                          conf->reason);
     }
   }
 }
 
 static void
-stats_tklines(struct Client *source_p, int parc, char *parv[])
+stats_tkill(struct Client *source_p, int parc, char *parv[])
 {
+  dlink_node *node;
+
   /* Oper only, if unopered, return ERR_NOPRIVILEGES */
-  if (ConfigGeneral.stats_k_oper_only == 2 && !HasUMode(source_p, UMODE_OPER))
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
-
-  /* If unopered, only return matching klines */
-  else if (ConfigGeneral.stats_k_oper_only == 1 && !HasUMode(source_p, UMODE_OPER))
+  if (ConfigGeneral.stats_k_oper_only && !HasUMode(source_p, UMODE_OPER))
   {
-    const struct MaskItem *conf = NULL;
-
-    if (MyConnect(source_p))
-      conf = find_conf_by_address(source_p->host,
-                                  &source_p->ip, CONF_KLINE,
-                                  source_p->username, NULL, 1);
-    else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE,
-                                  source_p->username, NULL, 1);
-
-    if (conf == NULL)
-      return;
-
-    /* Don't report a permanent kline as temporary kline */
-    if (conf->until == 0)
-      return;
-
-    sendto_one_numeric(source_p, &me, RPL_STATSKLINE, 'k',
-                       conf->host, conf->user, conf->reason);
-  }
-  else  /* They are opered, or allowed to see all klines */
-    report_Klines(source_p, 1);
-}
-
-static void
-stats_klines(struct Client *source_p, int parc, char *parv[])
-{
-  /* Oper only, if unopered, return ERR_NOPRIVILEGES */
-  if (ConfigGeneral.stats_k_oper_only == 2 && !HasUMode(source_p, UMODE_OPER))
     sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+    return;
+  }
 
-  /* If unopered, only return matching klines */
-  else if (ConfigGeneral.stats_k_oper_only == 1 && !HasUMode(source_p, UMODE_OPER))
+  for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
-    const struct MaskItem *conf = NULL;
+    DLINK_FOREACH(node, atable[i].head)
+    {
+      const struct AddressRec *arec = node->data;
 
-    /* Search for a kline */
-    if (MyConnect(source_p))
-      conf = find_conf_by_address(source_p->host,
-                                  &source_p->ip, CONF_KLINE,
-                                  source_p->username, NULL, 0);
-    else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE,
-                                  source_p->username, NULL, 0);
+      if (arec->type != CONF_KLINE)
+        continue;
 
-    if (conf == NULL)
-      return;
+      const struct MaskItem *conf = arec->conf;
+      /* Don't report a permanent kline as temporary kline */
+      if (conf->until == 0)
+        continue;
 
-    /* Don't report a temporary kline as permanent kline */
-    if (conf->until)
-      return;
-
-    sendto_one_numeric(source_p, &me, RPL_STATSKLINE, 'K',
-                       conf->host, conf->user, conf->reason);
+      sendto_one_numeric(source_p, &me, RPL_STATSKLINE, 'k', conf->host, conf->user,
+                         conf->reason);
+    }
   }
-  else  /* They are opered, or allowed to see all klines */
-    report_Klines(source_p, 0);
 }
 
 static void
@@ -903,8 +842,8 @@ static void
 stats_operedup(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
+  char buf[32];
   unsigned int opercount = 0;
-  char buf[IRCD_BUFSIZE] = "";
 
   DLINK_FOREACH(node, oper_list.head)
   {
@@ -943,10 +882,16 @@ stats_operedup(struct Client *source_p, int parc, char *parv[])
  * side effects - send port listing to a client
  */
 static void
-show_ports(struct Client *source_p)
+stats_ports(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
 
+  if (ConfigGeneral.stats_P_oper_only && !HasUMode(source_p, UMODE_OPER))
+  {
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+    return;
+  }
+
   DLINK_FOREACH(node, listener_get_list()->head)
   {
     char buf[8];
@@ -962,8 +907,8 @@ show_ports(struct Client *source_p)
 
     if (listener->flags & LISTENER_SERVER)
       *p++ = 'S';
-    if (listener->flags & LISTENER_SSL)
-      *p++ = 's';
+    if (listener->flags & LISTENER_TLS)
+      *p++ = 'T';
     *p = '\0';
 
     if (HasUMode(source_p, UMODE_ADMIN) && ConfigServerHide.hide_server_ips == 0)
@@ -978,15 +923,6 @@ show_ports(struct Client *source_p)
   }
 }
 
-static void
-stats_ports(struct Client *source_p, int parc, char *parv[])
-{
-  if (!HasUMode(source_p, UMODE_OPER) && ConfigGeneral.stats_P_oper_only)
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
-  else
-    show_ports(source_p);
-}
-
 static void
 stats_tstats(struct Client *source_p, int parc, char *parv[])
 {
@@ -1122,7 +1058,6 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
   uintmax_t sendB = 0, recvB = 0;
-  uintmax_t uptime = 0;
 
   if (ConfigServerHide.flatten_links && !HasUMode(source_p, UMODE_OPER))
   {
@@ -1164,8 +1099,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT, "? :Recv total: %7.2f %s",
                      _GMKv(recvB), _GMKs(recvB));
 
-  uptime = (event_base->time.sec_monotonic - me.connection->created_monotonic);
-
+  uintmax_t uptime = (event_base->time.sec_monotonic - me.connection->created_monotonic);
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                      "? :Server send: %7.2f %s (%4.1f KiB/s)",
                      _GMKv((me.connection->send.bytes >> 10)),
@@ -1224,7 +1158,7 @@ stats_L_list(struct Client *source_p, const char *name, bool doall, bool wilds,
   DLINK_FOREACH(node, list->head)
   {
     const struct Client *target_p = node->data;
-    enum addr_mask_type type = 0;
+    enum addr_mask_type type;
 
     if (!doall && wilds && match(name, target_p->name))
       continue;
@@ -1277,7 +1211,7 @@ stats_ltrace(struct Client *source_p, int parc, char *parv[])
 {
   bool doall = false;
   bool wilds = false;
-  const char *name = NULL;
+  const char *name;
 
   if ((name = parse_stats_args(source_p, parc, parv, &doall, &wilds)))
   {
@@ -1290,54 +1224,54 @@ stats_ltrace(struct Client *source_p, int parc, char *parv[])
 
 struct StatsStruct
 {
-  const unsigned char letter;
+  unsigned char letter;
   void (*handler)(struct Client *, int, char *[]);
-  const unsigned int required_modes;
+  unsigned int required_modes;
 };
 
 static const struct StatsStruct *stats_map[256];
 static const struct StatsStruct  stats_tab[] =
 {
-  { 'a',  stats_dns_servers, UMODE_ADMIN },
-  { 'A',  stats_dns_servers, UMODE_ADMIN },
-  { 'c',  stats_connect,     UMODE_OPER  },
-  { 'C',  stats_connect,     UMODE_OPER  },
-  { 'd',  stats_tdeny,       UMODE_OPER  },
-  { 'D',  stats_deny,        UMODE_OPER  },
-  { 'e',  stats_exempt,      UMODE_OPER  },
-  { 'E',  stats_events,      UMODE_ADMIN },
-  { 'f',  stats_fdlist,      UMODE_ADMIN },
-  { 'F',  stats_fdlist,      UMODE_ADMIN },
-  { 'h',  stats_hubleaf,     UMODE_OPER  },
-  { 'H',  stats_hubleaf,     UMODE_OPER  },
-  { 'i',  stats_auth,        0           },
-  { 'I',  stats_auth,        0           },
-  { 'k',  stats_tklines,     0           },
-  { 'K',  stats_klines,      0           },
-  { 'l',  stats_ltrace,      UMODE_OPER  },
-  { 'L',  stats_ltrace,      UMODE_OPER  },
-  { 'm',  stats_messages,    0           },
-  { 'M',  stats_messages,    0           },
-  { 'o',  stats_operator,    0           },
-  { 'O',  stats_operator,    0           },
-  { 'p',  stats_operedup,    0           },
-  { 'P',  stats_ports,       0           },
-  { 'q',  stats_resv,        UMODE_OPER  },
-  { 'Q',  stats_resv,        UMODE_OPER  },
-  { 's',  stats_pseudo,      UMODE_OPER  },
-  { 'S',  stats_service,     UMODE_OPER  },
-  { 't',  stats_tstats,      UMODE_OPER  },
-  { 'T',  motd_report,       UMODE_OPER  },
-  { 'u',  stats_uptime,      0           },
-  { 'U',  stats_shared,      UMODE_OPER  },
-  { 'v',  stats_servers,     UMODE_OPER  },
-  { 'x',  stats_gecos,       UMODE_OPER  },
-  { 'X',  stats_gecos,       UMODE_OPER  },
-  { 'y',  stats_class,       UMODE_OPER  },
-  { 'Y',  stats_class,       UMODE_OPER  },
-  { 'z',  stats_memory,      UMODE_OPER  },
-  { '?',  stats_servlinks,   0           },
-  { '\0', NULL,              0           }
+  { .letter = 'a', .handler = stats_dns_servers, .required_modes = UMODE_ADMIN },
+  { .letter = 'A', .handler = stats_dns_servers, .required_modes = UMODE_ADMIN },
+  { .letter = 'c', .handler = stats_connect, .required_modes = UMODE_OPER },
+  { .letter = 'C', .handler = stats_connect, .required_modes = UMODE_OPER },
+  { .letter = 'd', .handler = stats_tdeny, .required_modes = UMODE_OPER },
+  { .letter = 'D', .handler = stats_deny, .required_modes = UMODE_OPER },
+  { .letter = 'e', .handler = stats_exempt, .required_modes = UMODE_OPER },
+  { .letter = 'E', .handler = stats_events, .required_modes = UMODE_ADMIN },
+  { .letter = 'f', .handler = stats_fdlist, .required_modes = UMODE_ADMIN },
+  { .letter = 'F', .handler = stats_fdlist, .required_modes = UMODE_ADMIN },
+  { .letter = 'h', .handler = stats_hubleaf, .required_modes = UMODE_OPER },
+  { .letter = 'H', .handler = stats_hubleaf, .required_modes = UMODE_OPER },
+  { .letter = 'i', .handler = stats_auth },
+  { .letter = 'I', .handler = stats_auth },
+  { .letter = 'k', .handler = stats_tkill },
+  { .letter = 'K', .handler = stats_kill },
+  { .letter = 'l', .handler = stats_ltrace, .required_modes = UMODE_OPER },
+  { .letter = 'L', .handler = stats_ltrace, .required_modes = UMODE_OPER },
+  { .letter = 'm', .handler = stats_messages },
+  { .letter = 'M', .handler = stats_messages },
+  { .letter = 'o', .handler = stats_operator },
+  { .letter = 'O', .handler = stats_operator },
+  { .letter = 'p', .handler = stats_operedup },
+  { .letter = 'P', .handler = stats_ports },
+  { .letter = 'q', .handler = stats_resv, .required_modes = UMODE_OPER },
+  { .letter = 'Q', .handler = stats_resv, .required_modes = UMODE_OPER },
+  { .letter = 's', .handler = stats_pseudo, .required_modes = UMODE_OPER },
+  { .letter = 'S', .handler = stats_service, .required_modes = UMODE_OPER },
+  { .letter = 't', .handler = stats_tstats, .required_modes = UMODE_OPER },
+  { .letter = 'T', .handler = motd_report, .required_modes = UMODE_OPER },
+  { .letter = 'u', .handler = stats_uptime },
+  { .letter = 'U', .handler = stats_shared, .required_modes = UMODE_OPER },
+  { .letter = 'v', .handler = stats_servers, .required_modes = UMODE_OPER },
+  { .letter = 'x', .handler = stats_gecos, .required_modes = UMODE_OPER },
+  { .letter = 'X', .handler = stats_gecos, .required_modes = UMODE_OPER },
+  { .letter = 'y', .handler = stats_class, .required_modes = UMODE_OPER },
+  { .letter = 'Y', .handler = stats_class, .required_modes = UMODE_OPER },
+  { .letter = 'z', .handler = stats_memory, .required_modes = UMODE_OPER },
+  { .letter = '?', .handler = stats_servlinks },
+  { .letter = '\0' }
 };
 
 static void
@@ -1374,7 +1308,7 @@ do_stats(struct Client *source_p, int parc, char *parv[])
  *      parv[1] = stat letter/command
  *      parv[2] = (if present) server/mask in stats L
  */
-static int
+static void
 m_stats(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
@@ -1383,7 +1317,7 @@ m_stats(struct Client *source_p, int parc, char *parv[])
   if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "STATS");
-    return 0;
+    return;
   }
 
   last_used = event_base->time.sec_monotonic;
@@ -1391,10 +1325,9 @@ m_stats(struct Client *source_p, int parc, char *parv[])
   /* Is the stats meant for us? */
   if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
-      return 0;
+      return;
 
   do_stats(source_p, parc, parv);
-  return 0;
 }
 
 /*
@@ -1403,14 +1336,13 @@ m_stats(struct Client *source_p, int parc, char *parv[])
  *      parv[1] = stat letter/command
  *      parv[2] = (if present) server/mask in stats L, or target
  */
-static int
+static void
 ms_stats(struct Client *source_p, int parc, char *parv[])
 {
   if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
-     return 0;
+    return;
 
   do_stats(source_p, parc, parv);
-  return 0;
 }
 
 static void
@@ -1447,7 +1379,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 9037 $",
+  .version = "$Revision: 9321 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
