@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2016-2019 ircd-hybrid development team
+ *  Copyright (c) 2016-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,14 @@
 
 /*! \file m_svshost.c
  * \brief Includes required functions for processing the SVSHOST command.
- * \version $Id: m_svshost.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_svshost.c 9233 2020-01-31 17:31:08Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
 #include "send.h"
+#include "channel.h"
 #include "channel_mode.h"
 #include "parse.h"
 #include "modules.h"
@@ -47,19 +48,19 @@
  *      - parv[2] = TS
  *      - parv[3] = host name
  */
-static int
+static void
 ms_svshost(struct Client *source_p, int parc, char *parv[])
 {
   if (!HasFlag(source_p, FLAGS_SERVICE))
-    return 0;
+    return;
 
-  struct Client *target_p;
-  if ((target_p = find_person(source_p, parv[1])) == NULL)
-    return 0;
+  struct Client *target_p = find_person(source_p, parv[1]);
+  if (target_p == NULL)
+    return;
 
   uintmax_t ts = strtoumax(parv[2], NULL, 10);
   if (ts && (ts != target_p->tsinfo))
-    return 0;
+    return;
 
   if (valid_hostname(parv[3]) == true)
     user_set_hostmask(target_p, parv[3]);
@@ -67,7 +68,6 @@ ms_svshost(struct Client *source_p, int parc, char *parv[])
   sendto_server(source_p, 0, 0, ":%s SVSHOST %s %ju %s",
                 source_p->id,
                 target_p->id, target_p->tsinfo, parv[3]);
-  return 0;
 }
 
 static struct Message svshost_msgtab =
@@ -96,7 +96,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9233 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
