@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2019 ircd-hybrid development team
+ *  Copyright (c) 2011-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsmode.c
  * \brief Includes required functions for processing the SVSMODE command.
- * \version $Id: m_svsmode.c 8996 2019-05-25 20:53:32Z michael $
+ * \version $Id: m_svsmode.c 9275 2020-02-12 18:46:44Z michael $
  */
 
 #include "stdinc.h"
@@ -31,6 +31,7 @@
 #include "client_svstag.h"
 #include "ircd.h"
 #include "send.h"
+#include "channel.h"
 #include "channel_mode.h"
 #include "parse.h"
 #include "modules.h"
@@ -53,29 +54,28 @@
  *      - parv[3] = mode
  *      - parv[4] = optional argument (services account, vhost)
  */
-static int
+static void
 ms_svsmode(struct Client *source_p, int parc, char *parv[])
 {
   const struct user_modes *tab = NULL;
-  struct Client *target_p = NULL;
   int what = MODE_ADD;
-  unsigned int setmodes = 0;
   const char *modes = NULL, *extarg = NULL;
 
   if (!HasFlag(source_p, FLAGS_SERVICE))
-    return 0;
+    return;
 
   modes  = parv[3];
   extarg = (parc > 4) ? parv[4] : NULL;
 
-  if ((target_p = find_person(source_p, parv[1])) == NULL)
-    return 0;
+  struct Client *target_p = find_person(source_p, parv[1]);
+  if (target_p == NULL)
+    return;
 
   uintmax_t ts = strtoumax(parv[2], NULL, 10);
   if (ts && (ts != target_p->tsinfo))
-    return 0;
+    return;
 
-  setmodes = target_p->umodes;
+  const unsigned int setmodes = target_p->umodes;
 
   for (const char *m = modes; *m; ++m)
   {
@@ -112,14 +112,14 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
           if (MyConnect(target_p))
           {
-            dlink_node *node;
-
             svstag_detach(&target_p->svstags, RPL_WHOISOPERATOR);
             conf_detach(target_p, CONF_OPER);
+
             ClrOFlag(target_p);
             DelUMode(target_p, ConfigGeneral.oper_only_umodes);
 
-            if ((node = dlinkFindDelete(&oper_list, target_p)))
+            dlink_node *node = dlinkFindDelete(&oper_list, target_p);
+            if (node)
               free_dlink_node(node);
           }
         }
@@ -168,12 +168,10 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
   if (MyConnect(target_p) && (setmodes != target_p->umodes))
   {
-    char modebuf[IRCD_BUFSIZE] = "";
+    char buf[UMODE_MAX_STR] = "";
 
-    send_umode(target_p, true, setmodes, modebuf);
+    send_umode(target_p, true, setmodes, buf);
   }
-
-  return 0;
 }
 
 static struct Message svsmode_msgtab =
@@ -202,7 +200,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8996 $",
+  .version = "$Revision: 9275 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
