@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2015-2019 ircd-hybrid development team
+ *  Copyright (c) 2015-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svstag.c
  * \brief Includes required functions for processing the SVSTAG command.
- * \version $Id: m_svstag.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_svstag.c 9199 2020-01-23 17:49:06Z michael $
  */
 
 #include "stdinc.h"
@@ -50,19 +50,19 @@
  *      - parv[4] = required user mode(s) to see the tag
  *      - parv[5] = tag line
  */
-static int
+static void
 ms_svstag(struct Client *source_p, int parc, char *parv[])
 {
   if (!HasFlag(source_p, FLAGS_SERVICE) && !IsServer(source_p))
-    return 0;
+    return;
 
-  struct Client *target_p;
-  if ((target_p = find_person(source_p, parv[1])) == NULL)
-    return 0;
+  struct Client *target_p = find_person(source_p, parv[1]);
+  if (target_p == NULL)
+    return;
 
   uintmax_t ts = strtoumax(parv[2], NULL, 10);
   if (ts && (ts != target_p->tsinfo))
-    return 0;
+    return;
 
   if (strncmp(parv[3], "-", 1) == 0)
   {
@@ -71,11 +71,11 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
     sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %s",
                   source_p->id,
                   target_p->id, target_p->tsinfo, parv[3]);
-    return 0;
+    return;
   }
 
   if (parc < 6 || EmptyString(parv[5]))
-    return 0;
+    return;
 
   svstag_attach(&target_p->svstags, strtoul(parv[3], NULL, 10), parv[4], parv[5]);
 
@@ -83,7 +83,6 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
                 source_p->id,
                 target_p->id, target_p->tsinfo,
                 parv[3], parv[4], parv[5]);
-  return 0;
 }
 
 static struct Message svstag_msgtab =
@@ -112,7 +111,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9199 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
