@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2002-2019 ircd-hybrid development team
+ *  Copyright (c) 2002-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tburst.c
  * \brief Includes required functions for processing the TBURST command.
- * \version $Id: m_tburst.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_tburst.c 9233 2020-01-31 17:31:08Z michael $
  */
 
 #include "stdinc.h"
@@ -33,6 +33,7 @@
 #include "server_capab.h"
 #include "conf.h"
 #include "parse.h"
+#include "channel.h"
 
 
 /*! \brief TBURST command handler
@@ -50,7 +51,7 @@
  *      - parv[4] = topic setter
  *      - parv[5] = topic (can be an empty string)
  */
-static int
+static void
 ms_tburst(struct Client *source_p, int parc, char *parv[])
 {
   uintmax_t remote_channel_ts = strtoumax(parv[1], NULL, 10);
@@ -66,9 +67,9 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
    */
 
 
-  struct Channel *chptr;
-  if ((chptr = hash_find_channel(parv[2])) == NULL)
-    return 0;
+  struct Channel *channel = hash_find_channel(parv[2]);
+  if (channel == NULL)
+    return;
 
   /*
    * The logic for accepting and rejecting channel topics was
@@ -86,36 +87,35 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
   bool accept_remote = false;
   if (HasFlag(source_p, FLAGS_SERVICE))
     accept_remote = true;
-  else if (remote_channel_ts < chptr->creationtime)
+  else if (remote_channel_ts < channel->creation_time)
     accept_remote = true;
-  else if (remote_channel_ts == chptr->creationtime)
-    if (remote_topic_ts > chptr->topic_time)
+  else if (remote_channel_ts == channel->creation_time)
+    if (remote_topic_ts > channel->topic_time)
       accept_remote = true;
 
   if (accept_remote == true)
   {
-    bool topic_differs = strncmp(chptr->topic, topic, sizeof(chptr->topic) - 1);
+    bool topic_differs = strncmp(channel->topic, topic, sizeof(channel->topic) - 1);
     bool hidden_server = (ConfigServerHide.hide_servers || IsHidden(source_p));
 
-    channel_set_topic(chptr, topic, setby, remote_topic_ts, false);
+    channel_set_topic(channel, topic, setby, remote_topic_ts, false);
 
     sendto_server(source_p, CAPAB_TBURST, 0, ":%s TBURST %s %s %s %s :%s",
                   source_p->id, parv[1], parv[2], parv[3], setby, topic);
 
+    /* If it's a new topic, send it to clients, otherwise drop it to save bandwith. */
     if (topic_differs == true)
     {
       if (IsClient(source_p))
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
+        sendto_channel_local(NULL, channel, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                              source_p->name, source_p->username, source_p->host,
-                             chptr->name, chptr->topic);
+                             channel->name, channel->topic);
       else
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
+        sendto_channel_local(NULL, channel, 0, 0, 0, ":%s TOPIC %s :%s",
                              hidden_server ? me.name : source_p->name,
-                             chptr->name, chptr->topic);
+                             channel->name, channel->topic);
     }
   }
-
-  return 0;
 }
 
 static struct Message tburst_msgtab =
@@ -146,7 +146,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9233 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
