@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_topic.c
  * \brief Includes required functions for processing the TOPIC command.
- * \version $Id: m_topic.c 8927 2019-04-22 11:08:47Z michael $
+ * \version $Id: m_topic.c 9334 2020-04-18 16:18:49Z michael $
  */
 
 #include "stdinc.h"
@@ -52,75 +52,71 @@
  *      - parv[1] = channel name
  *      - parv[2] = topic text, if setting topic (can be an empty string)
  */
-static int
+static void
 m_topic(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *chptr = NULL;
-
   if (EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "TOPIC");
-    return 0;
+    return;
   }
 
-  if ((chptr = hash_find_channel(parv[1])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[1]);
+  if (channel == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[1]);
-    return 0;
+    return;
   }
 
-  /* setting topic */
+  /* Setting topic */
   if (parc > 2)
   {
-    const struct Membership *member = NULL;
-
-    if ((member = find_channel_link(source_p, chptr)) == NULL)
+    const struct ChannelMember *member = find_channel_link(source_p, channel);
+    if (member == NULL)
     {
-      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
-      return 0;
+      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
+      return;
     }
 
-    if (!HasCMode(chptr, MODE_TOPICLIMIT) ||
+    if (!HasCMode(channel, MODE_TOPICLIMIT) ||
         has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP))
     {
       char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
       snprintf(topic_info, sizeof(topic_info), "%s!%s@%s", source_p->name,
                source_p->username, source_p->host);
-      channel_set_topic(chptr, parv[2], topic_info, event_base->time.sec_real, true);
+      channel_set_topic(channel, parv[2], topic_info, event_base->time.sec_real, true);
 
       sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
-                    source_p->id, chptr->name,
-                    chptr->topic);
-      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
+                    source_p->id, channel->name,
+                    channel->topic);
+      sendto_channel_local(NULL, channel, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                            source_p->name,
                            source_p->username,
                            source_p->host,
-                           chptr->name, chptr->topic);
+                           channel->name, channel->topic);
     }
     else
-      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->name);
+      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, channel->name);
   }
-  else /* only asking for topic */
+  else  /* Only asking for topic */
   {
-    if (!SecretChannel(chptr) || IsMember(source_p, chptr))
+    if (!SecretChannel(channel) || IsMember(source_p, channel))
     {
-      if (chptr->topic[0] == '\0')
-        sendto_one_numeric(source_p, &me, RPL_NOTOPIC, chptr->name);
+      if (channel->topic[0] == '\0')
+        sendto_one_numeric(source_p, &me, RPL_NOTOPIC, channel->name);
       else
       {
         sendto_one_numeric(source_p, &me, RPL_TOPIC,
-                           chptr->name, chptr->topic);
-        sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, chptr->name,
-                           chptr->topic_info,
-                           chptr->topic_time);
+                           channel->name, channel->topic);
+        sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, channel->name,
+                           channel->topic_info,
+                           channel->topic_time);
       }
     }
     else
-      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
+      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, channel->name);
   }
-
-  return 0;
 }
 
 
@@ -136,22 +132,22 @@ m_topic(struct Client *source_p, int parc, char *parv[])
  *      - parv[1] = channel name
  *      - parv[2] = topic text (can be an empty string)
  */
-static int
+static void
 ms_topic(struct Client *source_p, int parc, char *parv[])
 {
-  struct Channel *chptr = NULL;
   char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
   if (parc < 3)
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "TOPIC");
-    return 0;
+    return;
   }
 
-  if ((chptr = hash_find_channel(parv[1])) == NULL)
+  struct Channel *channel = hash_find_channel(parv[1]);
+  if (channel == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[1]);
-    return 0;
+    return;
   }
 
   if (IsClient(source_p))
@@ -162,27 +158,24 @@ ms_topic(struct Client *source_p, int parc, char *parv[])
   else
     strlcpy(topic_info, source_p->name, sizeof(topic_info));
 
-  channel_set_topic(chptr, parv[2], topic_info, event_base->time.sec_real, false);
+  channel_set_topic(channel, parv[2], topic_info, event_base->time.sec_real, false);
 
   sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
-                source_p->id, chptr->name,
-                chptr->topic);
+                source_p->id, channel->name,
+                channel->topic);
 
   if (IsClient(source_p))
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                          source_p->name,
                          source_p->username,
                          source_p->host,
-                         chptr->name, chptr->topic);
+                         channel->name, channel->topic);
   else
-    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
+    sendto_channel_local(NULL, channel, 0, 0, 0, ":%s TOPIC %s :%s",
                          (IsHidden(source_p) || ConfigServerHide.hide_servers) ? me.name : source_p->name,
-                         chptr->name, chptr->topic);
-
-  return 0;
+                         channel->name, channel->topic);
 }
 
-
 static struct Message topic_msgtab =
 {
   .cmd = "TOPIC",
@@ -210,7 +203,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8927 $",
+  .version = "$Revision: 9334 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
