@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2019 ircd-hybrid development team
+ *  Copyright (c) 2001-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unresv.c
  * \brief Includes required functions for processing the UNRESV command.
- * \version $Id: m_unresv.c 8985 2019-05-22 16:47:20Z michael $
+ * \version $Id: m_unresv.c 9199 2020-01-23 17:49:06Z michael $
  */
 
 #include "stdinc.h"
@@ -45,9 +45,9 @@
 static void
 resv_remove(struct Client *source_p, const struct aline_ctx *aline)
 {
-  struct ResvItem *resv;
+  struct ResvItem *resv = resv_find(aline->mask, irccmp);
 
-  if ((resv = resv_find(aline->mask, irccmp)) == NULL)
+  if (resv == NULL)
   {
     if (IsClient(source_p))
       sendto_one_notice(source_p, &me, ":No RESV for %s", aline->mask);
@@ -88,7 +88,7 @@ resv_remove(struct Client *source_p, const struct aline_ctx *aline)
  *      - parv[2] = "ON"
  *      - parv[3] = target server
  */
-static int
+static void
 mo_unresv(struct Client *source_p, int parc, char *parv[])
 {
   struct aline_ctx aline = { .add = false, .simple_mask = true };
@@ -96,11 +96,11 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
   if (!HasOFlag(source_p, OPER_FLAG_UNRESV))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "unresv");
-    return 0;
+    return;
   }
 
   if (parse_aline("UNRESV", source_p, parc, parv, &aline) == false)
-    return 0;
+    return;
 
   if (aline.server)
   {
@@ -109,13 +109,12 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
 
     /* Allow ON to apply local unresv as well if it matches */
     if (match(aline.server, me.name))
-      return 0;
+      return;
   }
   else
     cluster_distribute(source_p, "UNRESV", CAPAB_KLN, CLUSTER_UNRESV, aline.mask);
 
   resv_remove(source_p, &aline);
-  return 0;
 }
 
 /*! \brief UNRESV command handler
@@ -130,7 +129,7 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
  *      - parv[1] = target server mask
  *      - parv[2] = name mask
  */
-static int
+static void
 ms_unresv(struct Client *source_p, int parc, char *parv[])
 {
   struct aline_ctx aline =
@@ -142,20 +141,18 @@ ms_unresv(struct Client *source_p, int parc, char *parv[])
   };
 
   if (parc != 3 || EmptyString(parv[parc - 1]))
-    return 0;
+    return;
 
   sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "UNRESV %s %s",
                      aline.server, aline.mask);
 
   if (match(aline.server, me.name))
-    return 0;
+    return;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
       shared_find(SHARED_UNRESV, source_p->servptr->name,
                   source_p->username, source_p->host))
     resv_remove(source_p, &aline);
-
-  return 0;
 }
 
 static struct Message unresv_msgtab =
@@ -184,7 +181,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8985 $",
+  .version = "$Revision: 9199 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
