@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_user.c
  * \brief Includes required functions for processing the USER command.
- * \version $Id: m_user.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_user.c 9360 2020-04-29 14:02:24Z michael $
  */
 
 #include "stdinc.h"
@@ -50,7 +50,6 @@ do_user(struct Client *source_p,
   assert(IsUnknown(source_p));
 
   source_p->connection->registration &= ~REG_NEED_USER;
-  source_p->servptr = &me;  /* Don't take the clients word for it, ever */
 
   strlcpy(source_p->info, realname, sizeof(source_p->info));
 
@@ -75,28 +74,29 @@ do_user(struct Client *source_p,
  *      - parv[3] = server host name (ignored)
  *      - parv[4] = user's real name info
  */
-static int
+static void
 mr_user(struct Client *source_p, int parc, char *parv[])
 {
-  char *p = NULL;
+  const char *const username = parv[1];
+  const char *const realname = parv[4];
 
   if (source_p->connection->listener->flags & LISTENER_SERVER)
   {
     exit_client(source_p, "Use a different port");
-    return 0;
+    return;
   }
 
-  if (EmptyString(parv[4]))
+  if (EmptyString(realname))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "USER");
-    return 0;
+    return;
   }
 
-  if ((p = strchr(parv[1], '@')))
+  char *p = strchr(username, '@');
+  if (p)
     *p = '\0';
 
-  do_user(source_p, parv[1], parv[4]);
-  return 0;
+  do_user(source_p, username, realname);
 }
 
 static struct Message user_msgtab =
@@ -125,7 +125,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9360 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
