@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2000-2019 ircd-hybrid development team
+ *  Copyright (c) 2000-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_watch.c
  * \brief Includes required functions for processing the WATCH command.
- * \version $Id: m_watch.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: m_watch.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -70,7 +70,7 @@ show_watch(struct Client *source_p, const char *name,
  *      - parv[0] = command
  *      - parv[1] = watch options
  */
-static int
+static void
 m_watch(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
@@ -233,8 +233,6 @@ m_watch(struct Client *source_p, int parc, char *parv[])
 
     /* Hmm.. unknown prefix character.. Ignore it. :-) */
   }
-
-  return 0;
 }
 
 static struct Message watch_msgtab =
@@ -264,7 +262,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8751 $",
+  .version = "$Revision: 9102 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
