@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 8918 2019-04-22 09:51:16Z michael $
+ * \version $Id: m_whois.c 9201 2020-01-24 23:51:50Z michael $
  */
 
 #include "stdinc.h"
@@ -44,14 +44,14 @@
 
 
 static int
-whois_can_see_channels(struct Channel *chptr,
+whois_can_see_channels(struct Channel *channel,
                        struct Client *source_p,
                        struct Client *target_p)
 {
-  if (PubChannel(chptr) && !HasUMode(target_p, UMODE_HIDECHANS))
+  if (PubChannel(channel) && !HasUMode(target_p, UMODE_HIDECHANS))
     return 1;
 
-  if (source_p == target_p || IsMember(source_p, chptr))
+  if (source_p == target_p || IsMember(source_p, channel))
     return 1;
 
   if (HasUMode(source_p, UMODE_OPER))
@@ -69,7 +69,7 @@ whois_can_see_channels(struct Channel *chptr,
 static void
 whois_person(struct Client *source_p, struct Client *target_p)
 {
-  char buf[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
   dlink_node *node;
   const struct ServicesTag *svstag = NULL;
   char *t = NULL;
@@ -88,12 +88,12 @@ whois_person(struct Client *source_p, struct Client *target_p)
 
   DLINK_FOREACH(node, target_p->channel.head)
   {
-    const struct Membership *member = node->data;
-    int show = whois_can_see_channels(member->chptr, source_p, target_p);
+    const struct ChannelMember *member = node->data;
+    int show = whois_can_see_channels(member->channel, source_p, target_p);
 
     if (show)
     {
-      if ((cur_len + 4 + member->chptr->name_len + 1) > (IRCD_BUFSIZE - 2))
+      if ((cur_len + 4 + member->channel->name_len + 1) > (IRCD_BUFSIZE - 2))
       {
         *(t - 1) = '\0';
         sendto_one(source_p, "%s", buf);
@@ -102,7 +102,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
       }
 
       tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(member, true),
-                     member->chptr->name);
+                     member->channel->name);
       t += tlen;
       cur_len += tlen;
       reply_to_send = 1;
@@ -201,7 +201,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
                        target_p->username, target_p->realhost,
                        target_p->sockhost);
 
-  if (HasUMode(target_p, UMODE_SSL))
+  if (HasUMode(target_p, UMODE_SECURE))
     sendto_one_numeric(source_p, &me, RPL_WHOISSECURE, target_p->name);
 
   if (!EmptyString(target_p->certfp))
@@ -253,7 +253,7 @@ do_whois(struct Client *source_p, const char *name)
  *      - parv[1] = nickname/servername
  *      - parv[2] = nickname
  */
-static int
+static void
 m_whois(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
@@ -261,7 +261,7 @@ m_whois(struct Client *source_p, int parc, char *parv[])
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
   if (parc > 2 && !EmptyString(parv[2]))
@@ -270,7 +270,7 @@ m_whois(struct Client *source_p, int parc, char *parv[])
     if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
     {
       sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHOIS");
-      return 0;
+      return;
     }
 
     last_used = event_base->time.sec_monotonic;
@@ -284,13 +284,12 @@ m_whois(struct Client *source_p, int parc, char *parv[])
       parv[1] = parv[2];
 
     if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
-      return 0;
+      return;
 
     parv[1] = parv[2];
   }
 
   do_whois(source_p, parv[1]);
-  return 0;
 }
 
 /*! \brief WHOIS command handler
@@ -305,25 +304,24 @@ m_whois(struct Client *source_p, int parc, char *parv[])
  *      - parv[1] = nickname/servername
  *      - parv[2] = nickname
  */
-static int
+static void
 mo_whois(struct Client *source_p, int parc, char *parv[])
 {
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
   if (parc > 2 && !EmptyString(parv[2]))
   {
     if (server_hunt(source_p, ":%s WHOIS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
-      return 0;
+      return;
 
     parv[1] = parv[2];
   }
 
   do_whois(source_p, parv[1]);
-  return 0;
 }
 
 static struct Message whois_msgtab =
@@ -351,7 +349,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8918 $",
+  .version = "$Revision: 9201 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
