@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_whowas.c 9199 2020-01-23 17:49:06Z michael $
  */
 
 #include "stdinc.h"
@@ -58,7 +58,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
   {
     const struct Whowas *whowas = node->data;
 
-    if (!irccmp(parv[1], whowas->name))
+    if (irccmp(parv[1], whowas->name) == 0)
     {
       sendto_one_numeric(source_p, &me, RPL_WHOWASUSER, whowas->name,
                          whowas->username, whowas->hostname,
@@ -72,7 +72,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
       if (strcmp(whowas->account, "*"))
         sendto_one_numeric(source_p, &me, RPL_WHOISACCOUNT, whowas->name, whowas->account, "was");
 
-      if ((whowas->shide || ConfigServerHide.hide_servers) && !HasUMode(source_p, UMODE_OPER))
+      if ((whowas->server_hidden || ConfigServerHide.hide_servers) && !HasUMode(source_p, UMODE_OPER))
         sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, whowas->name,
                            ConfigServerInfo.network_name, date_ctime(whowas->logoff));
       else
@@ -85,7 +85,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
       break;
   }
 
-  if (!count)
+  if (count == 0)
     sendto_one_numeric(source_p, &me, ERR_WASNOSUCHNICK, parv[1]);
 
   sendto_one_numeric(source_p, &me, RPL_ENDOFWHOWAS, parv[1]);
@@ -104,7 +104,7 @@ do_whowas(struct Client *source_p, const int parc, char *parv[])
  *      - parv[2] = count
  *      - parv[3] = nickname/servername
  */
-static int
+static void
 m_whowas(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
@@ -112,23 +112,22 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHOWAS");
-    return 0;
+    return;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
-  if (!ConfigServerHide.disable_remote_commands)
+  if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
-      return 0;
+      return;
 
   do_whowas(source_p, parc, parv);
-  return 0;
 }
 
 /*! \brief WHOWAS command handler
@@ -144,20 +143,19 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
  *      - parv[2] = count
  *      - parv[3] = nickname/servername
  */
-static int
+static void
 ms_whowas(struct Client *source_p, int parc, char *parv[])
 {
   if (parc < 2 || EmptyString(parv[1]))
   {
     sendto_one_numeric(source_p, &me, ERR_NONICKNAMEGIVEN);
-    return 0;
+    return;
   }
 
   if (server_hunt(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv)->ret != HUNTED_ISME)
-    return 0;
+    return;
 
   do_whowas(source_p, parc, parv);
-  return 0;
 }
 
 static struct Message whowas_msgtab =
@@ -185,7 +183,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 9199 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
