@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file auth.c
  * \brief Implementation of DNS and ident lookups.
- * \version $Id: auth.c 8940 2019-04-27 23:45:33Z michael $
+ * \version $Id: auth.c 9249 2020-02-01 13:35:32Z michael $
  */
 
 /*
@@ -470,21 +470,21 @@ auth_start_query(struct AuthRequest *auth)
  * side effects - starts auth (identd) and dns queries for a client
  */
 void
-auth_start(struct Client *client_p)
+auth_start(struct Client *client)
 {
-  struct AuthRequest *auth = auth_make(client_p);
+  struct AuthRequest *auth = auth_make(client);
 
-  assert(client_p);
-  assert(client_p->connection);
+  assert(client);
+  assert(client->connection);
 
-  auth_sendheader(client_p, REPORT_DO_DNS);
+  auth_sendheader(client, REPORT_DO_DNS);
 
   auth->dns_pending = true;
 
   if (ConfigGeneral.disable_auth == 0)
     auth_start_query(auth);
 
-  gethost_byaddr(auth_dns_callback, auth, &client_p->ip);
+  gethost_byaddr(auth_dns_callback, auth, &client->ip);
 }
 
 /*
