@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 8927 2019-04-22 11:08:47Z michael $
+ * \version $Id: channel_mode.c 9357 2020-04-28 13:56:17Z michael $
  */
 
 #include "stdinc.h"
@@ -38,9 +38,9 @@
 #include "send.h"
 #include "memory.h"
 #include "parse.h"
+#include "extban.h"
 
 
-static char nuh_mask[MAXPARA][IRCD_BUFSIZE];
 static struct ChModeChange mode_changes[IRCD_BUFSIZE];
 static unsigned int mode_count;
 static unsigned int mode_limit;  /* number of modes set other than simple */
@@ -56,14 +56,12 @@ static unsigned int simple_modes_mask;  /* bit mask of simple modes already set
  *                returns the 'fixed' string or "*" if the string
  *                was NULL length or a NULL pointer.
  */
-static char *
+static void
 check_string(char *s)
 {
-  char *const str = s;
-  static char star[] = "*";
+  char *str = s;
 
-  if (EmptyString(str))
-    return star;
+  assert(s);
 
   for (; *s; ++s)
   {
@@ -74,7 +72,25 @@ check_string(char *s)
     }
   }
 
-  return EmptyString(str) ? star : str;
+  if (EmptyString(str))
+    strcpy(str, "*");
+}
+
+static const char *
+get_mask(const struct Ban *ban)
+{
+  static char buf[MODEBUFLEN];
+  const unsigned int i = extban_format(ban->extban, buf);
+
+  assert(i <= sizeof(buf));
+
+  /* Matching extbans only use ban->host */
+  if (ban->extban & extban_matching_mask())
+    strlcpy(buf + i, ban->host, sizeof(buf) - i);
+  else
+    snprintf(buf + i, sizeof(buf) - i, "%s!%s@%s", ban->name, ban->user, ban->host);
+
+  return buf;
 }
 
 /*
@@ -84,80 +100,135 @@ check_string(char *s)
  *   -is 8/9/00
  */
 
-bool
-add_id(struct Client *client_p, struct Channel *chptr, char *banid, dlink_list *list)
+const char *
+add_id(struct Client *client, struct Channel *channel, const char *banid, dlink_list *list, unsigned int type)
 {
   dlink_node *node;
-  char name[NICKLEN + 1] = "";
-  char user[USERLEN + 1] = "";
-  char host[HOSTLEN + 1] = "";
-  struct split_nuh_item nuh;
+  char mask[MODEBUFLEN];
+  char *maskptr = mask;
+  unsigned int extbans, offset;
 
-  if (MyClient(client_p))
+  strlcpy(mask, banid, sizeof(mask));
+
+  if (MyClient(client))
   {
-    unsigned int num_mask = dlink_list_length(&chptr->banlist) +
-                            dlink_list_length(&chptr->exceptlist) +
-                            dlink_list_length(&chptr->invexlist);
+    unsigned int num_mask = dlink_list_length(&channel->banlist) +
+                            dlink_list_length(&channel->exceptlist) +
+                            dlink_list_length(&channel->invexlist);
 
     /* Don't let local clients overflow the b/e/I lists */
-    if (num_mask >= ((HasCMode(chptr, MODE_EXTLIMIT)) ? ConfigChannel.max_bans_large :
-                                                        ConfigChannel.max_bans))
+    if (num_mask >= ((HasCMode(channel, MODE_EXTLIMIT)) ? ConfigChannel.max_bans_large :
+                                                          ConfigChannel.max_bans))
     {
-      sendto_one_numeric(client_p, &me, ERR_BANLISTFULL, chptr->name, banid);
+      sendto_one_numeric(client, &me, ERR_BANLISTFULL, channel->name, banid);
       return false;
     }
 
-    collapse(banid);
+    collapse(mask);
   }
 
-  nuh.nuhmask  = check_string(banid);
-  nuh.nickptr  = name;
-  nuh.userptr  = user;
-  nuh.hostptr  = host;
+  enum extban_type etype = extban_parse(mask, &extbans, &offset);
+  maskptr += offset;
 
-  nuh.nicksize = sizeof(name);
-  nuh.usersize = sizeof(user);
-  nuh.hostsize = sizeof(host);
+  if (MyClient(client))
+  {
+    if (etype == EXTBAN_INVALID)
+    {
+      sendto_one_numeric(client, &me, ERR_INVALIDBAN, channel->name, mask);
+      return NULL;
+    }
 
-  split_nuh(&nuh);
+    if (etype != EXTBAN_NONE && ConfigChannel.enable_extbans == 0)
+    {
+      sendto_one_numeric(client, &me, ERR_INVALIDBAN, channel->name, mask);
+      return NULL;
+    }
 
-  /*
-   * Re-assemble a new n!u@h and print it back to banid for sending
-   * the mode to the channel.
-   */
-  size_t len = snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
+    unsigned int extban_acting = extbans & extban_acting_mask();
+    if (extban_acting)
+    {
+      const struct Extban *extban = extban_find_flag(extban_acting);
+
+      if (extban == NULL || !(extban->types & type))
+      {
+        sendto_one_numeric(client, &me, ERR_INVALIDBAN, channel->name, mask);
+        return NULL;
+      }
+    }
+
+    unsigned extban_matching = extbans & extban_matching_mask();
+    if (extban_matching)
+    {
+      const struct Extban *extban = extban_find_flag(extban_matching);
+
+      if (extban == NULL || !(extban->types & type))
+      {
+        sendto_one_numeric(client, &me, ERR_INVALIDBAN, channel->name, mask);
+        return NULL;
+      }
+    }
+  }
+
+  /* Don't allow empty bans */
+  if (EmptyString(maskptr))
+    return NULL;
+
+  struct Ban *ban = xcalloc(sizeof(*ban));
+  ban->extban = extbans;
+  ban->when = event_base->time.sec_real;
+
+  check_string(maskptr);
+
+  if (etype == EXTBAN_MATCHING)
+    /* Matching extbans have their own format, don't try to parse it */
+    strlcpy(ban->host, maskptr, sizeof(ban->host));
+  else
+  {
+    struct split_nuh_item nuh;
+
+    nuh.nuhmask  = maskptr;
+    nuh.nickptr  = ban->name;
+    nuh.userptr  = ban->user;
+    nuh.hostptr  = ban->host;
+
+    nuh.nicksize = sizeof(ban->name);
+    nuh.usersize = sizeof(ban->user);
+    nuh.hostsize = sizeof(ban->host);
+
+    split_nuh(&nuh);
+
+    ban->type = parse_netmask(ban->host, &ban->addr, &ban->bits);
+  }
+
+  if (MyClient(client))
+    ban->banstr_len = strlcpy(ban->banstr, get_mask(ban), sizeof(ban->banstr));
+  else
+    ban->banstr_len = strlcpy(ban->banstr, banid, sizeof(ban->banstr));
 
   DLINK_FOREACH(node, list->head)
   {
-    const struct Ban *ban = node->data;
+    const struct Ban *tmp = node->data;
 
-    if (irccmp(ban->name, name) == 0 &&
-        irccmp(ban->user, user) == 0 &&
-        irccmp(ban->host, host) == 0)
-      return false;
+    if (irccmp(tmp->banstr, ban->banstr) == 0)
+    {
+      xfree(ban);
+      return NULL;
+    }
   }
 
-  clear_ban_cache_list(&chptr->members_local);
+  clear_ban_cache_list(&channel->members_local);
 
-  struct Ban *ban = xcalloc(sizeof(*ban));
-  ban->when = event_base->time.sec_real;
-  ban->len = len - 2;  /* -2 for ! + @ */
-  ban->type = parse_netmask(host, &ban->addr, &ban->bits);
-  strlcpy(ban->name, name, sizeof(ban->name));
-  strlcpy(ban->user, user, sizeof(ban->user));
-  strlcpy(ban->host, host, sizeof(ban->host));
-
-  if (IsClient(client_p))
-    snprintf(ban->who, sizeof(ban->who), "%s!%s@%s", client_p->name,
-             client_p->username, client_p->host);
-  else if (IsHidden(client_p) || ConfigServerHide.hide_servers)
+  if (IsClient(client))
+    snprintf(ban->who, sizeof(ban->who), "%s!%s@%s", client->name,
+             client->username, client->host);
+  else if (IsHidden(client) || ConfigServerHide.hide_servers)
     strlcpy(ban->who, me.name, sizeof(ban->who));
   else
-    strlcpy(ban->who, client_p->name, sizeof(ban->who));
+    strlcpy(ban->who, client->name, sizeof(ban->who));
 
   dlinkAdd(ban, &ban->node, list);
 
-  return true;
+  return ban->banstr;
 }
 
 /*
@@ -167,49 +238,30 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, dlink_list *
  * output	- 0 for failure, 1 for success
  * side effects	-
  */
-static bool
-del_id(struct Channel *chptr, char *banid, dlink_list *list)
+static const char *
+del_id(struct Client *client, struct Channel *channel, const char *banid, dlink_list *list, unsigned int type)
 {
+  static char mask[MODEBUFLEN];
   dlink_node *node;
-  char name[NICKLEN + 1] = "";
-  char user[USERLEN + 1] = "";
-  char host[HOSTLEN + 1] = "";
-  struct split_nuh_item nuh;
-
   assert(banid);
 
-  nuh.nuhmask  = check_string(banid);
-  nuh.nickptr  = name;
-  nuh.userptr  = user;
-  nuh.hostptr  = host;
-
-  nuh.nicksize = sizeof(name);
-  nuh.usersize = sizeof(user);
-  nuh.hostsize = sizeof(host);
-
-  split_nuh(&nuh);
-
-  /*
-   * Re-assemble a new n!u@h and print it back to banid for sending
-   * the mode to the channel.
-   */
-  snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
+  /* TBD: n!u@h formatting fo local clients */
 
   DLINK_FOREACH(node, list->head)
   {
     struct Ban *ban = node->data;
 
-    if (irccmp(name, ban->name) == 0 &&
-        irccmp(user, ban->user) == 0 &&
-        irccmp(host, ban->host) == 0)
+    if (irccmp(banid, ban->banstr) == 0)
     {
-      clear_ban_cache_list(&chptr->members_local);
+      strlcpy(mask, ban->banstr, sizeof(mask));  /* caSe might be different in 'banid' */
+      clear_ban_cache_list(&channel->members_local);
       remove_ban(ban, list);
-      return true;
+
+      return mask;
     }
   }
 
-  return false;
+  return NULL;
 }
 
 /* channel_modes()
@@ -220,32 +272,32 @@ del_id(struct Channel *chptr, char *banid, dlink_list *list)
  *              - pointer to parameter buf
  * output       - NONE
  * side effects - write the "simple" list of channel modes for channel
- * chptr onto buffer mbuf with the parameters in pbuf.
+ * channel onto buffer mbuf with the parameters in pbuf.
  */
 void
-channel_modes(const struct Channel *chptr, const struct Client *client_p, char *mbuf, char *pbuf)
+channel_modes(const struct Channel *channel, const struct Client *client, char *mbuf, char *pbuf)
 {
   *mbuf++ = '+';
   *pbuf = '\0';
 
   for (const struct chan_mode *tab = cmode_tab; tab->letter; ++tab)
-    if (tab->mode && HasCMode(chptr, tab->mode))
+    if (tab->mode && HasCMode(channel, tab->mode))
       *mbuf++ = tab->letter;
 
-  if (chptr->mode.limit)
+  if (channel->mode.limit)
   {
     *mbuf++ = 'l';
 
-    if (IsServer(client_p) || IsMember(client_p, chptr))
-      pbuf += sprintf(pbuf, "%u ", chptr->mode.limit);
+    if (IsServer(client) || IsMember(client, channel))
+      pbuf += sprintf(pbuf, "%u ", channel->mode.limit);
   }
 
-  if (chptr->mode.key[0])
+  if (channel->mode.key[0])
   {
     *mbuf++ = 'k';
 
-    if (IsServer(client_p) || IsMember(client_p, chptr))
-      sprintf(pbuf, "%s ", chptr->mode.key);
+    if (IsServer(client) || IsMember(client, channel))
+      sprintf(pbuf, "%s ", channel->mode.key);
   }
 
   *mbuf = '\0';
@@ -288,8 +340,8 @@ clear_ban_cache_list(dlink_list *list)
 
   DLINK_FOREACH(node, list->head)
   {
-    struct Membership *member = node->data;
-    member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED);
+    struct ChannelMember *member = node->data;
+    member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED | CHFL_MUTE_CHECKED);
   }
 }
 
@@ -311,26 +363,26 @@ enum
 
 /* Mode functions handle mode changes for a particular mode... */
 static void
-chm_nosuch(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_nosuch(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
            int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
   if (*errors & SM_ERR_UNKNOWN)
     return;
 
   *errors |= SM_ERR_UNKNOWN;
-  sendto_one_numeric(source_p, &me, ERR_UNKNOWNMODE, c);
+  sendto_one_numeric(client, &me, ERR_UNKNOWNMODE, c);
 }
 
 static void
-chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_simple(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
            int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
   if (mode->only_opers)
   {
-    if (MyClient(source_p) && !HasUMode(source_p, UMODE_OPER))
+    if (MyClient(client) && !HasUMode(client, UMODE_OPER))
     {
       if (!(*errors & SM_ERR_NOTOPER))
-        sendto_one_numeric(source_p, &me, ERR_NOPRIVILEGES);
+        sendto_one_numeric(client, &me, ERR_NOPRIVILEGES);
 
       *errors |= SM_ERR_NOTOPER;
       return;
@@ -339,12 +391,12 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (mode->only_servers)
   {
-    if (!IsServer(source_p) && !HasFlag(source_p, FLAGS_SERVICE))
+    if (!IsServer(client) && !HasFlag(client, FLAGS_SERVICE))
     {
       if (!(*errors & SM_ERR_ONLYSERVER))
-        sendto_one_numeric(source_p, &me,
+        sendto_one_numeric(client, &me,
                            alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                           ERR_ONLYSERVERSCANCHANGE, chptr->name);
+                           ERR_ONLYSERVERSCANCHANGE, channel->name);
 
       *errors |= SM_ERR_ONLYSERVER;
       return;
@@ -354,9 +406,9 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
+      sendto_one_numeric(client, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
+                         ERR_CHANOPRIVSNEEDED, channel->name);
 
     *errors |= SM_ERR_NOOPS;
     return;
@@ -370,17 +422,17 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_ADD)  /* setting + */
   {
-    if (MyClient(source_p) && HasCMode(chptr, mode->mode))
+    if (MyClient(client) && HasCMode(channel, mode->mode))
       return;
 
-    AddCMode(chptr, mode->mode);
+    AddCMode(channel, mode->mode);
   }
   else if (dir == MODE_DEL)  /* setting - */
   {
-    if (MyClient(source_p) && !HasCMode(chptr, mode->mode))
+    if (MyClient(client) && !HasCMode(channel, mode->mode))
       return;
 
-    DelCMode(chptr, mode->mode);
+    DelCMode(channel, mode->mode);
   }
 
   mode_changes[mode_count].letter = mode->letter;
@@ -391,9 +443,10 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 }
 
 static void
-chm_mask(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_mask(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
          int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
+  const char *ret = NULL;
   dlink_list *list;
   enum irc_numerics rpl_list = 0, rpl_endlist = 0;
   int errtype = 0;
@@ -402,19 +455,19 @@ chm_mask(struct Client *source_p, struct Channel *chptr, int parc, int *parn, ch
   {
     case CHFL_BAN:
       errtype = SM_ERR_RPL_B;
-      list = &chptr->banlist;
+      list = &channel->banlist;
       rpl_list = RPL_BANLIST;
       rpl_endlist = RPL_ENDOFBANLIST;
       break;
     case CHFL_EXCEPTION:
       errtype = SM_ERR_RPL_E;
-      list = &chptr->exceptlist;
+      list = &channel->exceptlist;
       rpl_list = RPL_EXCEPTLIST;
       rpl_endlist = RPL_ENDOFEXCEPTLIST;
       break;
     case CHFL_INVEX:
       errtype = SM_ERR_RPL_I;
-      list = &chptr->invexlist;
+      list = &channel->invexlist;
       rpl_list = RPL_INVEXLIST;
       rpl_endlist = RPL_ENDOFINVEXLIST;
       break;
@@ -435,52 +488,56 @@ chm_mask(struct Client *source_p, struct Channel *chptr, int parc, int *parn, ch
     {
       const struct Ban *ban = node->data;
 
-      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= mode->required_oplevel)
-        sendto_one_numeric(source_p, &me, rpl_list, chptr->name,
-                           ban->name, ban->user, ban->host,
-                           ban->who, ban->when);
+      if (!HasCMode(channel, MODE_HIDEBMASKS) || alev >= mode->required_oplevel)
+        sendto_one_numeric(client, &me, rpl_list, channel->name,
+                           ban->banstr, ban->who, ban->when);
     }
 
-    sendto_one_numeric(source_p, &me, rpl_endlist, chptr->name);
+    sendto_one_numeric(client, &me, rpl_endlist, channel->name);
     return;
   }
 
   if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
+      sendto_one_numeric(client, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
+                         ERR_CHANOPRIVSNEEDED, channel->name);
 
     *errors |= SM_ERR_NOOPS;
     return;
   }
 
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
+  if (MyClient(client) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  char *const mask = nuh_mask[*parn];
-  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
+  char *mask = parv[*parn];
   ++(*parn);
 
-  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
+  if (*mask == ':' || (!MyConnect(client) && strchr(mask, ' ')))
     return;
 
   if (dir == MODE_ADD)  /* setting + */
   {
-    if (add_id(source_p, chptr, mask, list) == false)
+    ret = add_id(client, channel, mask, list, mode->flag);
+    if (ret == NULL)
       return;
   }
   else if (dir == MODE_DEL)  /* setting - */
   {
-    if (del_id(chptr, mask, list) == false)
+    ret = del_id(client, channel, mask, list, mode->flag);
+    if (ret == NULL)
       return;
   }
 
+  static char buf[MAXPARA][MODEBUFLEN];
+  mask = buf[(*parn) - 1];
+  strlcpy(mask, ret, sizeof(buf[(*parn) - 1]));
+
   mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
+  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than MODEBUFLEN */
   mode_changes[mode_count].id = NULL;
-  if (HasCMode(chptr, MODE_HIDEBMASKS))
+  if (HasCMode(channel, MODE_HIDEBMASKS))
     mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
   else
     mode_changes[mode_count].flags = 0;
@@ -488,18 +545,15 @@ chm_mask(struct Client *source_p, struct Channel *chptr, int parc, int *parn, ch
 }
 
 static void
-chm_flag(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_flag(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
          int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
-  struct Client *target_p;
-  struct Membership *member;
-
   if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
+      sendto_one_numeric(client, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
+                         ERR_CHANOPRIVSNEEDED, channel->name);
 
     *errors |= SM_ERR_NOOPS;
     return;
@@ -508,19 +562,21 @@ chm_flag(struct Client *source_p, struct Channel *chptr, int parc, int *parn, ch
   if (dir == MODE_QUERY || parc <= *parn)
     return;
 
-  if ((target_p = find_chasing(source_p, parv[(*parn)++])) == NULL)
+  struct Client *client_target = find_chasing(client, parv[(*parn)++]);
+  if (client_target == NULL)
     return;  /* find_chasing sends ERR_NOSUCHNICK */
 
-  if ((member = find_channel_link(target_p, chptr)) == NULL)
+  struct ChannelMember *member = find_channel_link(client_target, channel);
+  if (member == NULL)
   {
     if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
+      sendto_one_numeric(client, &me, ERR_USERNOTINCHANNEL, client_target->name, channel->name);
 
     *errors |= SM_ERR_NOTONCHANNEL;
     return;
   }
 
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
+  if (MyClient(client) && (++mode_limit > MAXMODEPARAMS))
     return;
 
   if (dir == MODE_ADD)  /* setting + */
@@ -539,22 +595,22 @@ chm_flag(struct Client *source_p, struct Channel *chptr, int parc, int *parn, ch
   }
 
   mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = target_p->name;
-  mode_changes[mode_count].id = target_p->id;
+  mode_changes[mode_count].arg = client_target->name;
+  mode_changes[mode_count].id = client_target->id;
   mode_changes[mode_count].flags = 0;
   mode_changes[mode_count++].dir = dir;
 }
 
 static void
-chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_limit(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
           int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
   if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
+      sendto_one_numeric(client, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
+                         ERR_CHANOPRIVSNEEDED, channel->name);
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -583,14 +639,14 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn, c
     mode_changes[mode_count].flags = 0;
     mode_changes[mode_count++].dir = dir;
 
-    chptr->mode.limit = limit;
+    channel->mode.limit = limit;
   }
   else if (dir == MODE_DEL)
   {
-    if (chptr->mode.limit == 0)
+    if (channel->mode.limit == 0)
       return;
 
-    chptr->mode.limit = 0;
+    channel->mode.limit = 0;
 
     mode_changes[mode_count].letter = mode->letter;
     mode_changes[mode_count].arg = NULL;
@@ -601,15 +657,15 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn, c
 }
 
 static void
-chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+chm_key(struct Client *client, struct Channel *channel, int parc, int *parn, char **parv,
         int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
   if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
+      sendto_one_numeric(client, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
+                         ERR_CHANOPRIVSNEEDED, channel->name);
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -625,7 +681,7 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn, cha
       return;
 
     assert(key[0] != ' ');
-    strlcpy(chptr->mode.key, key, sizeof(chptr->mode.key));
+    strlcpy(channel->mode.key, key, sizeof(channel->mode.key));
 
     /* If somebody does MODE #channel +kk a b, accept latter --fl */
     for (unsigned int i = 0; i < mode_count; ++i)
@@ -643,10 +699,10 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn, cha
     if (parc > *parn)
       ++(*parn);
 
-    if (chptr->mode.key[0] == '\0')
+    if (channel->mode.key[0] == '\0')
       return;
 
-    chptr->mode.key[0] = '\0';
+    channel->mode.key[0] = '\0';
 
     mode_changes[mode_count].letter = mode->letter;
     mode_changes[mode_count].arg = "*";
@@ -665,18 +721,18 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn, cha
  * side effects - NONE
  */
 static int
-get_channel_access(const struct Client *source_p,
-                   const struct Membership *member)
+get_channel_access(const struct Client *client,
+                   const struct ChannelMember *member)
 {
   /* Let hacked servers in for now... */
-  if (!MyClient(source_p))
+  if (!MyClient(client))
     return CHACCESS_REMOTE;
 
   if (member == NULL)
     return CHACCESS_NOTONCHAN;
 
   /* Just to be sure.. */
-  assert(source_p == member->client_p);
+  assert(client == member->client);
 
   if (has_member_flags(member, CHFL_CHANOP))
     return CHACCESS_CHANOP;
@@ -688,14 +744,14 @@ get_channel_access(const struct Client *source_p,
 }
 
 /* send_mode_changes_server()
- * Input: the source client(source_p),
- *        the channel to send mode changes for(chptr)
+ * Input: the source client(client),
+ *        the channel to send mode changes for(channel)
  * Output: None.
  * Side-effects: Sends the appropriate mode changes to servers.
  *
  */
 static void
-send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
+send_mode_changes_server(struct Client *client, struct Channel *channel)
 {
   char modebuf[IRCD_BUFSIZE] = "";
   char parabuf[IRCD_BUFSIZE] = "";
@@ -704,7 +760,7 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
   unsigned int dir = MODE_QUERY;
 
   mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ",
-                 source_p->id, chptr->creationtime, chptr->name);
+                 client->id, channel->creation_time, channel->name);
 
   /* Loop the list of modes we have */
   for (unsigned int i = 0; i < mode_count; ++i)
@@ -731,13 +787,13 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
         ((arglen + mbl + pbl + 2 /* +2 for /r/n */ ) > IRCD_BUFSIZE))
     {
       if (modecount)
-        sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
+        sendto_server(client, 0, 0, "%s %s", modebuf, parabuf);
 
       modecount = 0;
       paracount = 0;
 
       mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ",
-                     source_p->id, chptr->creationtime, chptr->name);
+                     client->id, channel->creation_time, channel->name);
 
       pbl = 0;
       parabuf[0] = '\0';
@@ -765,21 +821,21 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
   }
 
   if (modecount)
-    sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
+    sendto_server(client, 0, 0, "%s %s", modebuf, parabuf);
 }
 
-/* void send_mode_changes(struct Client *client_p,
- *                        struct Client *source_p,
- *                        struct Channel *chptr)
- * Input: The client sending(client_p), the source client(source_p),
- *        the channel to send mode changes for(chptr),
+/* void send_mode_changes(struct Client *client,
+ *                        struct Client *client,
+ *                        struct Channel *channel)
+ * Input: The client sending(client), the source client(client),
+ *        the channel to send mode changes for(channel),
  *        mode change globals.
  * Output: None.
  * Side-effects: Sends the appropriate mode changes to other clients
  *               and propagates to servers.
  */
 static void
-send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
+send_mode_changes_client(struct Client *client, struct Channel *channel)
 {
   unsigned int flags = 0;
 
@@ -791,13 +847,13 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
     unsigned int mbl = 0, pbl = 0, arglen = 0, modecount = 0, paracount = 0;
     unsigned int dir = MODE_QUERY;
 
-    if (IsClient(source_p))
-      mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                     source_p->username, source_p->host, chptr->name);
+    if (IsClient(client))
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", client->name,
+                     client->username, client->host, channel->name);
     else
-      mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(client) ||
                      ConfigServerHide.hide_servers) ?
-                     me.name : source_p->name, chptr->name);
+                     me.name : client->name, channel->name);
 
     for (unsigned int i = 0; i < mode_count; ++i)
     {
@@ -814,18 +870,18 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
           ((arglen + mbl + pbl + 2 /* +2 for /r/n */ ) > IRCD_BUFSIZE))
       {
         if (modecount)
-          sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
+          sendto_channel_local(NULL, channel, flags, 0, 0, "%s %s", modebuf, parabuf);
 
         modecount = 0;
         paracount = 0;
 
-        if (IsClient(source_p))
-          mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                         source_p->username, source_p->host, chptr->name);
+        if (IsClient(client))
+          mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", client->name,
+                         client->username, client->host, channel->name);
         else
-          mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
+          mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(client) ||
                          ConfigServerHide.hide_servers) ?
-                         me.name : source_p->name, chptr->name);
+                         me.name : client->name, channel->name);
 
         pbl = 0;
         parabuf[0] = '\0';
@@ -853,7 +909,7 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
     }
 
     if (modecount)
-      sendto_channel_local(NULL, chptr, flags, 0, 0, "%s %s", modebuf, parabuf);
+      sendto_channel_local(NULL, channel, flags, 0, 0, "%s %s", modebuf, parabuf);
   }
 }
 
@@ -883,7 +939,7 @@ const struct chan_mode  cmode_tab[] =
   { .letter = 'N', .mode = MODE_NONICKCHANGE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = 'O', .mode = MODE_OPERONLY, .required_oplevel = CHACCESS_HALFOP, .only_opers = true, .func = chm_simple },
   { .letter = 'R', .mode = MODE_REGONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
-  { .letter = 'S', .mode = MODE_SSLONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'S', .mode = MODE_SECUREONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = 'T', .mode = MODE_NONOTICE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = '\0', .mode = 0 }
 };
@@ -905,8 +961,8 @@ channel_mode_init(void)
  *               clients.
  */
 void
-channel_mode_set(struct Client *source_p, struct Channel *chptr,
-                 struct Membership *member, int parc, char *parv[])
+channel_mode_set(struct Client *client, struct Channel *channel,
+                 struct ChannelMember *member, int parc, char *parv[])
 {
   int dir = MODE_ADD;
   int parn = 1;
@@ -916,7 +972,7 @@ channel_mode_set(struct Client *source_p, struct Channel *chptr,
   mode_limit = 0;
   simple_modes_mask = 0;
 
-  alevel = get_channel_access(source_p, member);
+  alevel = get_channel_access(client, member);
 
   for (const char *ml = parv[0]; *ml; ++ml)
   {
@@ -936,9 +992,9 @@ channel_mode_set(struct Client *source_p, struct Channel *chptr,
         const struct chan_mode *mode = cmode_map[(unsigned char)*ml];
 
         if (mode)
-          mode->func(source_p, chptr, parc, &parn, parv, &errors, alevel, dir, *ml, mode);
+          mode->func(client, channel, parc, &parn, parv, &errors, alevel, dir, *ml, mode);
         else
-          chm_nosuch(source_p, chptr, parc, &parn, parv, &errors, alevel, dir, *ml, NULL);
+          chm_nosuch(client, channel, parc, &parn, parv, &errors, alevel, dir, *ml, NULL);
         break;
       }
     }
@@ -948,6 +1004,6 @@ channel_mode_set(struct Client *source_p, struct Channel *chptr,
   if (mode_count == 0)
     return;
 
-  send_mode_changes_client(source_p, chptr);
-  send_mode_changes_server(source_p, chptr);
+  send_mode_changes_client(client, channel);
+  send_mode_changes_server(client, channel);
 }
