@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 8970 2019-05-18 11:58:17Z michael $
+ * \version $Id: conf.c 9332 2020-04-11 17:01:20Z michael $
  */
 
 #include "stdinc.h"
@@ -98,29 +98,57 @@ conf_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
   conf->dns_pending = false;
 
   if (addr)
-    memcpy(conf->addr, addr, sizeof(*conf->addr));
+    *conf->addr = *addr;
   else
     conf->dns_failed = true;
 }
 
-/* conf_dns_lookup()
+/* conf_resolve_host()
  *
- * do a nameserver lookup of the conf host
- * if the conf entry is currently doing a ns lookup do nothing, otherwise
- * allocate a dns_query and start ns lookup.
+ * start DNS lookups of all hostnames in the conf
+ * line and convert an IP addresses in a.b.c.d number for to IP#s.
  */
-static void
+void
 conf_dns_lookup(struct MaskItem *conf)
 {
-  if (conf->dns_pending == true)
+  struct addrinfo hints, *res;
+
+  /*
+   * Do name lookup now on hostnames given and store the
+   * ip numbers in conf structure.
+   */
+  memset(&hints, 0, sizeof(hints));
+
+  hints.ai_family = AF_UNSPEC;
+  hints.ai_socktype = SOCK_STREAM;
+
+  /* Get us ready for a bind() and don't bother doing dns lookup */
+  hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
+
+  if (getaddrinfo(conf->host, NULL, &hints, &res))
+  {
+    /*
+     * By this point conf->host possibly is not a numerical network address. Do a nameserver
+     * lookup of the conf host. If the conf entry is currently doing a ns lookup do nothing.
+     */
+    if (conf->dns_pending == true)
+      return;
+
+    conf->dns_pending = true;
+
+    if (conf->aftype == AF_INET)
+      gethost_byname_type(conf_dns_callback, conf, conf->host, T_A);
+    else
+      gethost_byname_type(conf_dns_callback, conf, conf->host, T_AAAA);
     return;
+  }
 
-  conf->dns_pending = true;
+  assert(res);
 
-  if (conf->aftype == AF_INET)
-    gethost_byname_type(conf_dns_callback, conf, conf->host, T_A);
-  else
-    gethost_byname_type(conf_dns_callback, conf, conf->host, T_AAAA);
+  memcpy(conf->addr, res->ai_addr, res->ai_addrlen);
+  conf->addr->ss_len = res->ai_addrlen;
+
+  freeaddrinfo(res);
 }
 
 /* map_to_list()
@@ -216,14 +244,14 @@ conf_free(struct MaskItem *conf)
  * side effects - do actual attach
  */
 static int
-attach_iline(struct Client *client_p, struct MaskItem *conf)
+attach_iline(struct Client *client, struct MaskItem *conf)
 {
   const struct ClassItem *const class = conf->class;
   bool a_limit_reached = false;
 
-  struct ip_entry *ipcache = ipcache_record_find_or_add(&client_p->ip);
+  struct ip_entry *ipcache = ipcache_record_find_or_add(&client->ip);
   ++ipcache->count_local;
-  AddFlag(client_p, FLAGS_IPHASH);
+  AddFlag(client, FLAGS_IPHASH);
 
   if (class->max_total && class->ref_count >= class->max_total)
     a_limit_reached = true;
@@ -238,11 +266,11 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
     if (!IsConfExemptLimits(conf))
       return TOO_MANY;   /* Already at maximum allowed */
 
-    sendto_one_notice(client_p, &me, ":*** Your connection class is full, "
+    sendto_one_notice(client, &me, ":*** Your connection class is full, "
                       "but you have exceed_limit = yes;");
   }
 
-  return conf_attach(client_p, conf);
+  return conf_attach(client, conf);
 }
 
 /* verify_access()
@@ -252,20 +280,20 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
  * side effect  - find the first (best) I line to attach.
  */
 static int
-verify_access(struct Client *client_p)
+verify_access(struct Client *client)
 {
   struct MaskItem *conf;
 
-  if (HasFlag(client_p, FLAGS_GOTID))
-    conf = find_address_conf(client_p->host, client_p->username, &client_p->ip,
-                             client_p->connection->password);
+  if (HasFlag(client, FLAGS_GOTID))
+    conf = find_address_conf(client->host, client->username, &client->ip,
+                             client->connection->password);
   else
   {
     char non_ident[USERLEN + 1] = "~";
 
-    strlcpy(non_ident + 1, client_p->username, sizeof(non_ident) - 1);
-    conf = find_address_conf(client_p->host, non_ident, &client_p->ip,
-                             client_p->connection->password);
+    strlcpy(non_ident + 1, client->username, sizeof(non_ident) - 1);
+    conf = find_address_conf(client->host, non_ident, &client->ip,
+                             client->connection->password);
   }
 
   if (conf == NULL)
@@ -275,28 +303,22 @@ verify_access(struct Client *client_p)
 
   if (IsConfKill(conf))
   {
-    sendto_one_notice(client_p, &me, ":*** Banned: %s", conf->reason);
+    sendto_one_notice(client, &me, ":*** Banned: %s", conf->reason);
     return BANNED_CLIENT;
   }
 
   if (IsConfRedir(conf))
   {
-    sendto_one_numeric(client_p, &me, RPL_REDIR,
+    sendto_one_numeric(client, &me, RPL_REDIR,
                        conf->name ? conf->name : "",
                        conf->port);
     return NOT_AUTHORIZED;
   }
 
   if (IsConfDoSpoofIp(conf))
-  {
-    if (IsConfSpoofNotice(conf))
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE, "%s spoofing: %s as %s",
-                           client_p->name, client_p->host, conf->name);
+    strlcpy(client->host, conf->name, sizeof(client->host));
 
-    strlcpy(client_p->host, conf->name, sizeof(client_p->host));
-  }
-
-  return attach_iline(client_p, conf);
+  return attach_iline(client, conf);
 }
 
 /* check_client()
@@ -312,37 +334,37 @@ verify_access(struct Client *client_p)
  *		  Look for conf lines which have the same
  * 		  status as the flags passed.
  */
-int
-check_client(struct Client *source_p)
+bool
+conf_check_client(struct Client *client)
 {
   int i;
 
-  if ((i = verify_access(source_p)))
+  if ((i = verify_access(client)))
     ilog(LOG_TYPE_IRCD, "Access denied: %s[%s]",
-         source_p->name, source_p->sockhost);
+         client->name, client->sockhost);
 
   switch (i)
   {
     case TOO_MANY:
       sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                            "Too many on IP for %s (%s).",
-                           client_get_name(source_p, SHOW_IP),
-                           source_p->sockhost);
+                           client_get_name(client, SHOW_IP),
+                           client->sockhost);
       ilog(LOG_TYPE_IRCD, "Too many connections on IP from %s.",
-           client_get_name(source_p, SHOW_IP));
+           client_get_name(client, SHOW_IP));
       ++ServerStats.is_ref;
-      exit_client(source_p, "No more connections allowed on that IP");
+      exit_client(client, "No more connections allowed on that IP");
       break;
 
     case I_LINE_FULL:
       sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                            "auth {} block is full for %s (%s).",
-                           client_get_name(source_p, SHOW_IP),
-                           source_p->sockhost);
+                           client_get_name(client, SHOW_IP),
+                           client->sockhost);
       ilog(LOG_TYPE_IRCD, "Too many connections from %s.",
-           client_get_name(source_p, SHOW_IP));
+           client_get_name(client, SHOW_IP));
       ++ServerStats.is_ref;
-      exit_client(source_p, "No more connections allowed in your connection class");
+      exit_client(client, "No more connections allowed in your connection class");
       break;
 
     case NOT_AUTHORIZED:
@@ -350,21 +372,21 @@ check_client(struct Client *source_p)
       /*       a purely cosmetical change */
       sendto_realops_flags(UMODE_UNAUTH, L_ALL, SEND_NOTICE,
                            "Unauthorized client connection from %s on [%s/%u].",
-                           client_get_name(source_p, SHOW_IP),
-                           source_p->connection->listener->name,
-                           source_p->connection->listener->port);
+                           client_get_name(client, SHOW_IP),
+                           client->connection->listener->name,
+                           client->connection->listener->port);
       ilog(LOG_TYPE_IRCD, "Unauthorized client connection from %s on [%s/%u].",
-           client_get_name(source_p, SHOW_IP),
-           source_p->connection->listener->name,
-           source_p->connection->listener->port);
+           client_get_name(client, SHOW_IP),
+           client->connection->listener->name,
+           client->connection->listener->port);
 
       ++ServerStats.is_ref;
-      exit_client(source_p, "You are not authorized to use this server");
+      exit_client(client, "You are not authorized to use this server");
       break;
 
     case BANNED_CLIENT:
       ++ServerStats.is_ref;
-      exit_client(source_p, "Banned");
+      exit_client(client, "Banned");
       break;
 
     case 0:
@@ -372,20 +394,22 @@ check_client(struct Client *source_p)
       break;
   }
 
-  return !(i < 0);
+  if (i < 0)
+    return false;
+  return true;
 }
 
 /*! \brief Disassociate configuration from the client. Also removes a class
  *         from the list if marked for deleting.
- * \param client_p Client to operate on
+ * \param client Client to operate on
  * \param type     Type of conf to detach
  */
 void
-conf_detach(struct Client *client_p, enum maskitem_type type)
+conf_detach(struct Client *client, enum maskitem_type type)
 {
   dlink_node *node, *node_next;
 
-  DLINK_FOREACH_SAFE(node, node_next, client_p->connection->confs.head)
+  DLINK_FOREACH_SAFE(node, node_next, client->connection->confs.head)
   {
     struct MaskItem *conf = node->data;
 
@@ -396,11 +420,11 @@ conf_detach(struct Client *client_p, enum maskitem_type type)
     if (!(conf->type & type))
       continue;
 
-    dlinkDelete(node, &client_p->connection->confs);
+    dlinkDelete(node, &client->connection->confs);
     free_dlink_node(node);
 
     if (conf->type == CONF_CLIENT)
-      class_ip_limit_remove(conf->class, &client_p->ip);
+      class_ip_limit_remove(conf->class, &client->ip);
 
     if (--conf->class->ref_count == 0 && conf->class->active == false)
     {
@@ -416,23 +440,23 @@ conf_detach(struct Client *client_p, enum maskitem_type type)
 /*! \brief Associate a specific configuration entry to a *local* client (this
  *         is the one which used in accepting the connection). Note, that this
  *         automatically changes the attachment if there was an old one.
- * \param client_p Client to attach the conf to
+ * \param client Client to attach the conf to
  * \param conf Configuration record to attach
  */
 int
-conf_attach(struct Client *client_p, struct MaskItem *conf)
+conf_attach(struct Client *client, struct MaskItem *conf)
 {
-  if (dlinkFind(&client_p->connection->confs, conf))
+  if (dlinkFind(&client->connection->confs, conf))
     return 1;
 
   if (conf->type == CONF_CLIENT)
-    if (class_ip_limit_add(conf->class, &client_p->ip, IsConfExemptLimits(conf)) == true)
+    if (class_ip_limit_add(conf->class, &client->ip, IsConfExemptLimits(conf)) == true)
       return TOO_MANY;    /* Already at maximum allowed */
 
   conf->class->ref_count++;
   conf->ref_count++;
 
-  dlinkAdd(conf, make_dlink_node(), &client_p->connection->confs);
+  dlinkAdd(conf, make_dlink_node(), &client->connection->confs);
 
   return 0;
 }
@@ -478,7 +502,7 @@ connect_find(const char *name, int (*compare)(const char *, const char *))
   {
     struct MaskItem *conf = node->data;
 
-    if (!compare(name, conf->name))
+    if (compare(name, conf->name) == 0)
       return conf;
   }
 
@@ -497,36 +521,36 @@ connect_find(const char *name, int (*compare)(const char *, const char *))
 struct MaskItem *
 operator_find(const struct Client *who, const char *name)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, operator_items.head)
   {
     struct MaskItem *conf = node->data;
 
-    if (!irccmp(conf->name, name))
+    if (irccmp(conf->name, name) == 0)
     {
-      if (!who)
+      if (who == NULL)
         return conf;
 
-      if (!match(conf->user, who->username))
+      if (match(conf->user, who->username) == 0)
       {
         switch (conf->htype)
         {
           case HM_HOST:
-            if (!match(conf->host, who->host) || !match(conf->host, who->sockhost))
-              if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
+            if (match(conf->host, who->host) == 0 || match(conf->host, who->sockhost) == 0)
+              if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
                 return conf;
             break;
           case HM_IPV4:
             if (who->ip.ss.ss_family == AF_INET)
               if (match_ipv4(&who->ip, conf->addr, conf->bits))
-                if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
+                if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
                   return conf;
             break;
           case HM_IPV6:
             if (who->ip.ss.ss_family == AF_INET6)
               if (match_ipv6(&who->ip, conf->addr, conf->bits))
-                if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
+                if (conf->class->max_total == 0 || conf->class->ref_count < conf->class->max_total)
                   return conf;
             break;
           default:
@@ -539,7 +563,7 @@ operator_find(const struct Client *who, const char *name)
   return NULL;
 }
 
-/* set_default_conf()
+/* conf_set_defaults()
  *
  * inputs	- NONE
  * output	- NONE
@@ -549,10 +573,11 @@ operator_find(const struct Client *who, const char *name)
  *		  of values later, put them in validate_conf().
  */
 static void
-set_default_conf(void)
+conf_set_defaults(void)
 {
-  /* verify init_class() ran, this should be an unnecessary check
-   * but its not much work.
+  /*
+   * Verify init_class() ran, this should be an unnecessary check
+   * but it's not much work.
    */
   assert(class_default == class_get_list()->tail->data);
 
@@ -567,6 +592,7 @@ set_default_conf(void)
 
   ConfigLog.use_logging = 1;
 
+  ConfigChannel.enable_extbans = 0;
   ConfigChannel.disable_fake_channels = 0;
   ConfigChannel.invite_client_count = 10;
   ConfigChannel.invite_client_time = 300;
@@ -641,7 +667,7 @@ set_default_conf(void)
 }
 
 static void
-validate_conf(void)
+conf_validate(void)
 {
   if (EmptyString(ConfigServerInfo.network_name))
     ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
@@ -650,18 +676,18 @@ validate_conf(void)
     ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
 }
 
-/* read_conf()
+/* conf_read()
  *
  * inputs       - file descriptor pointing to config file to use
  * output       - None
  * side effects	- Read configuration file.
  */
 static void
-read_conf(FILE *file)
+conf_read(FILE *file)
 {
   lineno = 1;
 
-  set_default_conf();  /* Set default values prior to conf parsing */
+  conf_set_defaults();  /* Set default values prior to conf parsing */
   conf_parser_ctx.pass = 1;
   yyparse();  /* Pick up the classes first */
 
@@ -669,7 +695,7 @@ read_conf(FILE *file)
 
   conf_parser_ctx.pass = 2;
   yyparse();  /* Load the values from the conf */
-  validate_conf();  /* Check to make sure some values are still okay. */
+  conf_validate();  /* Check to make sure some values are still okay. */
                     /* Some global values are also loaded here. */
   whowas_trim();  /* Attempt to trim whowas list if necessary */
   class_delete_marked();  /* Delete unused classes that are marked for deletion */
@@ -695,48 +721,12 @@ conf_rehash(bool sig)
 
   /* don't close listeners until we know we can go ahead with the rehash */
 
-  read_conf_files(false);
+  conf_read_files(false);
 
   load_conf_modules();
   check_conf_klines();
 }
 
-/* lookup_confhost()
- *
- * start DNS lookups of all hostnames in the conf
- * line and convert an IP addresses in a.b.c.d number for to IP#s.
- */
-void
-lookup_confhost(struct MaskItem *conf)
-{
-  struct addrinfo hints, *res;
-
-  /*
-   * Do name lookup now on hostnames given and store the
-   * ip numbers in conf structure.
-   */
-  memset(&hints, 0, sizeof(hints));
-
-  hints.ai_family   = AF_UNSPEC;
-  hints.ai_socktype = SOCK_STREAM;
-
-  /* Get us ready for a bind() and don't bother doing dns lookup */
-  hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
-
-  if (getaddrinfo(conf->host, NULL, &hints, &res))
-  {
-    conf_dns_lookup(conf);
-    return;
-  }
-
-  assert(res);
-
-  memcpy(conf->addr, res->ai_addr, res->ai_addrlen);
-  conf->addr->ss_len = res->ai_addrlen;
-
-  freeaddrinfo(res);
-}
-
 /* conf_connect_allowed()
  *
  * inputs	- pointer to inaddr
@@ -747,7 +737,6 @@ lookup_confhost(struct MaskItem *conf)
 int
 conf_connect_allowed(struct irc_ssaddr *addr)
 {
-  struct ip_entry *ip_found = NULL;
   const struct MaskItem *conf = find_dline_conf(addr);
 
   if (conf)
@@ -758,8 +747,7 @@ conf_connect_allowed(struct irc_ssaddr *addr)
     return BANNED_CLIENT;
   }
 
-  ip_found = ipcache_record_find_or_add(addr);
-
+  struct ip_entry *ip_found = ipcache_record_find_or_add(addr);
   if ((event_base->time.sec_monotonic - ip_found->last_attempt) < ConfigGeneral.throttle_time)
   {
     if (ip_found->connection_count >= ConfigGeneral.throttle_count)
@@ -796,16 +784,16 @@ cleanup_tklines(void *unused)
  * Side effects: None.
  */
 const char *
-get_oper_name(const struct Client *client_p)
+get_oper_name(const struct Client *client)
 {
   static char buffer[IRCD_BUFSIZE];
 
-  if (IsServer(client_p))
-    return client_p->name;
+  if (IsServer(client))
+    return client->name;
 
-  if (MyConnect(client_p))
+  if (MyConnect(client))
   {
-    const dlink_node *const node = client_p->connection->confs.head;
+    const dlink_node *const node = client->connection->confs.head;
 
     if (node)
     {
@@ -813,8 +801,8 @@ get_oper_name(const struct Client *client_p)
 
       if (conf->type == CONF_OPER)
       {
-        snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client_p->name,
-                 client_p->username, client_p->host, conf->name);
+        snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client->name,
+                 client->username, client->host, conf->name);
         return buffer;
       }
     }
@@ -826,19 +814,19 @@ get_oper_name(const struct Client *client_p)
     assert(0);  /* Oper without oper conf! */
   }
 
-  snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client_p->name,
-           client_p->username, client_p->host, client_p->servptr->name);
+  snprintf(buffer, sizeof(buffer), "%s!%s@%s{%s}", client->name,
+           client->username, client->host, client->servptr->name);
   return buffer;
 }
 
-/* clear_out_old_conf()
+/* conf_clear()
  *
  * inputs       - none
  * output       - none
  * side effects - Clear out the old configuration
  */
 static void
-clear_out_old_conf(void)
+conf_clear(void)
 {
   dlink_node *node = NULL, *node_next = NULL;
   dlink_list *free_items [] = {
@@ -848,7 +836,7 @@ clear_out_old_conf(void)
   dlink_list ** iterator = free_items; /* C is dumb */
 
   /* We only need to free anything allocated by yyparse() here.
-   * Resetting structs, etc, is taken care of by set_default_conf().
+   * Resetting structs, etc, is taken care of by conf_set_defaults().
    */
 
   for (; *iterator; iterator++)
@@ -898,16 +886,18 @@ clear_out_old_conf(void)
   ConfigServerInfo.network_desc = NULL;
   xfree(ConfigServerInfo.rsa_private_key_file);
   ConfigServerInfo.rsa_private_key_file = NULL;
-  xfree(ConfigServerInfo.ssl_certificate_file);
-  ConfigServerInfo.ssl_certificate_file = NULL;
-  xfree(ConfigServerInfo.ssl_dh_param_file);
-  ConfigServerInfo.ssl_dh_param_file = NULL;
-  xfree(ConfigServerInfo.ssl_dh_elliptic_curve);
-  ConfigServerInfo.ssl_dh_elliptic_curve = NULL;
-  xfree(ConfigServerInfo.ssl_cipher_list);
-  ConfigServerInfo.ssl_cipher_list = NULL;
-  xfree(ConfigServerInfo.ssl_message_digest_algorithm);
-  ConfigServerInfo.ssl_message_digest_algorithm = NULL;
+  xfree(ConfigServerInfo.tls_certificate_file);
+  ConfigServerInfo.tls_certificate_file = NULL;
+  xfree(ConfigServerInfo.tls_dh_param_file);
+  ConfigServerInfo.tls_dh_param_file = NULL;
+  xfree(ConfigServerInfo.tls_supported_groups);
+  ConfigServerInfo.tls_supported_groups = NULL;
+  xfree(ConfigServerInfo.tls_cipher_list);
+  ConfigServerInfo.tls_cipher_list = NULL;
+  xfree(ConfigServerInfo.tls_cipher_suites);
+  ConfigServerInfo.tls_cipher_suites = NULL;
+  xfree(ConfigServerInfo.tls_message_digest_algorithm);
+  ConfigServerInfo.tls_message_digest_algorithm = NULL;
 
   /* Clean out ConfigAdminInfo */
   xfree(ConfigAdminInfo.name);
@@ -930,7 +920,7 @@ clear_out_old_conf(void)
 static void
 conf_handle_tls(bool cold)
 {
-  if (tls_new_cred() == false)
+  if (tls_new_credentials() == false)
   {
     if (cold == true)
     {
@@ -953,44 +943,44 @@ conf_handle_tls(bool cold)
  * side effects - read all conf files needed, ircd.conf kline.conf etc.
  */
 void
-read_conf_files(bool cold)
+conf_read_files(bool cold)
 {
-  const char *filename = NULL;
-  char chanmodes[IRCD_BUFSIZE] = "";
-  char chanlimit[IRCD_BUFSIZE] = "";
+  char buf[IRCD_BUFSIZE];
 
   conf_parser_ctx.boot = cold;
-  filename = ConfigGeneral.configfile;
+  conf_parser_ctx.conf_file = fopen(ConfigGeneral.configfile, "r");
 
-  /* We need to know the initial filename for the yyerror() to report
-     FIXME: The full path is in conffilenamebuf first time since we
-             don't know anything else
-
-     - Gozem 2002-07-21
-  */
-  strlcpy(conffilebuf, filename, sizeof(conffilebuf));
-
-  if ((conf_parser_ctx.conf_file = fopen(filename, "r")) == NULL)
+  if (conf_parser_ctx.conf_file == NULL)
   {
     if (cold == true)
     {
       ilog(LOG_TYPE_IRCD, "Unable to read configuration file '%s': %s",
-           filename, strerror(errno));
+           ConfigGeneral.configfile, strerror(errno));
       exit(EXIT_FAILURE);
     }
     else
     {
       sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                            "Unable to read configuration file '%s': %s",
-                           filename, strerror(errno));
+                           ConfigGeneral.configfile, strerror(errno));
       return;
     }
   }
 
-  if (cold == false)
-    clear_out_old_conf();
+  /*
+   * We need to know the initial filename for the yyerror() to report
+   *
+   *  FIXME: The full path is in conffilenamebuf first time since we
+   *          don't know anything else
+   *
+   *  - Gozem 2002-07-21
+   */
+  strlcpy(conffilebuf, ConfigGeneral.configfile, sizeof(conffilebuf));
 
-  read_conf(conf_parser_ctx.conf_file);
+  if (cold == false)
+    conf_clear();
+
+  conf_read(conf_parser_ctx.conf_file);
   fclose(conf_parser_ctx.conf_file);
 
   log_iterate(log_reopen);
@@ -999,18 +989,20 @@ read_conf_files(bool cold)
   isupport_add("NICKLEN", NULL, ConfigServerInfo.max_nick_length);
   isupport_add("NETWORK", ConfigServerInfo.network_name, -1);
 
-  snprintf(chanmodes, sizeof(chanmodes), "beI:%u", ConfigChannel.max_bans);
-  isupport_add("MAXLIST", chanmodes, -1);
+  snprintf(buf, sizeof(buf), "beI:%u", ConfigChannel.max_bans);
+  isupport_add("MAXLIST", buf, -1);
+
   isupport_add("MAXTARGETS", NULL, ConfigGeneral.max_targets);
   isupport_add("CHANTYPES", "#", -1);
 
-  snprintf(chanlimit, sizeof(chanlimit), "#:%u",
-           ConfigChannel.max_channels);
-  isupport_add("CHANLIMIT", chanlimit, -1);
-  snprintf(chanmodes, sizeof(chanmodes), "%s", "beI,k,l,cimnprstuCLMNORST");
+  snprintf(buf, sizeof(buf), "#:%u", ConfigChannel.max_channels);
+  isupport_add("CHANLIMIT", buf, -1);
+
   isupport_add("CHANNELLEN", NULL, CHANNELLEN);
   isupport_add("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
-  isupport_add("CHANMODES", chanmodes, -1);
+
+  snprintf(buf, sizeof(buf), "%s", "beI,k,l,cimnprstuCLMNORST");
+  isupport_add("CHANMODES", buf, -1);
 }
 
 /* conf_add_class_to_conf()
@@ -1156,7 +1148,7 @@ valid_wild_card_simple(const char *data)
  *		- int flag, 0 for no warning oper 1 for warning oper
  *		- count of following varargs to check
  * output       - 0 if not valid, 1 if valid
- * side effects - NOTICE is given to source_p if warn is 1
+ * side effects - NOTICE is given to client if warn is 1
  */
 bool
 valid_wild_card(int count, ...)
@@ -1237,7 +1229,7 @@ valid_wild_card(int count, ...)
  * - Dianora
  */
 bool
-parse_aline(const char *cmd, struct Client *source_p, int parc, char **parv, struct aline_ctx *aline)
+parse_aline(const char *cmd, struct Client *client, int parc, char **parv, struct aline_ctx *aline)
 {
   static char default_reason[] = CONF_NOREASON;
   static char user[USERLEN * 2 + 1];
@@ -1254,7 +1246,7 @@ parse_aline(const char *cmd, struct Client *source_p, int parc, char **parv, str
 
   if (parc == 0)
   {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, cmd);
+    sendto_one_numeric(client, &me, ERR_NEEDMOREPARAMS, cmd);
     return false;
   }
 
@@ -1294,15 +1286,15 @@ parse_aline(const char *cmd, struct Client *source_p, int parc, char **parv, str
       ++parv;
       --parc;
 
-      if (!HasOFlag(source_p, OPER_FLAG_REMOTEBAN))
+      if (!HasOFlag(client, OPER_FLAG_REMOTEBAN))
       {
-        sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "remoteban");
+        sendto_one_numeric(client, &me, ERR_NOPRIVS, "remoteban");
         return false;
       }
 
       if (parc == 0 || EmptyString(*parv))
       {
-        sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, cmd);
+        sendto_one_numeric(client, &me, ERR_NEEDMOREPARAMS, cmd);
         return false;
       }
 
