@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_class.c
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.c 9039 2019-05-30 22:46:20Z michael $
+ * \version $Id: conf_class.c 9249 2020-02-01 13:35:32Z michael $
  */
 
 #include "stdinc.h"
@@ -246,11 +246,11 @@ class_ip_limit_rebuild(struct ClassItem *class)
 
   DLINK_FOREACH(node, local_client_list.head)
   {
-    struct Client *client_p = node->data;
-    struct MaskItem *conf = client_p->connection->confs.tail->data;
+    struct Client *client = node->data;
+    struct MaskItem *conf = client->connection->confs.tail->data;
 
     if (conf->type == CONF_CLIENT)
       if (conf->class == class)
-        class_ip_limit_add(class, &client_p->ip, true);
+        class_ip_limit_add(class, &client->ip, true);
   }
 }
