@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2018 ircd-hybrid development team
+ *  Copyright (c) 2014-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_pseudo.c
  * \brief Handles with pseudo commands/service aliases.
- * \version $Id: conf_pseudo.c 8461 2018-03-31 15:42:41Z michael $
+ * \version $Id: conf_pseudo.c 9102 2020-01-01 09:58:57Z michael $
  */
 
 #include "stdinc.h"
@@ -48,7 +48,7 @@ pseudo_get_list(void)
   return &pseudo_list;
 }
 
-static int
+static void
 pseudo_message_handler(struct Client *source_p, int parc, char *parv[])
 {
   char buffer[IRCD_BUFSIZE] = "";
@@ -60,7 +60,7 @@ pseudo_message_handler(struct Client *source_p, int parc, char *parv[])
   if (parc < 3 || EmptyString(msg))
   {
     sendto_one_numeric(source_p, &me, ERR_NOTEXTTOSEND);
-    return 0;
+    return;
   }
 
   if (pseudo->prepend)
@@ -76,8 +76,6 @@ pseudo_message_handler(struct Client *source_p, int parc, char *parv[])
     sendto_one(target_p, ":%s PRIVMSG %s :%s", source_p->id, target_p->id, msg);
   else
     sendto_one_numeric(source_p, &me, ERR_SERVICESDOWN, pseudo->name);
-
-  return 0;
 }
 
 void
