@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_resv.c
  * \brief Functions to reserve(jupe) a nick/channel.
- * \version $Id: conf_resv.c 8472 2018-04-03 12:54:41Z michael $
+ * \version $Id: conf_resv.c 9249 2020-02-01 13:35:32Z michael $
  */
 
 #include "stdinc.h"
@@ -55,8 +55,12 @@ resv_nick_get_list(void)
 }
 
 void
-resv_delete(struct ResvItem *resv)
+resv_delete(struct ResvItem *resv, bool expired)
 {
+  if (expired == true)
+    sendto_realops_flags(UMODE_EXPIRATION, L_ALL, SEND_NOTICE, "Temporary RESV for [%s] expired",
+                         resv->mask);
+
   while (resv->exempt_list.head)
   {
     struct ResvExemptItem *exempt = resv->exempt_list.head->data;
@@ -87,9 +91,6 @@ resv_make(const char *mask, const char *reason, const dlink_list *elist)
 {
   dlink_list *list;
 
-  if (resv_find(mask, irccmp))
-    return NULL;
-
   if (IsChanPrefix(*mask))
     list = &resv_chan_list;
   else
@@ -139,7 +140,7 @@ resv_make(const char *mask, const char *reason, const dlink_list *elist)
 struct ResvItem *
 resv_find(const char *name, int (*compare)(const char *, const char *))
 {
-  dlink_node *node;
+  dlink_node *node, *node_next;
   dlink_list *list;
 
   if (IsChanPrefix(*name))
@@ -147,19 +148,22 @@ resv_find(const char *name, int (*compare)(const char *, const char *))
   else
     list = &resv_nick_list;
 
-  DLINK_FOREACH(node, list->head)
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
     struct ResvItem *resv = node->data;
 
-    if (!compare(resv->mask, name))
+    if (resv->expire &&
+        (resv->expire <= event_base->time.sec_real))
+      resv_delete(resv, true);
+    else if (compare(resv->mask, name) == 0)
       return resv;
   }
 
   return NULL;
 }
 
-int
-resv_exempt_find(const struct Client *client_p, const struct ResvItem *resv)
+bool
+resv_exempt_find(const struct Client *client, const struct ResvItem *resv)
 {
   dlink_node *node;
 
@@ -167,23 +171,23 @@ resv_exempt_find(const struct Client *client_p, const struct ResvItem *resv)
   {
     const struct ResvExemptItem *exempt = node->data;
 
-    if (!match(exempt->name, client_p->name) && !match(exempt->user, client_p->username))
+    if (match(exempt->name, client->name) == 0 && match(exempt->user, client->username) == 0)
     {
       switch (exempt->type)
       {
         case HM_HOST:
-          if (!match(exempt->host, client_p->host) || !match(exempt->host, client_p->sockhost))
-            return 1;
+          if (match(exempt->host, client->host) == 0 || match(exempt->host, client->sockhost) == 0)
+            return true;
           break;
         case HM_IPV4:
-          if (client_p->connection->aftype == AF_INET)
-            if (match_ipv4(&client_p->connection->ip, &exempt->addr, exempt->bits))
-              return 1;
+          if (client->ip.ss.ss_family == AF_INET)
+            if (match_ipv4(&client->ip, &exempt->addr, exempt->bits))
+              return true;
           break;
         case HM_IPV6:
-          if (client_p->connection->aftype == AF_INET6)
-            if (match_ipv6(&client_p->connection->ip, &exempt->addr, exempt->bits))
-              return 1;
+          if (client->ip.ss.ss_family == AF_INET6)
+            if (match_ipv6(&client->ip, &exempt->addr, exempt->bits))
+              return true;
           break;
         default:
           assert(0);
@@ -191,7 +195,7 @@ resv_exempt_find(const struct Client *client_p, const struct ResvItem *resv)
     }
   }
 
-  return 0;
+  return false;
 }
 
 void
@@ -207,8 +211,8 @@ resv_clear(void)
     {
       struct ResvItem *resv = node->data;
 
-      if (resv->in_database == 0)
-        resv_delete(resv);
+      if (resv->in_database == false)
+        resv_delete(resv, false);
     }
   }
 }
@@ -226,13 +230,9 @@ resv_expire(void)
     {
       struct ResvItem *resv = node->data;
 
-      if (resv->expire == 0 || resv->expire > CurrentTime)
-        continue;
-
-      if (ConfigGeneral.tkline_expire_notices)
-        sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Temporary RESV for [%s] expired",
-                             resv->mask);
-      resv_delete(resv);
+      if (resv->expire &&
+          (resv->expire <= event_base->time.sec_real))
+        resv_delete(resv, true);
     }
   }
 }
