@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.c
  * \brief Maintains a list of file descriptors.
- * \version $Id: fdlist.c 8874 2019-02-16 21:53:04Z michael $
+ * \version $Id: fdlist.c 9156 2020-01-13 14:51:47Z michael $
  */
 
 #include "stdinc.h"
@@ -115,8 +115,8 @@ fd_close(fde_t *F)
   if (F->flags.is_socket == true)
     comm_setselect(F, COMM_SELECT_WRITE | COMM_SELECT_READ, NULL, NULL, 0);
 
-  if (tls_isusing(&F->ssl))
-    tls_free(&F->ssl);
+  if (tls_isusing(&F->tls))
+    tls_free(&F->tls);
 
   xfree(F->desc);
   /* Unlike squid, we're actually closing the FD here! -- adrian */
