@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hash.c
  * \brief Hash table management.
- * \version $Id: hash.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: hash.c 9249 2020-02-01 13:35:32Z michael $
  */
 
 #include "stdinc.h"
@@ -41,8 +41,6 @@
 #include "dbuf.h"
 
 
-static unsigned int hashf_xor_key;
-
 /* The actual hash tables, They MUST be of the same HASHSIZE, variable
  * size tables could be supported but the rehash routine should also
  * rebuild the transformation maps, I kept the tables of equal size
@@ -53,21 +51,6 @@ static struct Client *clientTable[HASHSIZE];
 static struct Channel *channelTable[HASHSIZE];
 
 
-/* hash_init()
- *
- * inputs       - NONE
- * output       - NONE
- * side effects - Initialize the maps used by hash
- *                functions and clear the tables
- */
-void
-hash_init(void)
-{
-  do
-    hashf_xor_key = genrand_int32() % 256;  /* better than nothing --adx */
-  while (!hashf_xor_key);
-}
-
 /*
  * New hash function based on the Fowler/Noll/Vo (FNV) algorithm from
  * http://www.isthe.com/chongo/tech/comp/fnv/
@@ -78,12 +61,18 @@ hash_init(void)
 unsigned int
 strhash(const char *name)
 {
+  static unsigned int hashf_xor_key = 0;
   const unsigned char *p = (const unsigned char *)name;
   unsigned int hval = FNV1_32_INIT;
 
   if (EmptyString(p))
     return 0;
 
+  if (hashf_xor_key == 0)
+    do
+      hashf_xor_key = genrand_int32() % 256;  /* better than nothing --adx */
+    while (hashf_xor_key == 0);
+
   for (; *p; ++p)
   {
     hval += (hval << 1) + (hval << 4) +
@@ -109,17 +98,17 @@ strhash(const char *name)
  * inputs       - pointer to client
  * output       - NONE
  * side effects - Adds a client's name in the proper hash linked
- *                list, can't fail, client_p must have a non-null
+ *                list, can't fail, client must have a non-null
  *                name or expect a coredump, the name is infact
- *                taken from client_p->name
+ *                taken from client->name
  */
 void
-hash_add_client(struct Client *client_p)
+hash_add_client(struct Client *client)
 {
-  const unsigned int hashv = strhash(client_p->name);
+  const unsigned int hashv = strhash(client->name);
 
-  client_p->hnext = clientTable[hashv];
-  clientTable[hashv] = client_p;
+  client->hnext = clientTable[hashv];
+  clientTable[hashv] = client;
 }
 
 /* hash_add_channel()
@@ -127,27 +116,27 @@ hash_add_client(struct Client *client_p)
  * inputs       - pointer to channel
  * output       - NONE
  * side effects - Adds a channel's name in the proper hash linked
- *                list, can't fail. chptr must have a non-null name
+ *                list, can't fail. channel must have a non-null name
  *                or expect a coredump. As before the name is taken
- *                from chptr->name, we do hash its entire lenght
+ *                from channel->name, we do hash its entire lenght
  *                since this proved to be statistically faster
  */
 void
-hash_add_channel(struct Channel *chptr)
+hash_add_channel(struct Channel *channel)
 {
-  const unsigned int hashv = strhash(chptr->name);
+  const unsigned int hashv = strhash(channel->name);
 
-  chptr->hnextch = channelTable[hashv];
-  channelTable[hashv] = chptr;
+  channel->hnextch = channelTable[hashv];
+  channelTable[hashv] = channel;
 }
 
 void
-hash_add_id(struct Client *client_p)
+hash_add_id(struct Client *client)
 {
-  const unsigned int hashv = strhash(client_p->id);
+  const unsigned int hashv = strhash(client->id);
 
-  client_p->idhnext = idTable[hashv];
-  idTable[hashv] = client_p;
+  client->idhnext = idTable[hashv];
+  idTable[hashv] = client;
 }
 
 /* hash_del_id()
@@ -157,26 +146,26 @@ hash_add_id(struct Client *client_p)
  * side effects - Removes an ID from the hash linked list
  */
 void
-hash_del_id(struct Client *client_p)
+hash_del_id(struct Client *client)
 {
-  const unsigned int hashv = strhash(client_p->id);
+  const unsigned int hashv = strhash(client->id);
   struct Client *tmp = idTable[hashv];
 
   if (tmp)
   {
-    if (tmp == client_p)
+    if (tmp == client)
     {
-      idTable[hashv] = client_p->idhnext;
-      client_p->idhnext = client_p;
+      idTable[hashv] = client->idhnext;
+      client->idhnext = client;
     }
     else
     {
-      while (tmp->idhnext != client_p)
+      while (tmp->idhnext != client)
         if ((tmp = tmp->idhnext) == NULL)
           return;
 
       tmp->idhnext = tmp->idhnext->idhnext;
-      client_p->idhnext = client_p;
+      client->idhnext = client;
     }
   }
 }
@@ -188,26 +177,26 @@ hash_del_id(struct Client *client_p)
  * side effects - Removes a Client's name from the hash linked list
  */
 void
-hash_del_client(struct Client *client_p)
+hash_del_client(struct Client *client)
 {
-  const unsigned int hashv = strhash(client_p->name);
+  const unsigned int hashv = strhash(client->name);
   struct Client *tmp = clientTable[hashv];
 
   if (tmp)
   {
-    if (tmp == client_p)
+    if (tmp == client)
     {
-      clientTable[hashv] = client_p->hnext;
-      client_p->hnext = client_p;
+      clientTable[hashv] = client->hnext;
+      client->hnext = client;
     }
     else
     {
-      while (tmp->hnext != client_p)
+      while (tmp->hnext != client)
         if ((tmp = tmp->hnext) == NULL)
           return;
 
       tmp->hnext = tmp->hnext->hnext;
-      client_p->hnext = client_p;
+      client->hnext = client;
     }
   }
 }
@@ -220,26 +209,26 @@ hash_del_client(struct Client *client_p)
  *                hash linked list
  */
 void
-hash_del_channel(struct Channel *chptr)
+hash_del_channel(struct Channel *channel)
 {
-  const unsigned int hashv = strhash(chptr->name);
+  const unsigned int hashv = strhash(channel->name);
   struct Channel *tmp = channelTable[hashv];
 
   if (tmp)
   {
-    if (tmp == chptr)
+    if (tmp == channel)
     {
-      channelTable[hashv] = chptr->hnextch;
-      chptr->hnextch = chptr;
+      channelTable[hashv] = channel->hnextch;
+      channel->hnextch = channel;
     }
     else
     {
-      while (tmp->hnextch != chptr)
+      while (tmp->hnextch != channel)
         if ((tmp = tmp->hnextch) == NULL)
           return;
 
       tmp->hnextch = tmp->hnextch->hnextch;
-      chptr->hnextch = chptr;
+      channel->hnextch = channel;
     }
   }
 }
@@ -256,89 +245,89 @@ struct Client *
 hash_find_client(const char *name)
 {
   const unsigned int hashv = strhash(name);
-  struct Client *client_p;
+  struct Client *client;
 
-  if ((client_p = clientTable[hashv]))
+  if ((client = clientTable[hashv]))
   {
-    if (irccmp(name, client_p->name))
+    if (irccmp(name, client->name))
     {
       struct Client *prev;
 
-      while (prev = client_p, (client_p = client_p->hnext))
+      while (prev = client, (client = client->hnext))
       {
-        if (!irccmp(name, client_p->name))
+        if (irccmp(name, client->name) == 0)
         {
-          prev->hnext = client_p->hnext;
-          client_p->hnext = clientTable[hashv];
-          clientTable[hashv] = client_p;
+          prev->hnext = client->hnext;
+          client->hnext = clientTable[hashv];
+          clientTable[hashv] = client;
           break;
         }
       }
     }
   }
 
-  return client_p;
+  return client;
 }
 
 struct Client *
 hash_find_id(const char *name)
 {
   const unsigned int hashv = strhash(name);
-  struct Client *client_p;
+  struct Client *client;
 
-  if ((client_p = idTable[hashv]))
+  if ((client = idTable[hashv]))
   {
-    if (strcmp(name, client_p->id))
+    if (strcmp(name, client->id))
     {
       struct Client *prev;
 
-      while (prev = client_p, (client_p = client_p->idhnext))
+      while (prev = client, (client = client->idhnext))
       {
-        if (!strcmp(name, client_p->id))
+        if (strcmp(name, client->id) == 0)
         {
-          prev->idhnext = client_p->idhnext;
-          client_p->idhnext = idTable[hashv];
-          idTable[hashv] = client_p;
+          prev->idhnext = client->idhnext;
+          client->idhnext = idTable[hashv];
+          idTable[hashv] = client;
           break;
         }
       }
     }
   }
 
-  return client_p;
+  return client;
 }
 
 struct Client *
 hash_find_server(const char *name)
 {
   const unsigned int hashv = strhash(name);
-  struct Client *client_p = NULL;
+  struct Client *client;
 
   if (IsDigit(*name) && strlen(name) == IRC_MAXSID)
     return hash_find_id(name);
 
-  if ((client_p = clientTable[hashv]))
+  if ((client = clientTable[hashv]))
   {
-    if ((!IsServer(client_p) && !IsMe(client_p)) ||
-        irccmp(name, client_p->name))
+    if ((!IsServer(client) && !IsMe(client)) ||
+        irccmp(name, client->name))
     {
       struct Client *prev;
 
-      while (prev = client_p, (client_p = client_p->hnext))
+      while (prev = client, (client = client->hnext))
       {
-        if ((IsServer(client_p) || IsMe(client_p)) &&
-            !irccmp(name, client_p->name))
+        if ((IsServer(client) || IsMe(client)) &&
+            irccmp(name, client->name) == 0)
         {
-          prev->hnext = client_p->hnext;
-          client_p->hnext = clientTable[hashv];
-          clientTable[hashv] = client_p;
+          prev->hnext = client->hnext;
+          client->hnext = clientTable[hashv];
+          clientTable[hashv] = client;
           break;
         }
       }
     }
   }
 
-  return client_p;
+  return client;
 }
 
 /* hash_find_channel()
@@ -353,28 +342,28 @@ struct Channel *
 hash_find_channel(const char *name)
 {
   const unsigned int hashv = strhash(name);
-  struct Channel *chptr = NULL;
+  struct Channel *channel;
 
-  if ((chptr = channelTable[hashv]))
+  if ((channel = channelTable[hashv]))
   {
-    if (irccmp(name, chptr->name))
+    if (irccmp(name, channel->name))
     {
       struct Channel *prev;
 
-      while (prev = chptr, (chptr = chptr->hnextch))
+      while (prev = channel, (channel = channel->hnextch))
       {
-        if (!irccmp(name, chptr->name))
+        if (irccmp(name, channel->name) == 0)
         {
-          prev->hnextch = chptr->hnextch;
-          chptr->hnextch = channelTable[hashv];
-          channelTable[hashv] = chptr;
+          prev->hnextch = channel->hnextch;
+          channel->hnextch = channelTable[hashv];
+          channelTable[hashv] = channel;
           break;
         }
       }
     }
   }
 
-  return chptr;
+  return channel;
 }
 
 /* hash_get_bucket(int type, unsigned int hashv)
@@ -445,9 +434,9 @@ exceeding_sendq(const struct Client *to)
 }
 
 void
-free_list_task(struct Client *source_p)
+free_list_task(struct Client *client)
 {
-  struct ListTask *const lt = source_p->connection->list_task;
+  struct ListTask *const lt = client->connection->list_task;
   dlink_node *node, *node_next;
 
   dlinkDelete(&lt->node, &listing_client_list);
@@ -467,7 +456,7 @@ free_list_task(struct Client *source_p)
   }
 
   xfree(lt);
-  source_p->connection->list_task = NULL;
+  client->connection->list_task = NULL;
 }
 
 /* list_allow_channel()
@@ -503,50 +492,50 @@ list_allow_channel(const char *name, const struct ListTask *lt)
  * side effects -
  */
 static void
-list_one_channel(struct Client *source_p, struct Channel *chptr)
+list_one_channel(struct Client *client, struct Channel *channel)
 {
-  const struct ListTask *const lt = source_p->connection->list_task;
+  const struct ListTask *const lt = client->connection->list_task;
   char listbuf[MODEBUFLEN] = "";
   char modebuf[MODEBUFLEN] = "";
   char parabuf[MODEBUFLEN] = "";
 
-  if (SecretChannel(chptr) &&
-      !(HasUMode(source_p, UMODE_ADMIN) || IsMember(source_p, chptr)))
+  if (SecretChannel(channel) &&
+      !(HasUMode(client, UMODE_ADMIN) || IsMember(client, channel)))
     return;
 
-  if (dlink_list_length(&chptr->members) < lt->users_min ||
-      dlink_list_length(&chptr->members) > lt->users_max ||
-      (chptr->creationtime != 0 &&
-       ((unsigned int)chptr->creationtime < lt->created_min ||
-        (unsigned int)chptr->creationtime > lt->created_max)) ||
-      (unsigned int)chptr->topic_time < lt->topicts_min ||
-      (chptr->topic_time ? (unsigned int)chptr->topic_time : UINT_MAX) >
+  if (dlink_list_length(&channel->members) < lt->users_min ||
+      dlink_list_length(&channel->members) > lt->users_max ||
+      (channel->creation_time != 0 &&
+       ((unsigned int)channel->creation_time < lt->created_min ||
+        (unsigned int)channel->creation_time > lt->created_max)) ||
+      (unsigned int)channel->topic_time < lt->topicts_min ||
+      (channel->topic_time ? (unsigned int)channel->topic_time : UINT_MAX) >
       lt->topicts_max)
     return;
 
-  if (lt->topic[0] && match(lt->topic, chptr->topic))
+  if (lt->topic[0] && match(lt->topic, channel->topic))
     return;
 
-  if (list_allow_channel(chptr->name, lt) == false)
+  if (list_allow_channel(channel->name, lt) == false)
     return;
 
-  channel_modes(chptr, source_p, modebuf, parabuf);
+  channel_modes(channel, client, modebuf, parabuf);
 
-  if (chptr->topic[0])
+  if (channel->topic[0])
     snprintf(listbuf, sizeof(listbuf), "[%s] ", modebuf);
   else
     snprintf(listbuf, sizeof(listbuf), "[%s]",  modebuf);
 
-  sendto_one_numeric(source_p, &me, RPL_LIST, chptr->name,
-                     dlink_list_length(&chptr->members),
-                     listbuf, chptr->topic);
+  sendto_one_numeric(client, &me, RPL_LIST, channel->name,
+                     dlink_list_length(&channel->members),
+                     listbuf, channel->topic);
 }
 
 /* safe_list_channels()
  *
  * inputs	- pointer to client requesting list
  * output	- 0/1
- * side effects	- safely list all channels to source_p
+ * side effects	- safely list all channels to client
  *
  * Walk the channel buckets, ensure all pointers in a bucket are
  * traversed before blocking on a sendq. This means, no locking is needed.
@@ -554,23 +543,23 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
  * - Dianora
  */
 void
-safe_list_channels(struct Client *source_p, bool only_unmasked_channels)
+safe_list_channels(struct Client *client, bool only_unmasked_channels)
 {
-  struct ListTask *const lt = source_p->connection->list_task;
-  struct Channel *chptr = NULL;
+  struct ListTask *const lt = client->connection->list_task;
+  struct Channel *channel;
 
   if (only_unmasked_channels == false)
   {
     for (unsigned int i = lt->hash_index; i < HASHSIZE; ++i)
     {
-      if (exceeding_sendq(source_p) == true)
+      if (exceeding_sendq(client) == true)
       {
         lt->hash_index = i;
         return;  /* Still more to do */
       }
 
-      for (chptr = channelTable[i]; chptr; chptr = chptr->hnextch)
-        list_one_channel(source_p, chptr);
+      for (channel = channelTable[i]; channel; channel = channel->hnextch)
+        list_one_channel(client, channel);
     }
   }
   else
@@ -578,10 +567,10 @@ safe_list_channels(struct Client *source_p, bool only_unmasked_channels)
     dlink_node *node;
 
     DLINK_FOREACH(node, lt->show_mask.head)
-      if ((chptr = hash_find_channel(node->data)))
-        list_one_channel(source_p, chptr);
+      if ((channel = hash_find_channel(node->data)))
+        list_one_channel(client, channel);
   }
 
-  free_list_task(source_p);
-  sendto_one_numeric(source_p, &me, RPL_LISTEND);
+  free_list_task(client);
+  sendto_one_numeric(client, &me, RPL_LISTEND);
 }
