@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ipcache.c
  * \brief Routines to count connections from particular IP addresses.
- * \version $Id: ipcache.c 8902 2019-04-21 20:41:04Z michael $
+ * \version $Id: ipcache.c 9334 2020-04-18 16:18:49Z michael $
  */
 
 #include "stdinc.h"
@@ -100,7 +100,7 @@ ipcache_record_delete(patricia_node_t *pnode)
  *                 the struct ip_entry is returned to the ip_entry_heap
  */
 void
-ipcache_record_remove(void *addr, int local)
+ipcache_record_remove(void *addr, bool local)
 {
   patricia_node_t *pnode = patricia_try_search_exact_addr(ipcache_get_trie(addr), addr, 0);
 
@@ -110,7 +110,7 @@ ipcache_record_remove(void *addr, int local)
   struct ip_entry *iptr = PATRICIA_DATA_GET(pnode, struct ip_entry);
   assert(iptr->count_local > 0 || iptr->count_remote > 0);
 
-  if (local)
+  if (local == true)
     --iptr->count_local;
   else
     --iptr->count_remote;
