@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.c
  * \brief IRC string functions.
- * \version $Id: irc_string.c 8751 2019-01-01 11:06:50Z michael $
+ * \version $Id: irc_string.c 9330 2020-04-11 12:55:09Z michael $
  */
 
 #include "config.h"
@@ -63,42 +63,6 @@ stripws(char *txt)
   return txt;
 }
 
-/*
- * strtok_r - walk through a string of tokens, using a set of separators
- *   argv 9/90
- *
- */
-#ifndef HAVE_STRTOK_R
-char *
-strtok_r(char *str, const char *fs, char **save)
-{
-  char *pos = *save;  /* keep last position across calls */
-  char *tmp = NULL;
-
-  if (str)
-    pos = str;    /* new string scan */
-
-  while (pos && *pos && strchr(fs, *pos))
-    ++pos;        /* skip leading separators */
-
-  if (!pos || !*pos)
-    return pos = *save = NULL;   /* string contains only sep's */
-
-  tmp = pos;       /* now, keep position of the token */
-
-  while (*pos && strchr(fs, *pos) == NULL)
-    ++pos;       /* skip content of the token */
-
-  if (*pos)
-    *pos++ = '\0';    /* remove first sep after the token */
-  else
-    pos = NULL;    /* end of string */
-
-  *save = pos;
-  return tmp;
-}
-#endif /* !HAVE_STRTOK_R */
-
 /** Fill a vector of tokens from a delimited input list.
  * Empty tokens (when \a token occurs at the start or end of \a list,
  * or when \a token occurs adjacent to itself) are ignored.  When
