@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2019 ircd-hybrid development team
+ *  Copyright (c) 1997-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 8981 2019-05-19 10:54:54Z michael $
+ * \version $Id: ircd.c 9323 2020-03-29 10:40:17Z michael $
  */
 
 #include "stdinc.h"
@@ -50,7 +50,6 @@
 #include "server_capab.h"
 #include "send.h"
 #include "modules.h"
-#include "memory.h"
 #include "ircd_getopt.h"
 #include "conf_db.h"
 #include "conf_class.h"
@@ -58,6 +57,7 @@
 #include "isupport.h"
 #include "patchlevel.h"
 #include "serno.h"
+#include "extban.h"
 
 
 struct SetOptions GlobalSetOptions;  /* /quote set variables */
@@ -289,6 +289,10 @@ setup_fdlimit(void)
     exit(EXIT_FAILURE);
   }
 
+#ifdef __APPLE__
+  if (rlim.rlim_max > OPEN_MAX)
+    rlim.rlim_max = OPEN_MAX;
+#endif
   if (rlim.rlim_max > 0xFFFF)
     rlim.rlim_max = 0xFFFF;
   rlim.rlim_cur = rlim.rlim_max;
@@ -318,9 +322,9 @@ print_startup(int pid)
 static void
 make_daemon(void)
 {
-  int pid;
+  int pid = fork();
 
-  if ((pid = fork()) < 0)
+  if (pid < 0)
   {
     perror("fork");
     exit(EXIT_FAILURE);
@@ -404,16 +408,16 @@ main(int argc, char *argv[])
   check_pidfile(pidFileName);
 
   isupport_init();
-  hash_init();
   ipcache_init();
   client_init();
   class_init();
   resolver_init();      /* Needs to be setup before the io loop */
   modules_init();
-  read_conf_files(true);   /* cold start init conf files */
+  conf_read_files(true);   /* cold start init conf files */
   capab_init();  /* Set up default_server_capabs */
-  initialize_global_set_options();  /* Has to be called after read_conf_files() */
+  initialize_global_set_options();  /* Has to be called after conf_read_files() */
   channel_mode_init();
+  extban_init();
   read_links_file();
   motd_init();
   user_modes_init();
