@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2019 ircd-hybrid development team
+ *  Copyright (c) 1999-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 9013 2019-05-27 17:45:00Z michael $
+ * \version $Id: listener.c 9156 2020-01-13 14:51:47Z michael $
  */
 
 #include "stdinc.h"
@@ -123,7 +123,7 @@ listener_accept_connection(fde_t *F, void *data)
       sendto_realops_flags_ratelimited(&rate, "All connections in use. (%s)",
                                        listener_get_name(listener));
 
-      if (!(listener->flags & LISTENER_SSL))
+      if (!(listener->flags & LISTENER_TLS))
         send(fd, ALLINUSE_WARNING, sizeof(ALLINUSE_WARNING) - 1, 0);
 
       close(fd);
@@ -138,7 +138,7 @@ listener_accept_connection(fde_t *F, void *data)
     {
       ++ServerStats.is_ref;
 
-      if (!(listener->flags & LISTENER_SSL))
+      if (!(listener->flags & LISTENER_TLS))
       {
         switch (pe)
         {
