@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2019 ircd-hybrid development team
+ *  Copyright (c) 2015-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_none.c
  * \brief Dummy file for no TLS support
- * \version $Id: tls_none.c 8957 2019-05-10 17:07:45Z michael $
+ * \version $Id: tls_none.c 9223 2020-01-26 11:35:22Z michael $
  */
 
 #include "stdinc.h"
@@ -43,7 +43,7 @@ tls_init(void)
 }
 
 bool
-tls_new_cred(void)
+tls_new_credentials(void)
 {
   return true;
 }
@@ -107,7 +107,7 @@ tls_set_ciphers(tls_data_t *tls_data, const char *cipher_list)
 }
 
 bool
-tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
+tls_verify_certificate(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
 {
   return false;
 }
