@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2005-2019 ircd-hybrid development team
+ *  Copyright (c) 2005-2020 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_openssl.c
  * \brief Includes all OpenSSL-specific TLS functions
- * \version $Id: tls_openssl.c 8960 2019-05-11 08:50:02Z michael $
+ * \version $Id: tls_openssl.c 9223 2020-01-26 11:35:22Z michael $
  */
 
 #include "stdinc.h"
@@ -34,6 +34,9 @@
 #include "memory.h"
 
 #ifdef HAVE_TLS_OPENSSL
+#if OPENSSL_VERSION_NUMBER < 0x1010100fL
+#error "OpenSSL 1.1.1 and above is required to build this module"
+#endif
 
 static bool TLS_initialized;
 
@@ -43,7 +46,7 @@ static bool TLS_initialized;
 static void
 report_crypto_errors(void)
 {
-  unsigned long e = 0;
+  unsigned long e;
 
   while ((e = ERR_get_error()))
     ilog(LOG_TYPE_IRCD, "SSL error: %s", ERR_error_string(e, 0));
@@ -70,85 +73,68 @@ tls_is_initialized(void)
 void
 tls_init(void)
 {
-  SSL_load_error_strings();
-  SSLeay_add_ssl_algorithms();
-
-  if ((ConfigServerInfo.tls_ctx.server_ctx = SSL_CTX_new(SSLv23_server_method())) == NULL)
+  if ((ConfigServerInfo.tls_ctx.server_ctx = SSL_CTX_new(TLS_server_method())) == NULL)
   {
     const char *s = ERR_lib_error_string(ERR_get_error());
 
-    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the TLS Server context -- %s", s);
+    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the TLS server context -- %s", s);
     exit(EXIT_FAILURE);
     return;  /* Not reached */
   }
 
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1|SSL_OP_NO_TICKET);
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_SINGLE_DH_USE|SSL_OP_CIPHER_SERVER_PREFERENCE);
-  SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.server_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
-                     always_accept_verify_cb);
+  SSL_CTX_set_min_proto_version(ConfigServerInfo.tls_ctx.server_ctx, TLS1_2_VERSION);
+  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_CIPHER_SERVER_PREFERENCE|SSL_OP_NO_TICKET);
+  SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.server_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE, always_accept_verify_cb);
   SSL_CTX_set_session_cache_mode(ConfigServerInfo.tls_ctx.server_ctx, SSL_SESS_CACHE_OFF);
   SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
 
-#ifndef OPENSSL_NO_ECDH
-  EC_KEY *key = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
-
-  if (key)
-  {
-    SSL_CTX_set_tmp_ecdh(ConfigServerInfo.tls_ctx.server_ctx, key);
-    EC_KEY_free(key);
-  }
-
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_SINGLE_ECDH_USE);
-#endif
-
-  if ((ConfigServerInfo.tls_ctx.client_ctx = SSL_CTX_new(SSLv23_client_method())) == NULL)
+  if ((ConfigServerInfo.tls_ctx.client_ctx = SSL_CTX_new(TLS_client_method())) == NULL)
   {
     const char *s = ERR_lib_error_string(ERR_get_error());
 
-    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the TLS Client context -- %s", s);
+    ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the TLS client context -- %s", s);
     exit(EXIT_FAILURE);
     return;  /* Not reached */
   }
 
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1|SSL_OP_NO_TICKET);
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_SINGLE_DH_USE);
-  SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.client_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
-                     always_accept_verify_cb);
+  SSL_CTX_set_min_proto_version(ConfigServerInfo.tls_ctx.client_ctx, TLS1_2_VERSION);
+  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_NO_TICKET);
+  SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.client_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE, always_accept_verify_cb);
   SSL_CTX_set_session_cache_mode(ConfigServerInfo.tls_ctx.client_ctx, SSL_SESS_CACHE_OFF);
 }
 
 bool
-tls_new_cred(void)
+tls_new_credentials(void)
 {
   TLS_initialized = false;
 
-  if (!ConfigServerInfo.ssl_certificate_file || !ConfigServerInfo.rsa_private_key_file)
+  if (ConfigServerInfo.tls_certificate_file == NULL || ConfigServerInfo.rsa_private_key_file == NULL)
     return true;
 
-  if (SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.ssl_certificate_file) <= 0 ||
-      SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.ssl_certificate_file) <= 0)
+  if (SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.tls_certificate_file) != 1 ||
+      SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.tls_certificate_file) != 1)
   {
     report_crypto_errors();
     return false;
   }
 
-  if (SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0 ||
-      SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0)
+  if (SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) != 1 ||
+      SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) != 1)
   {
     report_crypto_errors();
     return false;
   }
 
-  if (!SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.server_ctx) ||
-      !SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.client_ctx))
+  if (SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.server_ctx) != 1 ||
+      SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.client_ctx) != 1)
   {
     report_crypto_errors();
     return false;
   }
 
-  if (ConfigServerInfo.ssl_dh_param_file)
+  if (ConfigServerInfo.tls_dh_param_file)
   {
-    BIO *file = BIO_new_file(ConfigServerInfo.ssl_dh_param_file, "r");
+    BIO *file = BIO_new_file(ConfigServerInfo.tls_dh_param_file, "r");
 
     if (file)
     {
@@ -163,56 +149,43 @@ tls_new_cred(void)
       }
     }
     else
-      ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::ssl_dh_param_file -- could not open/read Diffie-Hellman parameter file");
+      ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::tls_dh_param_file -- could not open/read Diffie-Hellman parameter file");
   }
 
-#ifndef OPENSSL_NO_ECDH
-  if (ConfigServerInfo.ssl_dh_elliptic_curve)
+  if (ConfigServerInfo.tls_supported_groups == NULL)
+    SSL_CTX_set1_groups_list(ConfigServerInfo.tls_ctx.server_ctx, "X25519:P-256");
+  else if (SSL_CTX_set1_groups_list(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.tls_supported_groups) == 0)
   {
-    int nid = 0;
-    EC_KEY *key = NULL;
-
-    if ((nid = OBJ_sn2nid(ConfigServerInfo.ssl_dh_elliptic_curve)) == 0)
-      goto set_default_curve;
-
-    if ((key = EC_KEY_new_by_curve_name(nid)) == NULL)
-      goto set_default_curve;
-
-    SSL_CTX_set_tmp_ecdh(ConfigServerInfo.tls_ctx.server_ctx, key);
-    EC_KEY_free(key);
+    SSL_CTX_set1_groups_list(ConfigServerInfo.tls_ctx.server_ctx, "X25519:P-256");
+    ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::tls_supported_groups -- could not set supported group(s)");
   }
-  else
+
+  if (ConfigServerInfo.tls_message_digest_algorithm == NULL)
+    ConfigServerInfo.message_digest_algorithm = EVP_sha256();
+  else if ((ConfigServerInfo.message_digest_algorithm = EVP_get_digestbyname(ConfigServerInfo.tls_message_digest_algorithm)) == NULL)
   {
-    EC_KEY *key;
+    ConfigServerInfo.message_digest_algorithm = EVP_sha256();
+    ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::tls_message_digest_algorithm -- unknown message digest algorithm");
+  }
 
-set_default_curve:
+  if (ConfigServerInfo.tls_cipher_list == NULL)
+    SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
+  else if (SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.tls_cipher_list) == 0)
+  {
+    SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
+    ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::tls_cipher_list -- could not set supported cipher(s)");
+  }
 
-    key = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
-
-    if (key)
-    {
-      SSL_CTX_set_tmp_ecdh(ConfigServerInfo.tls_ctx.server_ctx, key);
-      EC_KEY_free(key);
-    }
+#ifndef LIBRESSL_VERSION_NUMBER
+  if (ConfigServerInfo.tls_cipher_suites == NULL)
+    SSL_CTX_set_ciphersuites(ConfigServerInfo.tls_ctx.server_ctx, "TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:TLS_AES_128_GCM_SHA256");
+  else if (SSL_CTX_set_ciphersuites(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.tls_cipher_suites) == 0)
+  {
+    SSL_CTX_set_ciphersuites(ConfigServerInfo.tls_ctx.server_ctx, "TLS_AES_256_GCM_SHA384:TLS_CHACHA20_POLY1305_SHA256:TLS_AES_128_GCM_SHA256");
+    ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::tls_cipher_suites -- could not set supported cipher suite(s)");
   }
 #endif
 
-  if (ConfigServerInfo.ssl_message_digest_algorithm == NULL)
-    ConfigServerInfo.message_digest_algorithm = EVP_sha256();
-  else
-  {
-    ConfigServerInfo.message_digest_algorithm = EVP_get_digestbyname(ConfigServerInfo.ssl_message_digest_algorithm);
-
-    if (ConfigServerInfo.message_digest_algorithm == NULL)
-    {
-      ConfigServerInfo.message_digest_algorithm = EVP_sha256();
-      ilog(LOG_TYPE_IRCD, "Ignoring serverinfo::ssl_message_digest_algorithm -- unknown message digest algorithm");
-    }
-  }
-
-  if (ConfigServerInfo.ssl_cipher_list)
-    SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.ssl_cipher_list);
-
   TLS_initialized = true;
   return true;
 }
@@ -220,24 +193,20 @@ set_default_curve:
 const char *
 tls_get_cipher(const tls_data_t *tls_data)
 {
-  static char buffer[IRCD_BUFSIZE];
-  int bits = 0;
+  static char buf[128];
   SSL *ssl = *tls_data;
 
-  SSL_CIPHER_get_bits(SSL_get_current_cipher(ssl), &bits);
-
-  snprintf(buffer, sizeof(buffer), "%s-%s-%d", SSL_get_version(ssl),
-           SSL_get_cipher(ssl), bits);
-  return buffer;
+  snprintf(buf, sizeof(buf), "%s-%s", SSL_get_version(ssl), SSL_get_cipher(ssl));
+  return buf;
 }
 
 const char *
 tls_get_version(void)
 {
-  static char buf[IRCD_BUFSIZE];
+  static char buf[256];
 
   snprintf(buf, sizeof(buf), "OpenSSL version: library: %s, header: %s",
-           SSLeay_version(SSLEAY_VERSION), OPENSSL_VERSION_TEXT);
+           OpenSSL_version(OPENSSL_VERSION), OPENSSL_VERSION_TEXT);
   return buf;
 }
 
@@ -326,7 +295,7 @@ tls_shutdown(tls_data_t *tls_data)
 
   SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
 
-  if (!SSL_shutdown(ssl))
+  if (SSL_shutdown(ssl) == 0)
     SSL_shutdown(ssl);
 }
 
@@ -343,7 +312,7 @@ tls_new(tls_data_t *tls_data, int fd, tls_role_t role)
   else
     ssl = SSL_new(ConfigServerInfo.tls_ctx.client_ctx);
 
-  if (!ssl)
+  if (ssl == NULL)
   {
     ilog(LOG_TYPE_IRCD, "SSL_new() ERROR! -- %s",
          ERR_error_string(ERR_get_error(), NULL));
@@ -395,7 +364,7 @@ tls_handshake(tls_data_t *tls_data, tls_role_t role, const char **errstr)
 }
 
 bool
-tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
+tls_verify_certificate(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
 {
   SSL *ssl = *tls_data;
   unsigned int n;
